@@ -5,7 +5,7 @@
  * software
  */
 /*
- * $Id: huffd.c,v 1.5 2002/11/05 00:46:09 enlf Exp $
+ * $Id: huffd.c,v 1.6 2004/08/18 21:38:43 enlf Exp $
  */
 #include <stdio.h>
 #include <stdlib.h>
@@ -26,7 +26,7 @@ static int  bitsLeft;               /* # of unused bits in it */
  * The following variables keep track of the input buffer
  * for the JPEG data, which is read by ReadJpegData.
  */
-Uchar *inputBuffer;               /* Input buffer for JPEG data */
+Uchar *inputBuffer = 0;           /* Input buffer for JPEG data */
 int inputBufferOffset = 0;        /* Offset of current byte */
 
 /*
