@@ -39,7 +39,7 @@
  *                MdcUnpackBIT12()        - Unpack 12 bit into Uint16      *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-algori.c,v 1.68 2004/05/09 22:48:03 enlf Exp $ 
+/* $Id: m-algori.c,v 1.69 2005/02/01 23:23:30 enlf Exp $ 
  */
 
 /*
@@ -1122,9 +1122,11 @@ int MdcDoSimpleCast(double minv, double maxv, double negmin, double posmax)
 Uint8 *MdcGetResizedImage(FILEINFO *fi,Uint8 *buffer,int type,Uint32 img)
 {
   IMG_DATA *id = &fi->image[img];
-  Uint32 d, w, bytes, linesize, size;
+  Uint32 h, p, bytes, linesize, size;
+  Uint32 lpad, rpad, tpad, bpad, linepad;
+  Uint8 *lbuf=NULL, *rbuf=NULL, *linebuf=NULL, *pbuf;
   double pval;
-  Uint8 *maxbuf, *pbuf;
+  Uint8 *maxbuf, *obuf, *ibuf=buffer;
 
   if (id->rescaled) {
     pval = id->rescaled_min;
@@ -1140,23 +1142,110 @@ Uint8 *MdcGetResizedImage(FILEINFO *fi,Uint8 *buffer,int type,Uint32 img)
   maxbuf = MdcGetImgBuffer(size);
   if (maxbuf == NULL) return NULL;
 
-  pbuf = maxbuf;
+  obuf = maxbuf;
 
-  for (d=0; d < id->height; buffer+=linesize, d++) {
-     memcpy(pbuf,buffer,linesize); 
-     pbuf += linesize;
-     /* fill line ? */
-     for (w=id->width; w < fi->mwidth; w++) {
-        MdcPutDoublePixel(pbuf,pval,type);
-        pbuf += bytes;
+  /* calculate padding (left, right, top, bottom) */
+  linepad = fi->mwidth;
+
+  switch (MDC_PADDING_MODE) {
+
+    case MDC_PAD_AROUND:
+        lpad = (fi->mwidth - id->width) / 2;
+        rpad = (fi->mwidth - id->width + 1) / 2;   /* +1 for int rounding */
+        tpad = (fi->mheight - id->height) / 2;
+        bpad = (fi->mheight - id->height + 1) / 2; /* +1 for int rounding */
+        break;
+    case MDC_PAD_BOTTOM_RIGHT:
+        lpad = 0;
+        rpad = fi->mwidth - id->width;
+        tpad = 0;
+        bpad = fi->mheight - id->height;
+        break;
+    case MDC_PAD_TOP_LEFT:
+        lpad = fi->mwidth - id->width;
+        rpad = 0;
+        tpad = fi->mheight - id->height;
+        bpad = 0;
+        break;
+    default: /* MDC_PAD_BOTTOM_RIGHT: */
+        lpad = 0;
+        rpad = fi->mwidth - id->width;
+        tpad = 0;
+        bpad = fi->mheight - id->height;
+  }
+
+  /* malloc & fill left, right and full line buffers */
+  if (lpad > 0) {
+    lbuf = malloc(bytes * lpad);
+    if (lbuf == NULL) {
+      MdcFree(maxbuf);
+      return(NULL);
+    }
+     
+    pbuf = lbuf;
+    for (p = 0; p < lpad; p++) {
+       MdcPutDoublePixel(pbuf,pval,type);
+       pbuf += bytes;
+    }
+  }
+  if (rpad > 0) {
+    rbuf = malloc(bytes * rpad);
+    if (rbuf == NULL) {
+      MdcFree(maxbuf); MdcFree(lbuf);
+      return(NULL); 
+    }
+     
+    pbuf = rbuf;
+    for (p = 0; p < rpad; p++) {
+       MdcPutDoublePixel(pbuf,pval,type);
+       pbuf += bytes;
+    }
+  }
+
+  if ((tpad > 0) || (bpad > 0)) { 
+    linebuf = malloc(bytes * linepad);
+    if (linebuf == NULL) {
+      MdcFree(maxbuf); MdcFree(lbuf); MdcFree(rbuf);
+      return(NULL);
+    }
+
+    pbuf = linebuf;
+    for (p = 0; p < linepad; p++) {
+       MdcPutDoublePixel(pbuf,pval,type);
+       pbuf += bytes;
+    }
+  }
+
+
+  for (h=0; h < fi->mheight; h++) {
+     if ( (h < tpad) || h >= (fi->mheight - bpad) ) {
+       /* pad a full line at top or bottom */
+       memcpy(obuf,linebuf,linepad*bytes);
+       obuf += linepad*bytes;
+     }else{
+       /* copy an image line */
+       if (lpad > 0) {
+         /* first pad line left */
+         memcpy(obuf,lbuf,lpad*bytes);
+         obuf += lpad*bytes;
+       }
+
+       /* now copy line */
+       memcpy(obuf,ibuf,linesize);
+       obuf += linesize;
+       ibuf += linesize;
+
+       if (rpad > 0) {
+         /* then pad line right */
+         memcpy(obuf,rbuf,rpad*bytes);
+         obuf += rpad*bytes;
+       }
      }
   }
 
-  for (d=id->height; d < fi->mheight; d++) 
-     for (w=0; w < fi->mwidth; w++) { /* add lines */
-        MdcPutDoublePixel(pbuf,pval,type);
-        pbuf += bytes;
-  }
+  MdcFree(lbuf);
+  MdcFree(rbuf);
+  MdcFree(linebuf);
 
   return(maxbuf);
 
