@@ -8,11 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-color.h,v 1.1.1.1 2000/10/28 16:52:06 enlf Exp $
+/* $Id: m-color.h,v 1.7 2004/01/04 22:36:16 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2000 by Erik Nolf
+   Copyright (C) 1997-2004 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -37,10 +37,12 @@
 ****************************************************************************/
 int  MdcLoadLUT(char *lutname);
 void MdcGrayScale(Uint8 *palette);
+void MdcInvertedScale(Uint8 *palette);
 void MdcRainbowScale(Uint8 *palette);
 void MdcCombinedScale(Uint8 *palette);
 void MdcHotmetalScale(Uint8 *palette);
 void MdcGetColorMap(int map, Uint8 palette[]);
+int MdcSetPresentMap(Uint8 palette[]);
 
 #endif
 
