@@ -23,7 +23,7 @@
  * Credits      :                                                          *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-conc.c,v 1.79 2004/10/16 20:36:34 enlf Exp $
+/* $Id: m-conc.c,v 1.81 2005/01/27 22:43:37 enlf Exp $
  */
 
 /*
@@ -143,7 +143,11 @@ char * MdcConcRebinTypeNames[MDC_CONC_NUM_REBIN_TYPES] = {
 char * MdcConcReconTypeNames[MDC_CONC_NUM_RECON_TYPES] = {
   "Unknown, or no, algorithm type",
   "Filtered Backprojection",
-  "OSEM 2D"
+  "OSEM 2D",
+  "unused",
+  "unused",
+  "unused",
+  "OSEM 3D followed by MAP"
 };
 
 char * MdcConcOSEM2DTypeNames[MDC_CONC_NUM_OSEM2D_TYPES] = {
@@ -297,6 +301,14 @@ char * MdcConcHdrValueNames[MDC_CONC_NUM_HDR_VALUES] = {
   "rebinning_version",
   "recon_algorithm",
   "recon_version",
+  "map_subsets",
+  "map_osem3d_iterations",
+  "map_iterations",
+  "map_beta",
+  "map_blur_type",
+  "map_prior_type",
+  "map_blur_file",
+  "map_pmatrix_file",
   "osem2d_method",
   "osem2d_subsets",
   "osem2d_iterations",
@@ -1148,6 +1160,62 @@ const char *MdcLoadHeaderCONC(FILEINFO *fi)
       if (MDC_INFO) MdcPrntScrn("Reconstruction version:\t\t%f\n",
                                 conc_get_float(line, &return_code));
       break;
+    case MDC_CONC_HDR_MAP_SUBSETS:
+      if (recon_type == MDC_CONC_RECON_OSEM3D_MAP) {
+        temp_int = conc_get_int(line, &return_code);
+        if (MDC_INFO)
+          MdcPrntScrn("OSEM3D Subsets:\t\t\t%d\n", temp_int);
+      }
+      break;
+    case MDC_CONC_HDR_MAP_OSEM3D_ITERATIONS:
+      if (recon_type == MDC_CONC_RECON_OSEM3D_MAP) {
+        temp_int = conc_get_int(line, &return_code);
+        if (MDC_INFO)
+          MdcPrntScrn("OSEM3D Iterations:\t\t%d\n", temp_int);
+      }
+      break;
+    case MDC_CONC_HDR_MAP_ITERATIONS:
+      if (recon_type == MDC_CONC_RECON_OSEM3D_MAP) {
+        temp_int = conc_get_int(line, &return_code);
+        if (MDC_INFO)
+          MdcPrntScrn("MAP Iterations:\t\t\t%d\n", temp_int);
+      }
+      break;
+    case MDC_CONC_HDR_MAP_BETA:
+      if (recon_type == MDC_CONC_RECON_OSEM3D_MAP) {
+        temp_float = conc_get_float(line, &return_code);
+        if (MDC_INFO)
+          MdcPrntScrn("MAP Beta:\t\t\t%5.3f\n", temp_float);
+      }
+      break;
+    case MDC_CONC_HDR_MAP_BLUR_TYPE:
+      if (recon_type == MDC_CONC_RECON_OSEM3D_MAP) {
+        temp_int = conc_get_int(line, &return_code);
+        if (MDC_INFO)
+          MdcPrntScrn("MAP Blur Type:\t\t\t%d\n", temp_int);
+      }
+      break;
+    case MDC_CONC_HDR_MAP_PRIOR_TYPE:
+      if (recon_type == MDC_CONC_RECON_OSEM3D_MAP) {
+        temp_int = conc_get_int(line, &return_code);
+        if (MDC_INFO)
+          MdcPrntScrn("MAP Prior Type:\t\t\t%d\n", temp_int);
+      }
+      break;
+    case MDC_CONC_HDR_MAP_BLUR_FILE:
+      if (recon_type == MDC_CONC_RECON_OSEM3D_MAP) {
+	temp_string = conc_get_string(line, &return_code);
+	if (MDC_INFO) MdcPrntScrn("MAP Blur File:\t\t\t%s\n",temp_string);
+	MdcFree(temp_string);
+      }
+      break;
+    case MDC_CONC_HDR_MAP_PMATRIX_FILE:
+      if (recon_type == MDC_CONC_RECON_OSEM3D_MAP) {
+	temp_string = conc_get_string(line, &return_code);
+	if (MDC_INFO) MdcPrntScrn("MAP PMatrix File:\t\t%s\n",temp_string);
+	MdcFree(temp_string);
+      }
+      break;
     case MDC_CONC_HDR_OSEM2D_METHOD:
       if (recon_type == MDC_CONC_RECON_OSEM2D) {
         MdcConcOSEM2DTypes osem_type;
@@ -2056,10 +2124,10 @@ const char *MdcSaveHeaderCONC(FILEINFO *fi)
   fprintf(fi->ofp, "#\n%s %e\n"
                 , MdcConcHdrValueNames[MDC_CONC_HDR_ISOTOPE_HALF_LIFE]
                 , fi->isotope_halflife);
-  fprintf(fi->ofp, "#  Note: isotope branching fraction is included in the calibration fraction\n%s %f\n" 
+  fprintf(fi->ofp, "#  Note: isotope branching fraction is included in the calibration fraction\n%s %g\n" 
                 , MdcConcHdrValueNames[MDC_CONC_HDR_ISOTOPE_BRANCHING_FRACTION]
                 , 1.0);
-  fprintf(fi->ofp, "#\n%s %f\n"
+  fprintf(fi->ofp, "#\n%s %g\n"
                 , MdcConcHdrValueNames[MDC_CONC_HDR_AXIAL_CRYSTAL_PITCH]
                 , 2.0*fi->pixdim[3]/10.0);
 
@@ -2129,12 +2197,12 @@ const char *MdcSaveHeaderCONC(FILEINFO *fi)
   fprintf(fi->ofp, "#\n%s %d\n"
 	        , MdcConcHdrValueNames[MDC_CONC_HDR_DECAY_CORRECTION_APPLIED]
                 , fi->decay_corrected);
-  fprintf(fi->ofp, "#\n%s %f\n", MdcConcHdrValueNames[MDC_CONC_HDR_PIXEL_SIZE]
+  fprintf(fi->ofp, "#\n%s %g\n", MdcConcHdrValueNames[MDC_CONC_HDR_PIXEL_SIZE]
                 , fi->pixdim[1]/10.0);
   /* eNlf: don't use, scales always combined internally
   calibration_factor = fi->image[0].calibr_fctr; */
   calibration_factor = 1.0;
-  fprintf(fi->ofp, "#\n%s %f\n"
+  fprintf(fi->ofp, "#\n%s %g\n"
                 , MdcConcHdrValueNames[MDC_CONC_HDR_CALIBRATION_FACTOR]
                 , calibration_factor);
                                                                                 
@@ -2158,10 +2226,10 @@ const char *MdcSaveHeaderCONC(FILEINFO *fi)
   fprintf(fi->ofp, "#\n%s %d\n"
                 , MdcConcHdrValueNames[MDC_CONC_HDR_DOSE_UNITS]
                 , MDC_CONC_DOSE_UNITS_MEGA_BEQUERELS);
-  fprintf(fi->ofp, "#\n%s %f\n"
+  fprintf(fi->ofp, "#\n%s %g\n"
                 ,  MdcConcHdrValueNames[MDC_CONC_HDR_INJECTED_DOSE]
                 ,  fi->injected_dose);
-  fprintf(fi->ofp, "#\n%s %f\n"
+  fprintf(fi->ofp, "#\n%s %g\n"
                 ,  MdcConcHdrValueNames[MDC_CONC_HDR_INJECTION_DECAY_CORRECTION]
                 ,  1.0);
 
@@ -2170,7 +2238,7 @@ const char *MdcSaveHeaderCONC(FILEINFO *fi)
 	        ,  fi->gatednr);
   for (i_gate=0; i_gate < fi->gatednr; i_gate++) {
     gd = &(fi->gdata[i_gate]);
-    fprintf(fi->ofp, "#\n%s %d %1.0f %f %f\n"
+    fprintf(fi->ofp, "#\n%s %d %1.0f %g %g\n"
 	           ,  MdcConcHdrValueNames[MDC_CONC_HDR_GATE_BINS]
 	           ,  i_gate
 	           ,  gd->nr_projections
@@ -2181,7 +2249,7 @@ const char *MdcSaveHeaderCONC(FILEINFO *fi)
   fprintf(fi->ofp, "#\n%s %d\n"
                 , MdcConcHdrValueNames[MDC_CONC_HDR_SUBJECT_WEIGHT_UNITS]
                 , MDC_CONC_WEIGHT_UNITS_KILOGRAMS);
-  fprintf(fi->ofp, "#\n%s %f\n"
+  fprintf(fi->ofp, "#\n%s %g\n"
                 ,  MdcConcHdrValueNames[MDC_CONC_HDR_SUBJECT_WEIGHT]
                 ,  fi->patient_weight);
 
@@ -2219,10 +2287,10 @@ const char *MdcSaveHeaderCONC(FILEINFO *fi)
         fprintf(fi->ofp, "#\n%s %d\n"
                       , MdcConcBlockValueNames[MDC_CONC_BLOCK_BED], i_bed);
 	if (bd != NULL) {
-	  fprintf(fi->ofp, "#\n%s %f\n"
+	  fprintf(fi->ofp, "#\n%s %g\n"
 		         , MdcConcBlockValueNames[MDC_CONC_BLOCK_BED_OFFSET]
 		         , bd->hoffset/10.);
-	  fprintf(fi->ofp, "#\n%s %f\n"
+	  fprintf(fi->ofp, "#\n%s %g\n"
 		         , MdcConcBlockValueNames[MDC_CONC_BLOCK_VERTICAL_BED_OFFSET]
    		         , bd->voffset/10.);
 	}
@@ -2231,10 +2299,10 @@ const char *MdcSaveHeaderCONC(FILEINFO *fi)
         fprintf(fi->ofp, "%s %d %d\n"
                       , MdcConcBlockValueNames[MDC_CONC_BLOCK_DATA_FILE_POINTER]
                       , high_file_pointer, low_file_pointer);
-        fprintf(fi->ofp, "#\n%s %f\n"
+        fprintf(fi->ofp, "#\n%s %g\n"
                       , MdcConcBlockValueNames[MDC_CONC_BLOCK_FRAME_START]
                       , fstart);
-        fprintf(fi->ofp, "#\n%s %f\n"
+        fprintf(fi->ofp, "#\n%s %g\n"
                       , MdcConcBlockValueNames[MDC_CONC_BLOCK_FRAME_DURATION]
                       , fduration);
 
@@ -2252,20 +2320,20 @@ const char *MdcSaveHeaderCONC(FILEINFO *fi)
         }
         
         if (first_plane->rescaled) {
-          fprintf(fi->ofp, "#\n%s %f\n"
+          fprintf(fi->ofp, "#\n%s %g\n"
                         , MdcConcBlockValueNames[MDC_CONC_BLOCK_SCALE_FACTOR]
                         ,  first_plane->rescaled_fctr);
         } else {
           /* eNlf: must use combined scale factor 
-          fprintf(fi->ofp, "#\n%s %f\n"
+          fprintf(fi->ofp, "#\n%s %g\n"
                         , MdcConcBlockValueNames[MDC_CONC_BLOCK_SCALE_FACTOR]
                         , first_plane->quant_scale); */
-          fprintf(fi->ofp, "#\n%s %f\n"
+          fprintf(fi->ofp, "#\n%s %g\n"
                         , MdcConcBlockValueNames[MDC_CONC_BLOCK_SCALE_FACTOR]
                         , first_plane->rescale_slope);
         }
 	/* Concorde's ASIPro program requires the dead time correction entry on gated data.... */
-	fprintf(fi->ofp, "#\n# Not 1.0, Unknown\n%s %f\n"
+	fprintf(fi->ofp, "#\n# Not 1.0, Unknown\n%s %g\n"
 		      , MdcConcBlockValueNames[MDC_CONC_BLOCK_DEADTIME_CORRECTION]
 		      , 1.0);
 	/* Concorde's ASIPro program requires the decay correction entry on gated data.... */
@@ -2275,7 +2343,7 @@ const char *MdcSaveHeaderCONC(FILEINFO *fi)
           if (fi->isotope_halflife > 0.) {
             num_half_lifes = (fstart+fduration/2.0)/fi->isotope_halflife;
           }
-          fprintf(fi->ofp, "#\n# Check decay_correction_applied to know if already applied\n%s %f\n"
+          fprintf(fi->ofp, "#\n# Check decay_correction_applied to know if already applied\n%s %g\n"
                    , MdcConcBlockValueNames[MDC_CONC_BLOCK_DECAY_CORRECTION]
                    , pow(0.5,(double)num_half_lifes));
         }
