@@ -10,7 +10,7 @@
  * Author       : Andy Loening                                             *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-conc.h,v 1.19 2004/05/07 22:28:47 enlf Exp $
+/* $Id: m-conc.h,v 1.20 2005/01/27 22:43:37 enlf Exp $
  */
 
 /*
@@ -113,7 +113,11 @@ typedef enum {
 typedef enum {
   MDC_CONC_RECON_UNKNOWN,     /* Unknown, or no, algorithm type */
   MDC_CONC_RECON_FBP,         /* Filtered Backprojection */
-  MDC_CONC_RECON_OSEM2D,      /* OSEM2d */
+  MDC_CONC_RECON_OSEM2D,      /* OSEM2D */
+  MDC_CONC_RECON_UNUSED3,     /* unused */
+  MDC_CONC_RECON_UNUSED4,     /* unused */
+  MDC_CONC_RECON_UNUSED5,     /* unused */
+  MDC_CONC_RECON_OSEM3D_MAP,  /* OSEM3D followed by MAP */
   MDC_CONC_NUM_RECON_TYPES
 } MdcConcReconTypes;
 
@@ -456,12 +460,40 @@ typedef enum {
   /* Reconstruction type (integer) */
   /*   0 - Unknown, or no, algorithm type */
   /*   1 - Filtered Backprojection */
-  /*   2 - OSEM2d */
+  /*   2 - OSEM2D */
+  /*   3 - unused */
+  /*   4 - unused */
+  /*   5 - unused */
+  /*   6 - OSEM3D followed by MAP */
   MDC_CONC_HDR_RECON_ALGORITHM,
 
   /* Version of reconstruction program used (float) */
   MDC_CONC_HDR_RECON_VERSION,
 
+  /* Number of osem3d subsets in MAP reconstruction (integer) */
+  MDC_CONC_HDR_MAP_SUBSETS,
+
+  /* Number of osem3d iterations in MAP reconstruction (integer) */
+  MDC_CONC_HDR_MAP_OSEM3D_ITERATIONS,
+
+  /* Number of MAP iterations after osem3d iterations (integer) */
+  MDC_CONC_HDR_MAP_ITERATIONS,
+
+  /* Beta value for MAP reconstruction (float) */
+  MDC_CONC_HDR_MAP_BETA,
+
+  /* MAP blur kernel type (int) */
+  MDC_CONC_HDR_MAP_BLUR_TYPE,
+
+  /* MAP prior type (int) */
+  MDC_CONC_HDR_MAP_PRIOR_TYPE,
+
+  /* MAP blur kernel file prefix (string) */
+  MDC_CONC_HDR_MAP_BLUR_FILE,
+
+  /* MAP P matrix file prefix (string) */
+  MDC_CONC_HDR_MAP_PMATRIX_FILE,
+
   /* OSEM2D method (integer) */
   /* 0 - Unweighted osem2d reconstruction */
   /* 1 - Attenuation weighted osem2d reconstruction */
