@@ -11,7 +11,7 @@
  *                MdcDebugPrint()    - Print MDC_MY_DEBUG info             *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-debug.c,v 1.50 2004/04/21 22:50:29 enlf Exp $
+/* $Id: m-debug.c,v 1.55 2004/10/17 21:52:13 enlf Exp $
  */
 
 /*
@@ -84,6 +84,8 @@ void MdcPrintFI(FILEINFO *fi)
                                                 ,FrmtString[fi->iformat]);
   MdcPrntScrn("oformat            : %d (= %s)\n",fi->oformat
                                                 ,FrmtString[fi->oformat]);
+  MdcPrntScrn("modality           : %d (= %s)\n",fi->modality
+                                            ,MdcGetStrModality(fi->modality));
   v = (int)fi->rawconv;
   MdcPrntScrn("rawconv            : %d (= %s)\n",v,MdcGetStrRawConv(v));
   v = (int)fi->endian;
@@ -138,12 +140,15 @@ void MdcPrintFI(FILEINFO *fi)
   MdcPrntScrn("patient_weight     : %.2f [kg]\n",fi->patient_weight);
   MdcPrntScrn("study_descr        : %s\n",fi->study_descr);
   MdcPrntScrn("study_id           : %s\n",fi->study_id);
-  MdcPrntScrn("study_date_day     : %d\n",fi->study_date_day);
-  MdcPrntScrn("study_date_month   : %d\n",fi->study_date_month);
-  MdcPrntScrn("study_date_year    : %d\n",fi->study_date_year);
-  MdcPrntScrn("study_time_hour    : %d\n",fi->study_time_hour);
-  MdcPrntScrn("study_time_minute  : %d\n",fi->study_time_minute);
-  MdcPrntScrn("study_time_second  : %d\n",fi->study_time_second);
+  MdcPrntScrn("study_date_year    : %02d\n",fi->study_date_year);
+  MdcPrntScrn("study_date_month   : %02d\n",fi->study_date_month);
+  MdcPrntScrn("study_date_day     : %02d\n",fi->study_date_day);
+  MdcPrntScrn("study_time_hour    : %02d\n",fi->study_time_hour);
+  MdcPrntScrn("study_time_minute  : %02d\n",fi->study_time_minute);
+  MdcPrntScrn("study_time_second  : %02d\n",fi->study_time_second);
+  MdcPrntScrn("dose_time_hour     : %02d\n",fi->dose_time_hour);
+  MdcPrntScrn("dose_time_minute   : %02d\n",fi->dose_time_minute);
+  MdcPrntScrn("dose_time_second   : %02d\n",fi->dose_time_second);
   MdcPrntScrn("nr_series          : %-5hd ",fi->nr_series);
   if (fi->nr_series < 0) MdcPrintYesNo(MDC_NO);
   else MdcPrintYesNo(MDC_YES);
@@ -171,7 +176,9 @@ void MdcPrintFI(FILEINFO *fi)
   MdcPrntScrn("filter_type        : %s\n",fi->filter_type);
   MdcPrntScrn("organ_code         : %s\n",fi->organ_code);
   MdcPrntScrn("isotope_code       : %s\n",fi->isotope_code);
-  MdcPrntScrn("isotope_halflife   : %+e [sec]\n",fi->isotope_halflife);
+  MdcPrntScrn("isotope_halflife   : %+e [sec] or %g [hrs]\n"
+                                         ,fi->isotope_halflife
+                                         ,fi->isotope_halflife/3600.);
   MdcPrntScrn("injected_dose      : %+e [MBq]\n",fi->injected_dose);
   MdcPrntScrn("gantry_tilt        : %+e [degrees]\n",fi->gantry_tilt);
   v = (int) fi->map;
@@ -333,7 +340,6 @@ void MdcPrintFI(FILEINFO *fi)
      MdcPrntScrn("pixel_ysize        : %+e [mm]\n",id->pixel_ysize);
      MdcPrntScrn("slice_width        : %+e [mm]\n",id->slice_width);
      MdcPrntScrn("recon_scale        : %+e\n",id->recon_scale);
-     MdcPrntScrn("image_mod          : %s\n",id->image_mod);
      for (j=0; j<3; j++) MdcPrntScrn("image_pos_dev[%u]   : %+e [mm]\n",j
                                                       ,id->image_pos_dev[j]);
      for (j=0; j<3; j++) MdcPrntScrn("image_pos_pat[%u]   : %+e [mm]\n",j
