@@ -8,7 +8,7 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-defs.h,v 1.45 2004/09/23 22:24:12 enlf Exp $
+/* $Id: m-defs.h,v 1.46 2005/02/01 23:23:41 enlf Exp $
  */
 
 /*
@@ -236,6 +236,11 @@
 #define MDC_HEART_RATE_ACQUIRED  1
 #define MDC_HEART_RATE_OBSERVED  2
 
+/* image padding */
+#define MDC_PAD_AROUND        1
+#define MDC_PAD_TOP_LEFT      2
+#define MDC_PAD_BOTTOM_RIGHT  3
+
 /* some maximum limits */
 #define MDC_MAX_FILES 10000 /* maximum files handled        */
                             /* 3-char prefix: 34696 uniques */
