@@ -18,7 +18,7 @@
  *                - Mosaic support     - Roland Marcus Rutschmann          *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-dicm.c,v 1.151 2004/05/09 22:48:03 enlf Exp $
+/* $Id: m-dicm.c,v 1.165 2004/10/31 23:16:07 enlf Exp $
  */
 
 /*
@@ -71,6 +71,8 @@
 #define ICOL 1
 
 /* extra stuff for reading DICOM */
+static void MdcDicomFixType(IMG_DATA *id, Uint32 nr, double wc, double ww
+, double rs, double ri);
 static char *MdcDicomContrast(IMG_DATA *id, Uint32 nr, double wc, double ww
 , double rs, double ri);
 static void MdcDicomInvert(IMG_DATA *id);
@@ -78,6 +80,7 @@ static char *MdcDicomHandleImages(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom
 , IMAGE *image, Uint32 number);
 static char *MdcHandleMosaic(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom
 , IMAGE *image);
+static void MdcPrintDicomInfoDB(FILEINFO *fi);
 
 /* extra stuff for writing DICOM */
 static Uint32 MdcDicomMakeUID(FILEINFO *fi, Int8 uid, char str[]);
@@ -147,6 +150,38 @@ int MdcCheckDICM(FILEINFO *fi)
    return(MDC_FRMT_DICM);
 }
 
+static void MdcDicomFixType(IMG_DATA *id, Uint32 nr, double wc, double ww, double rs, double ri)
+{
+  Int16 newtype = id->type;
+
+  /* rescale window center/width towards pixel values */
+  wc = (wc - ri) / rs;
+  ww = (ww / rs);
+
+  /* auto correct bad unsigned types <=> negative contrast window */
+  if ((wc - 0.5 - ((ww - 1.) / 2.)) < 0.) {
+    switch (id->type) {
+      case  BIT8_U: newtype =  BIT8_S;
+          break;
+      case BIT16_U: newtype = BIT16_S;
+          break;
+      case BIT32_U: newtype = BIT32_S;
+          break;
+      case BIT64_U: newtype = BIT64_S;
+          break;
+    }
+  }
+
+  /* give warning once */
+  if ((newtype != id->type) && (nr == 0)) {
+    MdcPrntWarn("DICM Fix wrong unsigned pixel type");
+  }
+
+  /* fix pixel type */
+  id->type = newtype;
+
+}
+
 /* see also DICOM standards: PS 3.3 - 2001 Page 505 */
 char *MdcDicomContrast(IMG_DATA *id, Uint32 nr, double wc, double ww, double rs, double ri) 
 {
@@ -160,29 +195,6 @@ char *MdcDicomContrast(IMG_DATA *id, Uint32 nr, double wc, double ww, double rs,
    wc = (wc - ri) / rs;
    ww = (ww / rs);
 
-#if MDC_DICM_FIX_TYPE
-   /* auto correct bad unsigned types <=> negative contrast window */
-   if ((wc - (ww / 2.)) < 0.) {
-     switch (id->type) {
-       case  BIT8_U: type =  BIT8_S;
-           break;
-       case BIT16_U: type = BIT16_S;
-           break;
-       case BIT32_U: type = BIT32_S;
-           break;
-       case BIT64_U: type = BIT64_S;
-           break;
-       default     : type = id->type;
-     }
-   }
-
-   /* give warning only once */
-   if ((type != id->type) && (nr == 0)) {
-     MdcPrntWarn("DICM Fix wrong unsigned pixel type");
-   }
-
-#endif
-
    /* prepare range values: [0 -> +max] */
    ymin = 0.; 
    ymax = 255.;
@@ -245,43 +257,34 @@ char *MdcDicomHandleImages(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom, IMAGE *image,
   IMG_DATA *id;
   Uint32 img=0, i, f, bytes, t;
   Uint8 *pdata = NULL;
-  double rescale_slope=1., rescale_intercept=0.;
-  double window_center=0., window_width=0.;
-  float quantify_slope=1., quantify_intercept=0.;
+  double rs, ri;
+  double wc, ww;
   char *msg=NULL;
 
   /* handle window center/width */
   if (MDC_FORCE_CONTRAST == MDC_YES) {
     /* apply user specified values */
-    window_center = (double)mdc_cw_center;
-    window_width  = (double)mdc_cw_width;
+    wc = (double)mdc_cw_center;
+    ww = (double)mdc_cw_width;
   }else{
     /* apply file specified values */
-    window_center = (double)dicom->cw_center;
-    window_width  = (double)dicom->cw_width;
+    wc = (double)dicom->cw_center;
+    ww = (double)dicom->cw_width;
   }
 
   /* handle rescale slope and intercept */
   if (MDC_FORCE_RESCALE == MDC_YES) {
-    /* overide with user specified values */
-    dicom->si_slope     = mdc_si_slope;
-    dicom->si_intercept = mdc_si_intercept;
+    /* apply user specified values */
+    rs = (double)mdc_si_slope;
+    ri = (double)mdc_si_intercept;
+  }else{
+    /* apply file specified values */
+    rs = (double)dicom->si_slope;
+    ri = (double)dicom->si_intercept; 
   }
 
-  if ((window_center != 0.) && (window_width != 0.0)) {
-    /* slope/intercept used for contrast remap */
-    if (MDC_DICOM_CONTRAST == MDC_YES) {
-      rescale_slope     = dicom->si_slope;
-      rescale_intercept = dicom->si_intercept;
-    }else{
-    /* slope/intercept unused */
-      rescale_slope = 1.; rescale_intercept = 0.;
-    }
-  }else{
-    /* slope/intercept used for quantitation */
-    quantify_slope     = dicom->si_slope;
-    quantify_intercept = dicom->si_intercept;
-  }
+  /* prevent division by zero */
+  if (rs == 0.) rs = 1.;
 
   for (img=0, i=0; i<number; i++) {
      pimg = &image[i];
@@ -297,12 +300,10 @@ char *MdcDicomHandleImages(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom, IMAGE *image,
         id->bits   = MdcType2Bits(id->type);
 
         if (id->type != COLRGB) {
-          id->quant_scale = quantify_slope;
-          id->intercept   = quantify_intercept;
+          id->quant_scale = (float)rs;
+          id->intercept   = (float)ri;
         }
 
-        strcpy(id->image_mod,MdcGetStrModality((signed)dicom->modality));
-
         bytes = id->width*id->height*MdcType2Bytes(id->type);
         id->buf = MdcGetImgBuffer(bytes);
         if (id->buf == NULL) return("DICM Couldn't allocate image buffer");
@@ -362,13 +363,15 @@ char *MdcDicomHandleImages(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom, IMAGE *image,
           }
         } 
 
-        /* contrast remapping */
         if (id->type != COLRGB) {
-          if ((MDC_DICOM_CONTRAST == MDC_YES) && (window_width != 0.0)) {
-            msg = MdcDicomContrast(id,img,window_center
-                                         ,window_width
-                                         ,rescale_slope
-                                         ,rescale_intercept);
+
+#if MDC_DICM_FIX_TYPE
+          /* fix pixel type */
+          MdcDicomFixType(id,img,wc,ww,rs,ri);
+#endif
+          /* contrast remapping */
+          if ((MDC_DICOM_CONTRAST == MDC_YES) && (ww != 0.0)) {
+            msg = MdcDicomContrast(id,img,wc,ww,rs,ri);
             if (msg != NULL) {
               MdcPrntWarn(msg);
             }
@@ -523,6 +526,20 @@ char *MdcHandleMosaic(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom, IMAGE *image)
   return(NULL);
 }
 
+static void MdcPrintDicomInfoDB(FILEINFO *fi)
+{
+  /* make string */
+  sprintf(mdcbufr,"%s+%04d%02d%02d+%02d%02d%02d",fi->patient_name
+                                                ,fi->study_date_year
+                                                ,fi->study_date_month
+                                                ,fi->study_date_day
+                                                ,fi->study_time_hour
+                                                ,fi->study_time_minute
+                                                ,fi->study_time_second);
+  /* print string */
+  MdcPrntScrn("%s\n",mdcbufr);
+
+}
 
 const char *MdcReadDICM(FILEINFO *fi)
 {
@@ -538,23 +555,34 @@ const char *MdcReadDICM(FILEINFO *fi)
   /* init dicom struct */
   MdcDicomInitStuff(dicom);
 
+  /* init  MOD structs */
+  MdcGetStructMOD(fi);
+
   if (MDC_PROGRESS) MdcProgress(MDC_PROGRESS_BEGIN,0.,"Reading DICOM:");
 
   if (MDC_VERBOSE) MdcPrntMesg("DICM Reading <%s> ...",fi->ifname);
 
-  if (MDC_ECHO_ALIAS == MDC_YES) {
+  if ((MDC_ECHO_ALIAS == MDC_YES) || (MDC_INFO_DB == MDC_YES)) {
     /* get one struct to fill */
     MdcGetStructID(fi,1);
     /* retrieve info from file */
     mdc_dicom_getinfo(fi);
-    /* echo alias and leave */
-    MdcEchoAliasName(fi); return(NULL);
+    /* echo alias */
+    if (MDC_ECHO_ALIAS == MDC_YES) MdcEchoAliasName(fi);
+    /* print db info */
+    if (MDC_INFO_DB == MDC_YES) MdcPrintDicomInfoDB(fi);
+    /* leave */
+    return(NULL);
   }
 
   MdcMergePath(fi->ipath,fi->idir,fi->ifname);
 
   /* first pass: limit log level to errors */
-  dicom_log_level = ERROR;
+  if (MDC_BLOCK_MESSAGES == MDC_LEVEL_ALL) {
+    dicom_log_level = EMERGENCY; 
+  }else{
+    dicom_log_level = ERROR;
+  }
 
   /* reading file 1st time for info printout */
   if (MDC_INFO) {
@@ -567,7 +595,7 @@ const char *MdcReadDICM(FILEINFO *fi)
   if (MDC_PROGRESS) MdcProgress(MDC_PROGRESS_INCR,0.1,NULL);
 
   /* second pass: allow warnings */
-  dicom_log_level = NOTICE;
+  if (MDC_BLOCK_MESSAGES == MDC_NO) dicom_log_level = NOTICE;
 
   /* reading file 2nd time for images */
   if (mdc_dicom_read(fi,&image,(Int32 *)&nrimages)) {
@@ -598,7 +626,7 @@ const char *MdcReadDICM(FILEINFO *fi)
   }
 
   /* third pass: limit log level back to errors */
-  dicom_log_level = ERROR;
+  if (MDC_BLOCK_MESSAGES == MDC_NO) dicom_log_level = ERROR;
 
   /* reading file 3rd time for info retrieving (through Acr/Nema reader) */
   if (MDC_INFO) {
@@ -606,7 +634,7 @@ const char *MdcReadDICM(FILEINFO *fi)
     MdcPrintLine('*',MDC_HALF_LENGTH);
     MdcPrntScrn("Pass #2: through Acr/Nema reader\n");
     MdcPrintLine('*',MDC_HALF_LENGTH);
-  } 
+  }
 
   MdcMergePath(fi->ipath,fi->idir,fi->ifname);
   mdc_dicom_getinfo(fi); 
@@ -731,7 +759,7 @@ Uint32 MdcDicomMakeUID(FILEINFO *fi, Int8 uid, char str[])
 
   switch (uid) {
     case MDC_TYPE_UID_CREATOR:
-        sprintf(str,"%s.0.0",MDC_STR_UID_CREATOR);
+        sprintf(str,"%s",MDC_STR_UID_CREATOR);
         break;
     case MDC_TYPE_UID_SOP_INSTANCE:
         series = mdc_incrinstance;
@@ -830,10 +858,6 @@ char *MdcDicomWriteMetaHeader(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
         strcpy(mdcbufr,"1.2.840.10008.5.1.4.1.1.128"); len = strlen(mdcbufr);
         mdc_dicom_write_element(fi->ofp,0x0002,0x0002,len,(Uint8 *)mdcbufr);
         break;
-    case M_NM:
-        strcpy(mdcbufr,"1.2.840.10008.5.1.4.1.1.20"); len = strlen(mdcbufr);
-        mdc_dicom_write_element(fi->ofp,0x0002,0x0002,len,(Uint8 *)mdcbufr);
-        break;
     default  : /* default to NM modality */
         strcpy(mdcbufr,"1.2.840.10008.5.1.4.1.1.20"); len = strlen(mdcbufr);
         mdc_dicom_write_element(fi->ofp,0x0002,0x0002,len,(Uint8 *)mdcbufr);
@@ -965,15 +989,11 @@ char *MdcWriteNMDetectorImageModule(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
 
 char *MdcDicomWriteSetModality(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
 {
-  IMG_DATA *id=&fi->image[0];
-  int modality;
+  /* currently only NM writing supported */
+  switch (fi->modality) {
+    case M_PT:
 
-  modality = MdcGetIntModality(id->image_mod);
-
-  switch (modality) {
-    case M_PT: /* MARK: PT modality not yet enabled */
-    case M_NM:
-    default  : dicom->modality = M_NM; /* default to NM modality */
+    default  : dicom->modality = M_NM;
   }
 
   return(NULL);
@@ -989,7 +1009,6 @@ char *MdcDicomWriteG0008(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
   strcpy(mdcbufr,"DERIVED\\PRIMARY");
   switch (dicom->modality) {
     case M_PT: break;
-    case M_NM:
     default  : /* default to NM modality */
         switch (fi->acquisition_type) {
           case MDC_ACQUISITION_TOMO: 
@@ -1035,10 +1054,6 @@ char *MdcDicomWriteG0008(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
         strcpy(mdcbufr,"1.2.840.10008.5.1.4.1.1.128"); len = strlen(mdcbufr);
         mdc_dicom_write_element(fi->ofp,0x0008,0x0016,len,(Uint8 *)mdcbufr);
         break;
-    case M_NM:
-        strcpy(mdcbufr,"1.2.840.10008.5.1.4.1.1.20"); len = strlen(mdcbufr);
-        mdc_dicom_write_element(fi->ofp,0x0008,0x0016,len,(Uint8 *)mdcbufr);
-        break; 
     default  : /* default to NM modality */
         strcpy(mdcbufr,"1.2.840.10008.5.1.4.1.1.20"); len = strlen(mdcbufr);
         mdc_dicom_write_element(fi->ofp,0x0008,0x0016,len,(Uint8 *)mdcbufr);
@@ -1048,40 +1063,61 @@ char *MdcDicomWriteG0008(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
   mdc_dicom_write_element(fi->ofp,0x0008,0x0018,len,(Uint8 *)mdcbufr);
 
   /* date settings, make sure it is conform */
-  if (fi->study_date_year == 0) {
-    pdata = NULL; bytes=0;
+  if (fi->mod != NULL) {
+    pdata = fi->mod->gn_info.study_date;       len = strlen(pdata);
+    mdc_dicom_write_element(fi->ofp,0x0008,0x0020,len,(Uint8 *)pdata);
+    pdata = fi->mod->gn_info.series_date;      len = strlen(pdata);
+    mdc_dicom_write_element(fi->ofp,0x0008,0x0021,len,(Uint8 *)pdata);
+    pdata = fi->mod->gn_info.acquisition_date; len = strlen(pdata);
+    mdc_dicom_write_element(fi->ofp,0x0008,0x0022,len,(Uint8 *)pdata);
+    pdata = fi->mod->gn_info.image_date;       len = strlen(pdata);
+    mdc_dicom_write_element(fi->ofp,0x0008,0x0023,len,(Uint8 *)pdata);
   }else{
-    sprintf(mdcbufr,"%04d%02d%02d",fi->study_date_year
-                                  ,fi->study_date_month
-                                  ,fi->study_date_day);
-    pdata = mdcbufr; bytes = strlen(mdcbufr);
+    if (fi->study_date_year == 0) {
+      pdata = NULL; bytes=0;
+    }else{
+      sprintf(mdcbufr,"%04d%02d%02d",fi->study_date_year
+                                    ,fi->study_date_month
+                                    ,fi->study_date_day);
+      pdata = mdcbufr; bytes = strlen(mdcbufr);
+    }
+    mdc_dicom_write_element(fi->ofp,0x0008,0x0020,bytes,(Uint8 *)pdata);
+    mdc_dicom_write_element(fi->ofp,0x0008,0x0021,bytes,(Uint8 *)pdata);
+    mdc_dicom_write_element(fi->ofp,0x0008,0x0022,bytes,(Uint8 *)pdata);
+    mdc_dicom_write_element(fi->ofp,0x0008,0x0023,bytes,(Uint8 *)pdata);
   }
-  mdc_dicom_write_element(fi->ofp,0x0008,0x0020,bytes,(Uint8 *)pdata);
-  mdc_dicom_write_element(fi->ofp,0x0008,0x0021,bytes,(Uint8 *)pdata);
-  mdc_dicom_write_element(fi->ofp,0x0008,0x0022,bytes,(Uint8 *)pdata);
-  mdc_dicom_write_element(fi->ofp,0x0008,0x0023,bytes,(Uint8 *)pdata);
-
   /* time settings, can be full of zero's ... */ 
-  sprintf(mdcbufr,"%02d%02d%02d",fi->study_time_hour
-                                ,fi->study_time_minute
-                                ,fi->study_time_second);
-  len = strlen(mdcbufr);
-  mdc_dicom_write_element(fi->ofp,0x0008,0x0030,len,(Uint8 *)mdcbufr);
-  mdc_dicom_write_element(fi->ofp,0x0008,0x0031,len,(Uint8 *)mdcbufr);
-  if (fi->image[0].sdata != NULL) {
-    sprintf(mdcbufr,"%02d%02d%02d",fi->image[0].sdata->start_time_hour
-                                  ,fi->image[0].sdata->start_time_minute
-                                  ,fi->image[0].sdata->start_time_second);
-    len = strlen(mdcbufr);
-    mdc_dicom_write_element(fi->ofp,0x0008,0x0032,len,(Uint8 *)mdcbufr);
+  if (fi->mod != NULL) {
+    pdata = fi->mod->gn_info.study_time;       len = strlen(pdata);
+    mdc_dicom_write_element(fi->ofp,0x0008,0x0030,len,(Uint8 *)pdata);
+    pdata = fi->mod->gn_info.series_time;      len = strlen(pdata);
+    mdc_dicom_write_element(fi->ofp,0x0008,0x0031,len,(Uint8 *)pdata);
+    pdata = fi->mod->gn_info.acquisition_time; len = strlen(pdata);
+    mdc_dicom_write_element(fi->ofp,0x0008,0x0032,len,(Uint8 *)pdata);
+    pdata = fi->mod->gn_info.image_time;       len = strlen(pdata);
+    mdc_dicom_write_element(fi->ofp,0x0008,0x0033,len,(Uint8 *)pdata);
   }else{
-    mdc_dicom_write_element(fi->ofp,0x0008,0x0032,len,(Uint8 *)mdcbufr);
+    sprintf(mdcbufr,"%02d%02d%02d",fi->study_time_hour
+                                  ,fi->study_time_minute
+                                  ,fi->study_time_second);
+    len = strlen(mdcbufr);
+    mdc_dicom_write_element(fi->ofp,0x0008,0x0030,len,(Uint8 *)mdcbufr);
+    mdc_dicom_write_element(fi->ofp,0x0008,0x0031,len,(Uint8 *)mdcbufr);
+    if (fi->image[0].sdata != NULL) {
+      sprintf(mdcbufr,"%02d%02d%02d",fi->image[0].sdata->start_time_hour
+                                    ,fi->image[0].sdata->start_time_minute
+                                    ,fi->image[0].sdata->start_time_second);
+      len = strlen(mdcbufr);
+      mdc_dicom_write_element(fi->ofp,0x0008,0x0032,len,(Uint8 *)mdcbufr);
+    }else{
+      mdc_dicom_write_element(fi->ofp,0x0008,0x0032,len,(Uint8 *)mdcbufr);
+    }
+    sprintf(mdcbufr,"%02d%02d%02d",fi->study_time_hour
+                                  ,fi->study_time_minute
+                                  ,fi->study_time_second);
+    len = strlen(mdcbufr);
+    mdc_dicom_write_element(fi->ofp,0x0008,0x0033,len,(Uint8 *)mdcbufr);
   }
-  sprintf(mdcbufr,"%02d%02d%02d",fi->study_time_hour
-                                ,fi->study_time_minute
-                                ,fi->study_time_second);
-  len = strlen(mdcbufr);
-  mdc_dicom_write_element(fi->ofp,0x0008,0x0033,len,(Uint8 *)mdcbufr);
 
   len = strlen(mdc_dummy1);
   mdc_dicom_write_element(fi->ofp,0x0008,0x0050,len,(Uint8 *)mdc_dummy1);
@@ -1199,7 +1235,6 @@ char *MdcDicomWriteG0018(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
 
   switch (dicom->modality) {
     case M_PT: break;
-    case M_NM:
     default  : /* default to NM modality */
         if ((fi->acquisition_type == MDC_ACQUISITION_UNKNOWN) ||
             (fi->acquisition_type == MDC_ACQUISITION_STATIC)) {
@@ -1309,7 +1344,6 @@ char *MdcDicomWriteG0028(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
         mdc_dicom_write_element(fi->ofp,0x0028,0x0009,bytes,(Uint8 *)pui16);
         MdcFree(pui16);
         break;
-    case M_NM:
     default  : /* default to NM modality */
         switch (fi->acquisition_type) {
           case MDC_ACQUISITION_TOMO:
@@ -1529,8 +1563,11 @@ char *MdcDicomWriteG0054(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
      mdc_dicom_write_element(fi->ofp,0x0018,0x0031,len,(Uint8 *)mdcbufr);
      strcpy(mdcbufr,"0.0"); len = strlen(mdcbufr);
      mdc_dicom_write_element(fi->ofp,0x0018,0x1071,len,(Uint8 *)mdcbufr);
-     /* strcpy(mdcbufr,"000000"); len = strlen(mdcbufr); start time
-     mdc_dicom_write_element(fi->ofp,0x0018,0x1072,len,(Uint8 *)mdcbufr); */
+     sprintf(mdcbufr,"%02d%02d%02d",fi->dose_time_hour
+                                   ,fi->dose_time_minute
+                                   ,fi->dose_time_second);
+     len = strlen(mdcbufr);
+     mdc_dicom_write_element(fi->ofp,0x0018,0x1072,len,(Uint8 *)mdcbufr);
      sprintf(mdcbufr,"%g",fi->injected_dose); len = strlen(mdcbufr);
      mdc_dicom_write_element(fi->ofp,0x0018,0x1074,len,(Uint8 *)mdcbufr);
      sprintf(mdcbufr,"%g",fi->isotope_halflife); len = strlen(mdcbufr);
@@ -2180,6 +2217,9 @@ const char *MdcWriteDICM(FILEINFO *fi)
   /* init dicom struct */
   MdcDicomInitStuff(dicom);
 
+  /* set modality to write */
+  MdcDicomWriteSetModality(fi,dicom);
+
   /* check for requested pixel type */
   if (MDC_FORCE_INT != MDC_NO) dicom->type = MDC_FORCE_INT;
 
@@ -2190,13 +2230,12 @@ const char *MdcWriteDICM(FILEINFO *fi)
   }
 
   /* NM dynamic inappropriate for non-planar */
-  if (fi->acquisition_type == MDC_ACQUISITION_DYNAMIC && fi->planar == MDC_NO) {
+  if (dicom->modality == M_NM &&
+      fi->planar == MDC_NO    &&
+      fi->acquisition_type == MDC_ACQUISITION_DYNAMIC) {
     MdcPrntWarn("DICM Inappropriate for non-planar dynamic studies (NM)");
   }
 
-  /* MARK: set the modality to write */
-  MdcDicomWriteSetModality(fi,dicom);
-
   if (MDC_DICOM_WRITE_NOMETA == MDC_NO) {
     msg = MdcDicomWriteMetaHeader(fi,dicom);
     if (msg != NULL) return(msg);
@@ -2214,7 +2253,6 @@ const char *MdcWriteDICM(FILEINFO *fi)
 
   switch (dicom->modality) {
     case M_PT:
-    case M_NM:
     default  : /* default to NM modality */
         msg = MdcDicomWriteG0054(fi,dicom); if (msg != NULL) return(msg);
   }
