@@ -14,7 +14,7 @@
  *                MdcPrntErr()          - Print error and leave            *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-error.c,v 1.18 2004/01/04 22:36:16 enlf Exp $
+/* $Id: m-error.c,v 1.20 2004/09/04 10:30:33 enlf Exp $
  */
 
 /*
@@ -78,62 +78,65 @@ void MdcPrntScrn(char *fmt, ...)
   va_start(args, fmt);
   vfprintf(MdcPrntStream(), fmt, args);
   va_end(args);
+
 }
 
 void MdcPrntMesg(char *fmt, ...)
 {
   va_list args;
 
-  if (MDC_BLOCK_MESSAGES < MDC_LEVEL_MESG) {
-    va_start(args,fmt);
+  if (MDC_BLOCK_MESSAGES >= MDC_LEVEL_MESG) return;
+
+  va_start(args,fmt);
 
 #if GLIBSUPPORTED
-    g_logv(MDC_PRGR,G_LOG_LEVEL_MESSAGE, fmt, args);
+  g_logv(MDC_PRGR,G_LOG_LEVEL_MESSAGE, fmt, args);
 #else
-    MdcPrntScrn("\n%s: Message: ",MDC_PRGR);
-    vfprintf(MdcPrntStream(), fmt, args); fprintf(MdcPrntStream(),"\n\n");
+  MdcPrntScrn("\n%s: Message: ",MDC_PRGR);
+  vfprintf(MdcPrntStream(), fmt, args); fprintf(MdcPrntStream(),"\n\n");
 #endif
 
-    va_end(args);
-  }
+  va_end(args);
+
 }
 
 void MdcPrntWarn(char *fmt, ...)
 {
   va_list args; 
 
-  if (MDC_BLOCK_MESSAGES < MDC_LEVEL_WARN) {
-    va_start(args, fmt);
+  if (MDC_BLOCK_MESSAGES >= MDC_LEVEL_WARN) return;
+
+  va_start(args, fmt);
 
 #if GLIBSUPPORTED
-    g_logv(MDC_PRGR,G_LOG_LEVEL_WARNING, fmt, args);
+  g_logv(MDC_PRGR,G_LOG_LEVEL_WARNING, fmt, args);
 #else
-    MdcPrntScrn("\n%s: Warning: ",MDC_PRGR);
-    vfprintf(MdcPrntStream(), fmt, args); fprintf(MdcPrntStream(),"\n\n");
+  MdcPrntScrn("\n%s: Warning: ",MDC_PRGR);
+  vfprintf(MdcPrntStream(), fmt, args); fprintf(MdcPrntStream(),"\n\n");
 #endif
 
-    va_end(args);
-  }
+  va_end(args);
+
 }
 
 void MdcPrntErr(int code, char *fmt, ...)
 {
   va_list args;
 
-  if (MDC_BLOCK_MESSAGES < MDC_LEVEL_ERR) {
-    va_start(args, fmt);
+  if (MDC_BLOCK_MESSAGES >= MDC_LEVEL_ERR) exit(-code);
+
+  va_start(args, fmt);
 
 #if GLIBSUPPORTED
-    g_logv(MDC_PRGR,G_LOG_LEVEL_ERROR, fmt, args);
+  g_logv(MDC_PRGR,G_LOG_LEVEL_ERROR, fmt, args);
 #else
-    MdcPrntScrn("\n%s: Error  : ",MDC_PRGR);
-    vfprintf(MdcPrntStream(), fmt, args); fprintf(MdcPrntStream(),"\n\n");
+  MdcPrntScrn("\n%s: Error  : ",MDC_PRGR);
+  vfprintf(MdcPrntStream(), fmt, args); fprintf(MdcPrntStream(),"\n\n");
 #endif
 
-    va_end(args);
-  }
+  va_end(args);
 
-  exit(code);
+  exit(-code);
 
 }
 
