@@ -60,7 +60,7 @@
  *                MdcAddCompressionExt()  - Add  compression extension     *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-fancy.c,v 1.51 2004/01/04 22:36:16 enlf Exp $
+/* $Id: m-fancy.c,v 1.53 2004/10/16 20:36:35 enlf Exp $
  */
 
 /*
@@ -923,11 +923,23 @@ char *MdcGetStrMotion(int motion)
 
 char *MdcGetStrModality(int modint)
 {
-  switch (modint) {
-    case M_PT: return("PT");
-    case M_NM: return("NM");
-    default  : return("NM");
+  char *pmod;
+  Uint16 umod16;
+
+  umod16 = (Uint16)modint;
+
+  pmod = (char *)&umod16;
+
+  if (MdcHostBig()) {
+    mdcbufr[0] = pmod[0];
+    mdcbufr[1] = pmod[1];
+  }else{
+    mdcbufr[0] = pmod[1];
+    mdcbufr[1] = pmod[0];
   }
+  mdcbufr[2]='\0';
+
+  return(mdcbufr);
 }
 
 char *MdcGetStrGSpectNesting(int nesting)
