@@ -29,7 +29,7 @@
  *                MdcNewExt()           - Create filename extension        *
  *                MdcPrefix()           - Create filename prefix           * 
  *                MdcGetPrefixNr()      - Get proper filename prefix       *
- *                MdcGetLastPathSlash() - Get pointer to last path-slash   * 
+ *                MdcGetLastPathDelim() - Get pointer last path delimiter  * 
  *                MdcMySplitPath()      - Split path from filename         *
  *                MdcMyMergePath()      - Merge path to filename           *
  *                MdcNewExt()           - Give filename a new extension    *
@@ -47,7 +47,7 @@
  *                MdcGetHeartRate()     - Get heart rate from gated data   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-files.c,v 1.87 2004/05/09 22:48:03 enlf Exp $ 
+/* $Id: m-files.c,v 1.91 2004/09/25 22:26:55 enlf Exp $ 
  */
 
 /*
@@ -914,7 +914,7 @@ char *MdcGetFname(char path[])
 {
   char *p;
 
-  p = MdcGetLastPathSlash(path);
+  p = MdcGetLastPathDelim(path);
 
   if ( p == NULL ) return(path);
 
@@ -1161,7 +1161,7 @@ void MdcRenameFile(char *name)
   MdcPrntScrn("\tRENAME FILE\n");
   MdcPrintLine('-',MDC_FULL_LENGTH);
 
-  pbegin = MdcGetLastPathSlash(name);    /* get the basename  */
+  pbegin = MdcGetLastPathDelim(name);    /* point to basename */
 
   if (pbegin == NULL) pbegin = name;
   else pbegin = pbegin + 1;
@@ -1181,17 +1181,17 @@ void MdcRenameFile(char *name)
 
 }
 
-char *MdcGetLastPathSlash(char *path)
+/* always check for both path delimiters */
+char *MdcGetLastPathDelim(char *path)
 {
   char *p=NULL;
 
   if (path == NULL) return NULL;
 
-#ifdef MDC_DOS
-  p = (char *)strrchr(path,'\\');
-  if (p != NULL) return(p);
-#endif
   p = (char *)strrchr(path,'/');
+  if (p != NULL) return(p);
+
+  p = (char *)strrchr(path,'\\');
   return(p);
 
 }
@@ -1201,7 +1201,7 @@ void MdcMySplitPath(char path[], char **dir, char **fname)
 {
   char *p=NULL;
 
-  p = MdcGetLastPathSlash(path);       /* last slash becomes '\0'      */
+  p = MdcGetLastPathDelim(path);       /* last path delim becomes '\0'       */
 
   if ( p == NULL ) {
     *fname=&path[0];
@@ -1215,18 +1215,13 @@ void MdcMySplitPath(char path[], char **dir, char **fname)
 }
 
 void MdcMyMergePath(char path[], char *dir, char **fname) 
-                                      /* first '\0' becomes slash again */
+                                      /* first '\0' becomes path delim again */
 {
   char *p;
 
   if ( dir != NULL ) {
     p=(char *)strchr(path,'\0');
-    if ( p != NULL )
-#ifdef MDC_DOS
-      *p='\\';
-#else
-      *p='/';
-#endif
+    if ( p != NULL ) *p=MDC_PATH_DELIM_CHR;
   }
 
   *fname = &path[0];
