@@ -8,7 +8,7 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-files.h,v 1.23 2004/04/30 21:59:36 enlf Exp $
+/* $Id: m-files.h,v 1.24 2004/09/25 22:26:55 enlf Exp $
  */
 
 /*
@@ -66,7 +66,7 @@ int MdcWriteLine(IMG_DATA *id, Uint8 *buf, int type, FILE *fp);
 int MdcWriteDoublePixel(double pix, int type, FILE *fp);
 char *MdcGetFname(char path[]);
 char *MdcGetExtension(char path[]);
-char *MdcGetLastPathSlash(char *path);
+char *MdcGetLastPathDelim(char *path);
 void MdcMySplitPath(char path[], char **dir, char **fname);
 void MdcMyMergePath(char path[], char *dir, char **fname);
 void MdcNewExt(char dest[], char *src, char *ext);
