@@ -14,7 +14,7 @@
  *                MdcHandleArgs()         - Handle the arguments           *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-getopt.c,v 1.121 2004/11/08 23:30:28 enlf Exp $
+/* $Id: m-getopt.c,v 1.122 2005/02/01 23:23:44 enlf Exp $
  */
 
 /*
@@ -170,7 +170,7 @@ Fallback Read Format: [-fb-none|-fb-anlz|-fb-conc|-fb-ecat|fb-dicom]\n\
   MdcPrntScrn("(*unused*)");
 #endif
   MdcPrntScrn("\n\n\
-Slices Transform: [-fh -fv] [-rs -cs -cu] [-sqr | -sqr2] [-crop=<X>:<Y>:<W>:<H>]\n\
+Slices Transform: [-fh -fv] [-rs -cs -cu] [-sqr | -sqr2] [-crop=<X>:<Y>:<W>:<H>]\n\t\t[-pad | -padtl | -padbr]\
 \n  -fh, --flip-horizontal        flip images horizontally (along x-axis)\
 \n  -fv, --flip-vertical          flip images vertically   (along y-axis)\
 \n  -sqr, --make-square           make square images (lagest dimension)\
@@ -180,6 +180,9 @@ Slices Transform: [-fh -fv] [-rs -cs -cu] [-sqr | -sqr2] [-crop=<X>:<Y>:<W>:<H>]
 \n  -rs, --reverse-slices         reverse slices sequence\
 \n  -cs, --cine-sorting           apply cine sorting\
 \n  -cu, --cine-undo              undo  cine sorting\
+\n  -pad, --pad-around            padding symmetrical around image\
+\n  -padtl, --pad-top-left        padding before first row and column\
+\n  -padbr, --pad-bottom-right    padding after last row and column (default)\
 \n");
   MdcPrntScrn("\n\
 Color Remap: [-24 | -8 [-g -dith -mh|-mr|-mi|-mc|-lut <file>]]\n\
@@ -731,6 +734,15 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
      }else if ( (strcasecmp(argv[a],"-sqr2") == 0) ||
                 (strcasecmp(argv[a],"--make-square-two") == 0) ) {
        MDC_MAKE_SQUARE = MDC_TRANSF_SQR2; continue;
+     }else if ( (strcasecmp(argv[a],"-pad") == 0) ||
+                (strcasecmp(argv[a],"--pad-around") == 0) ) {
+       MDC_PADDING_MODE = MDC_PAD_AROUND; continue;
+     }else if ( (strcasecmp(argv[a],"-padtl") == 0) ||
+                (strcasecmp(argv[a],"--pad-top-left") == 0) ) {
+       MDC_PADDING_MODE = MDC_PAD_TOP_LEFT; continue;
+     }else if ( (strcasecmp(argv[a],"-padbr") == 0) ||
+                (strcasecmp(argv[a],"--pad-bottom-right") == 0) ) {
+       MDC_PADDING_MODE = MDC_PAD_BOTTOM_RIGHT; continue;
      }else if ((pset=strstr(argv[a],"-crop=")) != NULL) {
        MDC_CROP_IMAGES = MDC_YES;
        MdcLowStr(pset);
