@@ -8,7 +8,7 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-intf.h,v 1.20 2004/02/12 23:34:43 enlf Exp $
+/* $Id: m-intf.h,v 1.22 2004/10/24 21:47:32 enlf Exp $
  */
 
 /*
@@ -37,7 +37,7 @@
 
 #define MDC_INTF_SIG    "interfile"
 
-#define MDC_INTF_SUPP_VERS   3.3
+#define MDC_INTF_SUPP_VERS   "3.3"
 #define MDC_INTF_SUPP_DATE   "1996:09:24"
 
 #define MDC_INTF_MAXKEYCHARS 256
@@ -76,7 +76,6 @@ typedef struct MdcInterFile_t {
   float procent_cycles_acquired;
   float rescale_slope, rescale_intercept;
   Int8 patient_rot, patient_orient, slice_orient;
-  double version;
 
 } MDC_INTERFILE;
 
@@ -97,6 +96,8 @@ double MdcGetFloatKey(void);
 void MdcGetStrKey(char *str);
 void MdcGetSubStrKey(char *str, int n);
 void MdcGetDateKey(char *str);
+void MdcGetSplitDateKey(Int16 *year, Int16 *month, Int16 *day);
+void MdcGetSplitTimeKey(Int16 *hour, Int16 *minute, Int16 *second);
 int MdcGetDataType(void);
 int MdcGetProcessStatus(void);
 int MdcGetPatRotation(void);
