@@ -16,7 +16,7 @@
  * Notes        : code fragments from 'example.c' included with PNG lib    *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-png.c,v 1.31 2004/05/09 22:48:03 enlf Exp $
+/* $Id: m-png.c,v 1.32 2004/08/30 22:55:34 enlf Exp $
  */
 
 /*
@@ -295,7 +295,7 @@ char *MdcReadPNG(FILEINFO *fi)
 
 char *MdcWritePNG(FILEINFO *fi)
 {
-  char slicenr[6];
+  char suffix[11], *pext;
   png_structp png_ptr;
   png_infop info_ptr;
   png_colorp palette;
@@ -335,13 +335,17 @@ char *MdcWritePNG(FILEINFO *fi)
 
   length = strlen(fi->ofname);
 
+  pext = strrchr(fi->ofname,'.');
+  if (pext == NULL) pext = &fi->ofname[length];
+
   /* split up in separate files   */
   /* PNG is a single image format */ 
   for (n=0; n < fi->number; n++) {
 
      /* add slice number to filename */
      if (fi->number > 1) {
-       sprintf(slicenr,".%.4u",n+1); strcpy(&fi->ofname[length],slicenr);
+       sprintf(suffix,"-%.5u.%.3s",n+1,FrmtExt[MDC_FRMT_PNG]);
+       strcpy(pext,suffix);
      }
  
      if ((MDC_FILE_STDOUT == MDC_YES) && (fi->number == 1)) {
