@@ -17,7 +17,7 @@
  *                the headersize to skip and the pixel data type           *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-raw.c,v 1.34 2004/05/09 22:48:03 enlf Exp $
+/* $Id: m-raw.c,v 1.36 2004/09/25 22:31:01 enlf Exp $
  */
 
 /*
@@ -451,8 +451,9 @@ char *MdcWriteRAW(FILEINFO *fi)
          case MDC_FRMT_ASCII:
            for (pbuf=new_buf, p=0; p < size; p++, pbuf+=bytes) {
               MdcPrintValue(fi->ofp,pbuf,MDC_FORCE_INT); fprintf(fi->ofp," ");
-              /* if ( ((p+1) % id->width) == 0 ) fprintf(fi->ofp,"\n"); */
+              if ( ((p+1) % id->width) == 0 ) fprintf(fi->ofp,MDC_NEWLINE);
            }
+           fprintf(fi->ofp,MDC_NEWLINE);
            break;
        }
      }else if (MDC_QUANTIFY || MDC_CALIBRATE) {
@@ -471,30 +472,32 @@ char *MdcWriteRAW(FILEINFO *fi)
          case MDC_FRMT_ASCII:
            for (pbuf = new_buf, p=0; p < size; p++, pbuf+=bytes) {
               MdcPrintValue(fi->ofp,pbuf,FLT32); fprintf(fi->ofp," ");
-              /* if ( ((p+1) % id->width) == 0 ) fprintf(fi->ofp,"\n"); */
+              if ( ((p+1) % id->width) == 0 ) fprintf(fi->ofp,MDC_NEWLINE);
            }
+           fprintf(fi->ofp,MDC_NEWLINE);
            break;
        }
      }else{ /* same pixel type */
        bytes = MdcType2Bytes(id->type);
        switch (fi->rawconv) {
-        case MDC_FRMT_RAW:
-          if (MDC_FILE_ENDIAN != MDC_HOST_ENDIAN) {
-            new_buf = MdcGetImgSwapped(fi,i);
-            if (fwrite(new_buf,bytes,size,fi->ofp) != size) {
-              MdcFree(new_buf);
-              return("RAW  Bad write swapped image");
-            }
-          }else if (fwrite(id->buf,bytes,size,fi->ofp) != size) {
-            return("RAW  Bad write original image ");
-          }
-          break;
-        case MDC_FRMT_ASCII:
-          for (pbuf=id->buf, p=0; p < size; p++, pbuf+=bytes) {
-             MdcPrintValue(fi->ofp,pbuf,id->type); fprintf(fi->ofp," ");
-             /* if ( ((p+1) % id->width) == 0 ) fprintf(fi->ofp,"\n"); */
-          }
-          break;
+         case MDC_FRMT_RAW:
+           if (MDC_FILE_ENDIAN != MDC_HOST_ENDIAN) {
+             new_buf = MdcGetImgSwapped(fi,i);
+             if (fwrite(new_buf,bytes,size,fi->ofp) != size) {
+               MdcFree(new_buf);
+               return("RAW  Bad write swapped image");
+             }
+           }else if (fwrite(id->buf,bytes,size,fi->ofp) != size) {
+             return("RAW  Bad write original image ");
+           }
+           break;
+         case MDC_FRMT_ASCII:
+           for (pbuf=id->buf, p=0; p < size; p++, pbuf+=bytes) {
+              MdcPrintValue(fi->ofp,pbuf,id->type); fprintf(fi->ofp," ");
+              if ( ((p+1) % id->width) == 0 ) fprintf(fi->ofp,MDC_NEWLINE);
+           }
+           fprintf(fi->ofp,MDC_NEWLINE);
+           break;
        }
      }
 
