@@ -17,7 +17,7 @@
  *                MdcSplitFrames()        - Write each frame to a file     *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-split.c,v 1.19 2004/05/02 21:12:28 enlf Exp $
+/* $Id: m-split.c,v 1.21 2004/09/25 22:26:56 enlf Exp $
  */
 
 /*
@@ -92,7 +92,7 @@ char *MdcGetSplitBaseName(char *path)
   char *p, *bname;
 
   /* terminate path */
-  p = MdcGetLastPathSlash(path);
+  p = MdcGetLastPathDelim(path);
   if (p != NULL) {
     p[0]='\0'; bname = p + 1;
   }else{
@@ -113,11 +113,7 @@ void MdcUpdateSplitPrefix(char *dpath, char *spath, char *bname, int nr )
 {
   MdcPrefix(nr);
   strcpy(dpath,spath);
-#ifdef MDC_DOS
-  strcat(dpath,"\\");
-#else
-  strcat(dpath,"/");
-#endif
+  strcat(dpath,MDC_PATH_DELIM_STR);
   strcat(dpath,prefix);
   strcat(dpath,bname);
 }
@@ -319,7 +315,7 @@ char *MdcSplitFrames(FILEINFO *fi, int format, int prefixnr)
     MdcGetSafeString(tpath,fi->ifname,strlen(fi->ifname),MDC_MAX_PATH);
   }else{
     MdcGetSafeString(tpath,fi->ofname,strlen(fi->ofname),MDC_MAX_PATH);
-    p = MdcGetLastPathSlash(tpath);
+    p = MdcGetLastPathDelim(tpath);
     if (p != NULL) {
       p[0]='\0'; bname = p + 1;
     }else{
