@@ -8,12 +8,14 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * Functions    : MdcCheckFI()          - Check FILEINFO struct integrity  * 
+ *                MdcGetStructMOD()     - Get MOD_INFO structs             *
  *                MdcGetStructID()      - Get IMG_DATA structs             *
  *                MdcGetStructSD()      - Get STATIC_DATA structs          *
  *                MdcGetStructGD()      - Get GATED_DATA structs           *
  *                MdcGetStructAD()      - Get ACQ_DATA structs             *
  *                MdcGetStructDD()      - Get DYNAMIC_DATA structs         *
  *                MdcGetStructBD()      - Get BED_DATA structs             *
+ *                MdcInitMOD()          - Initialize MOD_INFO struct       *
  *                MdcInitID()           - Initialize IMG_DATA structs      *
  *                MdcInitSD()           - Initialize STATIC_DATA strucs    *
  *                MdcInitGD()           - Initialize GATED_DATA structs    *
@@ -35,7 +37,7 @@
  *                MdcCleanUpFI()        - Clean up FILEINFO struct         *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-structs.c,v 1.58 2004/04/16 22:26:11 enlf Exp $ 
+/* $Id: m-structs.c,v 1.62 2004/10/16 20:36:35 enlf Exp $ 
  */
 
 /*
@@ -112,6 +114,17 @@ char *MdcCheckFI(FILEINFO *fi)
 
 }
 
+/* returns 1 on success and 0 on failure */
+int  MdcGetStructMOD(FILEINFO *fi)
+{
+   fi->mod = calloc(sizeof(MOD_INFO),1);
+
+   if (fi->mod == NULL) return(MDC_NO);
+
+   return(MDC_YES);
+
+}
+
 /* returns 1 on success and 0 on failure */
 int  MdcGetStructID(FILEINFO *fi, Uint32 number)
 {
@@ -275,10 +288,26 @@ int MdcGetStructBD(FILEINFO *fi, Uint32 number)
   return(MDC_YES);
 }
 
+void MdcInitMOD(MOD_INFO *mod)
+{
+  if (mod == NULL) return;
+
+  mod->gn_info.study_date[0]='\0';
+  mod->gn_info.study_time[0]='\0';
+  mod->gn_info.series_date[0]='\0';
+  mod->gn_info.series_time[0]='\0';
+  mod->gn_info.acquisition_date[0]='\0';
+  mod->gn_info.acquisition_time[0]='\0';
+  mod->gn_info.image_date[0]='\0';
+  mod->gn_info.image_time[0]='\0';
+}
+
 void MdcInitID(IMG_DATA *id)
 {
   int i;
 
+  if (id == NULL) return;
+
   memset(id,'\0',sizeof(IMG_DATA));
 
   id->rescaled = MDC_NO;
@@ -294,8 +323,6 @@ void MdcInitID(IMG_DATA *id)
   id->pixel_ysize = 1.;
   id->slice_width = 1.;
 
-  strcpy(id->image_mod,"NM");
-
   for(i=0;i<3;i++) { id->image_pos_dev[i]=0.;    id->image_pos_pat[i]=0.;}
   for(i=0;i<6;i++) { id->image_orient_dev[i]=0.; id->image_orient_pat[i]=0.;}
 
@@ -320,52 +347,54 @@ void MdcInitSD(STATIC_DATA *sd)
 
 void MdcInitGD(GATED_DATA *gd) 
 {
-  if (gd != NULL) {
-    gd->gspect_nesting = MDC_GSPECT_NESTING_GATED;
-    gd->nr_projections = 0.0;
-    gd->extent_rotation = 0.0;
-    gd->study_duration = 0.0;
-    gd->image_duration = 0.0;
-    gd->time_per_proj  = 0.0;
-    gd->window_low = 0.0;
-    gd->window_high= 0.0;
-    gd->cycles_observed = 0.0;
-    gd->cycles_acquired = 0.0;
-    
-  }
+  if (gd == NULL) return;
+
+  gd->gspect_nesting = MDC_GSPECT_NESTING_GATED;
+  gd->nr_projections = 0.0;
+  gd->extent_rotation = 0.0;
+  gd->study_duration = 0.0;
+  gd->image_duration = 0.0;
+  gd->time_per_proj  = 0.0;
+  gd->window_low = 0.0;
+  gd->window_high= 0.0;
+  gd->cycles_observed = 0.0;
+  gd->cycles_acquired = 0.0;
 
 }
 
 void MdcInitAD(ACQ_DATA *acq)
 {
-  if (acq != NULL) {
-     acq->rotation_direction = MDC_ROTATION_CW;
-     acq->detector_motion = MDC_MOTION_STEP;
-     acq->rotation_offset = 0.;
-     acq->radial_position = 0.;
-     acq->angle_start = 0.;
-     acq->angle_step = 0.; 
-     acq->scan_arc = 360.;
-  }
+  if (acq == NULL) return;
+
+  acq->rotation_direction = MDC_ROTATION_CW;
+  acq->detector_motion = MDC_MOTION_STEP;
+  acq->rotation_offset = 0.;
+  acq->radial_position = 0.;
+  acq->angle_start = 0.;
+  acq->angle_step = 0.; 
+  acq->scan_arc = 360.;
+
 }
 
 void MdcInitDD(DYNAMIC_DATA *dd)
 {
-  if (dd != NULL) {
-    dd->nr_of_slices = 0;
-    dd->time_frame_start = 0.;
-    dd->time_frame_delay = 0.;
-    dd->time_frame_duration = 0.;
-    dd->delay_slices = 0.;
-  }
+  if (dd == NULL) return;
+
+  dd->nr_of_slices = 0;
+  dd->time_frame_start = 0.;
+  dd->time_frame_delay = 0.;
+  dd->time_frame_duration = 0.;
+  dd->delay_slices = 0.;
+ 
 }
 
 void MdcInitBD(BED_DATA *bd)
 {
-  if (bd != NULL) {
-    bd->hoffset = 0.;
-    bd->voffset = 0.;
-  }
+  if (bd == NULL) return;
+
+  bd->hoffset = 0.;
+  bd->voffset = 0.;
+
 }
 
 void MdcInitFI(FILEINFO *fi, char *path)
@@ -379,6 +408,7 @@ void MdcInitFI(FILEINFO *fi, char *path)
    fi->diff_type = fi->diff_size = MDC_NO;
    fi->rawconv = MDC_NO;
    fi->endian = MDC_UNKNOWN;
+   fi->modality = M_NM;
    fi->compression = MDC_NO;
    fi->truncated=MDC_NO;
    fi->number = 0;
@@ -395,6 +425,9 @@ void MdcInitFI(FILEINFO *fi, char *path)
    fi->study_time_hour  = 0;
    fi->study_time_minute= 0;
    fi->study_time_second= 0;
+   fi->dose_time_hour   = 0;
+   fi->dose_time_minute = 0;
+   fi->dose_time_second = 0;
 
    fi->nr_series      = -1;
    fi->nr_acquisition = -1;
@@ -467,6 +500,24 @@ void MdcInitFI(FILEINFO *fi, char *path)
 
    fi->pluga = NULL;
 
+}
+
+char *MdcCopyMOD(MOD_INFO *dest, MOD_INFO *src)
+{
+  GN_INFO *dgn, *sgn;
+
+  dgn = &dest->gn_info; sgn = &src->gn_info;
+
+  strncpy(dgn->study_date      , sgn->study_date         , MDC_MAXSTR);
+  strncpy(dgn->study_time      , sgn->study_time         , MDC_MAXSTR);
+  strncpy(dgn->series_date     , sgn->series_date        , MDC_MAXSTR);
+  strncpy(dgn->series_time     , sgn->series_time        , MDC_MAXSTR);
+  strncpy(dgn->acquisition_date, sgn->acquisition_date   , MDC_MAXSTR);
+  strncpy(dgn->acquisition_time, sgn->acquisition_time   , MDC_MAXSTR);
+  strncpy(dgn->image_date      , sgn->image_date         , MDC_MAXSTR);
+  strncpy(dgn->image_time      , sgn->image_time         , MDC_MAXSTR);
+
+  return(NULL);
 
 }
 
@@ -593,8 +644,6 @@ char *MdcCopyID(IMG_DATA *dest, IMG_DATA *src, int COPY_IMAGE)
   dest->slice_width  = src->slice_width;
   dest->recon_scale      = src->recon_scale;
 
-  strncpy(dest->image_mod,src->image_mod,3);
-
   for (i=0; i<3; i++) dest->image_pos_dev[i] = src->image_pos_dev[i];
   for (i=0; i<6; i++) dest->image_orient_dev[i] = src->image_orient_dev[i];
   for (i=0; i<3; i++) dest->image_pos_pat[i] = src->image_pos_pat[i];
@@ -609,7 +658,7 @@ char *MdcCopyID(IMG_DATA *dest, IMG_DATA *src, int COPY_IMAGE)
     if (dest->sdata == NULL) return("Failed to copy static data struct");
     MdcCopySD(dest->sdata,src->sdata);
   }
- 
+
   return(NULL);
 }
 
@@ -635,6 +684,7 @@ char *MdcCopyFI(FILEINFO *dest, FILEINFO *src, int COPY_IMAGES, int KEEP_FILES)
   dest->oformat = src->oformat;
   dest->rawconv = src->rawconv;
   dest->endian  = src->endian;
+  dest->modality    = src->modality;
   dest->compression = src->compression;
   dest->truncated   = src->truncated;
   dest->diff_type   = src->diff_type;
@@ -671,6 +721,9 @@ char *MdcCopyFI(FILEINFO *dest, FILEINFO *src, int COPY_IMAGES, int KEEP_FILES)
   dest->study_time_hour  = src->study_time_hour;
   dest->study_time_minute= src->study_time_minute;
   dest->study_time_second= src->study_time_second;
+  dest->dose_time_hour   = src->dose_time_hour;
+  dest->dose_time_minute = src->dose_time_minute;
+  dest->dose_time_second = src->dose_time_second;
   dest->nr_series        = src->nr_series;
   dest->nr_acquisition   = src->nr_acquisition;
   dest->nr_instance      = src->nr_instance;
@@ -773,17 +826,19 @@ char *MdcCopyFI(FILEINFO *dest, FILEINFO *src, int COPY_IMAGES, int KEEP_FILES)
   }else{
     dest->number = 0; dest->image = NULL;
   }
+ 
+  /* copy MOD_INFO struct */
+  if (src->mod != NULL) {
+    dest->mod = (MOD_INFO *)malloc(sizeof(MOD_INFO));
+    if (dest->mod == NULL) return("Failed to copy MOD_INFO struct");
+    MdcCopyMOD(dest->mod,src->mod);
+  }
 
   return(NULL);
 }
 
 void MdcFreeMODs(FILEINFO *fi)
 {
-  if (fi->mod != NULL) {
-    MdcFree(fi->mod->xa_info);
-    MdcFree(fi->mod->mr_info);
-  }
-
   MdcFree(fi->mod);
 }
 
