@@ -8,7 +8,7 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-structs.h,v 1.42 2004/04/16 22:24:25 enlf Exp $
+/* $Id: m-structs.h,v 1.46 2004/10/16 20:36:35 enlf Exp $
  */
 
 /*
@@ -37,6 +37,20 @@
 
 #define MDC_MAX_DIMS    8                   /* maximum number of dimensions */
 
+/* generic  info GN */
+typedef struct General_Info_t {
+
+	char study_date[MDC_MAXSTR];
+	char study_time[MDC_MAXSTR];
+        char series_date[MDC_MAXSTR]; 
+        char series_time[MDC_MAXSTR];
+        char acquisition_date[MDC_MAXSTR];
+        char acquisition_time[MDC_MAXSTR];
+        char image_date[MDC_MAXSTR];
+        char image_time[MDC_MAXSTR];
+
+} GN_INFO;
+
 /* specific info XA modality */
 typedef struct Mod_XA_Info_t  {
 
@@ -72,8 +86,10 @@ typedef struct Mod_MR_Info_t  {
 
 typedef struct Modality_Info_t {
 
-  XA_INFO *xa_info;
-  MR_INFO *mr_info;
+  GN_INFO gn_info;
+
+  XA_INFO xa_info;
+  MR_INFO mr_info;
 
 } MOD_INFO;
 
@@ -112,7 +128,7 @@ typedef struct Acquisition_Data_t {
   Int16 detector_motion;         /* type detector motion   */
   float rotation_offset;         /* centre rotation offset */
   float radial_position;         /* radial position        */
-  float angle_start;             /* start angle (interfile)*/
+  float angle_start;             /* start angle (interfile)*/ /* 180 - dicom */
   float angle_step;              /* angular step           */
   float scan_arc;                /* angular range          */
 
@@ -176,7 +192,6 @@ typedef struct Image_Data_t {
 
   /*            **  Acr/Nema items   **                    */
 
-  char  image_mod[3];            /* images modality        */
   float image_pos_dev[3];        /* image posit  dev  (mm) */
   float image_orient_dev[6];     /* image orient dev  (mm) */
   float image_pos_pat[3];        /* image posit  pat  (mm) */
@@ -207,6 +222,7 @@ typedef struct File_Info_t {
   char *ofname;                  /* name of output file    */
   int  iformat;                  /* format of  input file  */
   int  oformat;                  /* format of output file  */
+  int  modality;                 /* modality               */
   Int8 rawconv;                  /* FRMT_RAW | FRMT_ASCII  */
   Int8 endian;                   /* endian of file         */
   Int8 compression;              /* file compression       */
@@ -253,6 +269,9 @@ typedef struct File_Info_t {
   Int16 study_time_hour;         /* hour of study          */
   Int16 study_time_minute;       /* minute of study        */
   Int16 study_time_second;       /* second of study        */
+  Int16 dose_time_hour;          /* hour   of dose start   */
+  Int16 dose_time_minute;        /* minute of dose start   */
+  Int16 dose_time_second;        /* second of dose start   */
   Int16 nr_series;               /* series number          */
   Int16 nr_acquisition;          /* acquisition number     */
   Int16 nr_instance;             /* instance number        */
@@ -294,7 +313,7 @@ typedef struct File_Info_t {
 
   IMG_DATA *image;               /* array IMG_DATA images  */
 
-  MOD_INFO *mod;                 /* modalities information */
+  MOD_INFO *mod;                 /* modality related info  */
 
   unsigned char *pluga;          /* want to attach stuff?  */
 
@@ -305,12 +324,14 @@ typedef struct File_Info_t {
 ****************************************************************************/
 
 char *MdcCheckFI(FILEINFO *fi);
+int MdcGetStructMOD(FILEINFO *fi);
 int MdcGetStructID(FILEINFO *fi, Uint32 number);
 int MdcGetStructSD(FILEINFO *fi, Uint32 number);
 int MdcGetStructGD(FILEINFO *fi, Uint32 number);
 int MdcGetStructAD(FILEINFO *fi, Uint32 number);
 int MdcGetStructDD(FILEINFO *fi, Uint32 number);
 int MdcGetStructBD(FILEINFO *fi, Uint32 number);
+void MdcInitMOD(MOD_INFO *mod);
 void MdcInitID(IMG_DATA *id);
 void MdcInitSD(STATIC_DATA *sd);
 void MdcInitGD(GATED_DATA *gd);
@@ -318,6 +339,7 @@ void MdcInitAD(ACQ_DATA *acq);
 void MdcInitDD(DYNAMIC_DATA *dd);
 void MdcInitBD(BED_DATA *bd);
 void MdcInitFI(FILEINFO *fi, char *path);
+char *MdcCopyMOD(MOD_INFO *mod, MOD_INFO *src);
 char *MdcCopyID(IMG_DATA *dest, IMG_DATA *src, int COPY_IMAGE);
 char *MdcCopySD(STATIC_DATA *dest, STATIC_DATA *src);
 char *MdcCopyGD(GATED_DATA *dest, GATED_DATA *src);
