@@ -20,7 +20,7 @@
  *                MdcHandleColor()           - Handle color images         *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-transf.c,v 1.21 2004/05/09 22:48:03 enlf Exp $
+/* $Id: m-transf.c,v 1.22 2005/02/02 22:46:51 enlf Exp $
  */
 
 /*
@@ -224,12 +224,10 @@ char *MdcMakeSquare(FILEINFO *fi, int SQR_TYPE)
   Uint32 i, dim;
   Uint8 *sqrbuf;
 
-  if ((fi->diff_size == MDC_NO) && (fi->mwidth == fi->mheight))
-    return(NULL);
-
+  /* get largest dim */
   dim = (fi->mwidth > fi->mheight) ? fi->mwidth : fi->mheight;
 
-  /* dimensions as a power of two */
+  /* dims as a power of two */
   if (SQR_TYPE == MDC_TRANSF_SQR2) dim = MdcCeilPwr2(dim);
 
   /* set to new dimensions */
