@@ -12,7 +12,7 @@
  *                MdcEditFI()               - Edit FILEINFO structure      *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-vifi.c,v 1.28 2004/01/04 22:36:16 enlf Exp $
+/* $Id: m-vifi.c,v 1.30 2004/10/16 20:36:35 enlf Exp $
  */
 
 /*
@@ -136,9 +136,10 @@ char *MdcEditFI(FILEINFO *fi)
    IMG_DATA *id=NULL;
    DYNAMIC_DATA *dd=NULL;
    Uint32 i, number, dflt, dim[MDC_MAX_DIMS];
-   Int8 a, LAST_FOUND=MDC_NO, PET_MOD=MDC_YES;
+   Int8 a, LAST_FOUND=MDC_NO;
    float pixel_size, slice_width, slice_spacing, frame_duration;
-   char *msg, modality[3], *badvalue="Bad dim[]-value supplied";
+   char *msg, *badvalue="Bad dim[]-value supplied";
+   int modality = fi->modality;
 
    if (MDC_FILE_STDIN == MDC_YES) return(NULL); /* stdin already in use */
 
@@ -303,24 +304,21 @@ char *MdcEditFI(FILEINFO *fi)
      }
    }
 
-   if (strncmp(fi->image[0].image_mod,"PT",2) == 0) {
-     strcpy(modality,"PT"); PET_MOD = MDC_YES;
-   }else{
-     strcpy(modality,"NM"); PET_MOD = MDC_NO;
-   }
    MdcPrntScrn("\n\tSelect Modality:\n");
-   MdcPrntScrn("\n\t\t   1    ->  NM (NucMed)");
-   MdcPrntScrn("\n\t\t   2    ->  PT (PET)");
-   MdcPrntScrn("\n\t\t<enter> ->  default");
-   MdcPrntScrn("\n\n\tYour choice ");
-   if (PET_MOD == MDC_NO) MdcPrntScrn("[1] ? ");
-   else MdcPrntScrn("[2] ? ");
+   MdcPrntScrn("\n\t\t   1    ->  NM");
+   MdcPrntScrn("\n\t\t   2    ->  PT");
+   MdcPrntScrn("\n\t\t   3    ->  CT");
+   MdcPrntScrn("\n\t\t   4    ->  MR");
+   MdcPrntScrn("\n\t\t<enter> ->  current");
+   MdcPrntScrn("\n\n\tYour choice [%s] ? ",MdcGetStrModality(modality));
 
    if (! MdcPutDefault(mdcbufr)) {
      a = atoi(mdcbufr);
      switch (a) {
-       case 1: strcpy(modality,"NM"); break;
-       case 2: strcpy(modality,"PT"); break;
+       case 1: modality = M_NM; break;
+       case 2: modality = M_PT; break;
+       case 3: modality = M_CT; break;
+       case 4: modality = M_MR; break;
      } 
    } 
 
@@ -347,6 +345,8 @@ char *MdcEditFI(FILEINFO *fi)
    fi->pixdim[3] = slice_width; 
    fi->pixdim[4] = frame_duration;
 
+   fi->modality  = modality;
+
    /* fill in IMG_DATA structs */
    for (i=0; i < fi->number; i++) {
       id = &fi->image[i];
@@ -356,7 +356,6 @@ char *MdcEditFI(FILEINFO *fi)
       id->slice_width  = slice_width;
       id->slice_spacing= slice_spacing;
 
-      strcpy(fi->image[i].image_mod,modality);
       MdcFillImgPos(fi,i,i%fi->dim[3],(float)0.0);
       MdcFillImgOrient(fi,i);
    }
