@@ -10,11 +10,11 @@
  * Functions    : main()             -  The hart of the project            *
  *                                                                         * 
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: medcon.c,v 1.1.1.1 2000/10/28 16:51:38 enlf Exp $
+/* $Id: medcon.c,v 1.21 2004/05/02 21:12:28 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2000 by Erik Nolf
+   Copyright (C) 1997-2004 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -34,6 +34,8 @@
                               H E A D E R S  
 ****************************************************************************/
 
+#include <stdio.h>
+
 #include "medcon.h"
 
 /****************************************************************************
@@ -51,14 +53,23 @@ int main(int argc, char *argv[])
   int   convert, error;            /* some variables                         */
   char *msg=NULL;
 
-  XMDC_MEDCON = MDC_NO;            /* make sure it is command line driven    */
+  XMDC_GUI = MDC_NO;               /* program is CLI, command-line interface */
+
+  /* init library */
+  MdcInit();
+
+  if (argc == 1) { MdcPrintShortInfo(); return(MDC_BAD_CODE); }
 
   /* parse the command line arguments */
   if (MdcHandleArgs(&fi,argc,argv,MDC_MAX_FILES) != MDC_OK) 
     MdcPrintUsage(NULL);
 
-  /* ignore floating exceptions */
-  if (!MDC_SIGFPE) MdcIgnoreSIGFPE();
+  if (MDC_FILE_STACK != MDC_NO) {
+    /* stack files, leave program afterwards */
+    msg = MdcStackFiles(MDC_FILE_STACK);
+    if (msg != NULL) MdcPrntErr(MDC_BAD_CODE,msg);
+    return(MDC_OK);
+  }
 
   /* initialize raw read input */
   if (MDC_INTERACTIVE) MdcInitRawPrevInput();
@@ -74,7 +85,7 @@ int main(int argc, char *argv[])
      if (MDC_HACK_ACR) {
        if ((msg = MdcHackACR(&fi)) != NULL)
          /* tolerate errors */
-         MdcPrntWarn("Error reading - %s",msg); 
+         MdcPrntWarn("Failed ACR Hack - %s",msg); 
        if (MDC_DEBUG) MdcPrintFI(&fi);
        MdcCleanUpFI(&fi);
        continue;
@@ -82,7 +93,10 @@ int main(int argc, char *argv[])
 #endif
 
      /* read the file */
-     if ((error = MdcReadFile(&fi,f+1)) != MDC_OK) return(error);
+     if ((error = MdcReadFile(&fi,f+1,NULL)) != MDC_OK) return(error);
+
+     /* echo alias name on one file at a time; nothing else allowed */
+     if (MDC_ECHO_ALIAS) { MdcCleanUpFI(&fi); return(MDC_OK); }
 
      /* only printing database info */
      if (MDC_INFO_DB) continue;
@@ -97,7 +111,7 @@ int main(int argc, char *argv[])
      if (MDC_EDIT_FI) {
        if ((msg = MdcEditFI(&fi)) != NULL) {
          MdcCleanUpFI(&fi);
-         MdcPrntErr(MDC_BAD_CODE,msg);
+         MdcPrntErr(MDC_BAD_CODE,"Failed Info Edit - %s",msg);
        }
      }
 
@@ -109,9 +123,17 @@ int main(int argc, char *argv[])
 
      /* extract some images */
      if (MDC_EXTRACT) { 
-       if ((error = MdcExtractImages(&fi)) != MDC_OK) {
+       if ((msg = MdcExtractImages(&fi)) != NULL) {
          MdcCleanUpFI(&fi);
-         MdcPrntErr(error,"Images extraction NOT succeeded!");
+         MdcPrntErr(error,"Failed Extract - %s",msg);
+       }
+     }
+
+     if (MDC_RESLICE != MDC_NO) {
+       msg=MdcResliceImages(&fi, MDC_RESLICE);
+       if (msg != NULL) {
+         MdcCleanUpFI(&fi);
+         MdcPrntErr(MDC_BAD_CODE,"Failed Reslice - %s",msg);
        }
      }
 
@@ -126,10 +148,28 @@ int main(int argc, char *argv[])
           convert = convs[c];
           /* write output format when selected */
           while (convert-- > 0) {
-               if ((error = MdcWriteFile(&fi, c, t++)) != MDC_OK) {
-                 MdcCleanUpFI(&fi);
-                 return(error);
-               } 
+               switch (MDC_FILE_SPLIT) {
+                 case MDC_SPLIT_PER_SLICE:
+                     msg = MdcSplitSlices(&fi,c,MdcGetPrefixNr(&fi,t++));
+                     if (msg != NULL) {
+                       MdcCleanUpFI(&fi);
+                       MdcPrntErr(MDC_BAD_CODE,"Failed Split - %s",msg);
+                     }
+                     break;
+                 case MDC_SPLIT_PER_FRAME:
+                     msg = MdcSplitFrames(&fi,c,MdcGetPrefixNr(&fi,t++));
+                     if (msg != NULL) {
+                       MdcCleanUpFI(&fi);
+                       MdcPrntErr(MDC_BAD_CODE,"Failed Split - %s",msg);
+                     }
+                     break;
+                 default:
+                     error = MdcWriteFile(&fi,c,MdcGetPrefixNr(&fi,t++),NULL);
+                     if (error != MDC_OK) {
+                       MdcCleanUpFI(&fi);
+                       return(error);
+                     }
+	       }
           }
        }
 
@@ -140,6 +180,9 @@ int main(int argc, char *argv[])
 
   }
 
+  /* finish library */
+  MdcFinish();
+
   /* bye */
   return(MDC_OK);
 }
