@@ -20,7 +20,7 @@
  *                XMdcColGbcCorrectSel();         - GBC selection          *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xcolgbc.c,v 1.12 2004/01/04 22:36:17 enlf Exp $
+/* $Id: xcolgbc.c,v 1.14 2004/10/21 23:48:39 enlf Exp $
  */
 
 /*
@@ -95,7 +95,7 @@ void XMdcColGbcCorrectUpdate(void)
 
   XMdcSetGbcCorrection(&modtmp);
 
-  imtmp = XMdcBuildGdkPixbuf(sGbc.img8,sGbc.w,sGbc.h,sGbc.t,modtmp.vgbc,MDC_NO);
+  imtmp = XMdcBuildGdkPixbuf(sGbc.img8,sGbc.w,sGbc.h,sGbc.t,modtmp.vgbc);
 
   w = gdk_pixbuf_get_width(sGbc.im);
   h = gdk_pixbuf_get_height(sGbc.im);
@@ -142,8 +142,8 @@ void XMdcColGbcCorrectAddImg(GtkWidget *w)
   GtkWidget *box, *area, *imgbox;
   int rw, rh;
 
-  rw = (signed)XMdcResize(sGbc.w);
-  rh = (signed)XMdcResize(sGbc.h);
+  rw = (signed)XMdcScaleW(sGbc.w);
+  rh = (signed)XMdcScaleH(sGbc.h);
 
   box = gtk_vbox_new(FALSE, 0);
   gtk_box_pack_start(GTK_BOX(w), box, FALSE, FALSE, 0);
@@ -289,8 +289,8 @@ void XMdcColGbcCorrectSel(GtkWidget *widget, Uint32 nr)
   modtmp.brightness = sGbc.mod.brightness;
   modtmp.contrast = sGbc.mod.contrast;
   XMdcSetGbcCorrection(&modtmp);
-  rw = (signed)XMdcResize(sGbc.w);
-  rh = (signed)XMdcResize(sGbc.h);
+  rw = (signed)XMdcScaleW(sGbc.w);
+  rh = (signed)XMdcScaleH(sGbc.h);
 
   MdcFree(sGbc.img8);
 
@@ -300,7 +300,7 @@ void XMdcColGbcCorrectSel(GtkWidget *widget, Uint32 nr)
     return;
   }
 
-  im = XMdcBuildGdkPixbuf(sGbc.img8,sGbc.w,sGbc.h,sGbc.t,modtmp.vgbc,MDC_YES);
+  im = XMdcBuildGdkPixbuf(sGbc.img8,sGbc.w,sGbc.h,sGbc.t,modtmp.vgbc);
   if (im == NULL) {
     MdcFree(sGbc.img8);
     XMdcDisplayErr("Couldn't create GdkPixbuf");
