@@ -8,11 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xcolmap.h,v 1.1.1.1 2000/10/28 16:51:39 enlf Exp $
+/* $Id: xcolmap.h,v 1.9 2004/01/04 22:36:17 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2000 by Erik Nolf
+   Copyright (C) 1997-2004 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -37,10 +37,17 @@
 
 void XMdcRemovePreviousColorMap(void);
 void XMdcApplyNewColorMap(int map);
+gboolean XMdcColorMapCallbackClicked(GtkWidget *widget, GdkEventButton *button, gpointer data);
 void XMdcColorMapSelCallbackApply(GtkWidget *widget, gpointer data);
 gboolean XMdcColorMapSel(void);
 gboolean XMdcColorMapCallbackExpose(GtkWidget *widget, GdkEventExpose *event, gpointer data);
+void XMdcApplyMapPlace(int place);
+void XMdcMapPlaceSelCallbackApply(GtkWidget *widget, gpointer data);
+gboolean XMdcMapPlaceSel(void);
 void XMdcBuildColorMap(void);
+int XMdcLoadLUT(gchar *lutname);
+gboolean XMdcChangeLUT(GtkWidget *spinner, gpointer data);
+gboolean XMdcMapNotAllowed(void);
 
 #endif
 
