@@ -8,7 +8,7 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xdefs.h,v 1.58 2004/11/07 00:15:43 enlf Exp $
+/* $Id: xdefs.h,v 1.59 2005/02/01 23:23:46 enlf Exp $
  */
 
 /*
@@ -124,6 +124,9 @@ typedef struct OptionsMedConStruct_t {
         GtkWidget *ColorModeIndexed;
         GtkWidget *ColorMakeGray;
         GtkWidget *ColorDither;
+        GtkWidget *PadAround;
+        GtkWidget *PadTopLeft;
+        GtkWidget *PadBottomRight;
         GtkWidget *NameAlias;
         GtkWidget *NameNoPrefix;
         GtkWidget *DicmMosaicEnabled;
