@@ -19,7 +19,7 @@
  *                XMdcShowErrorConsole() - Show the error console          *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xerror.c,v 1.16 2004/01/04 22:36:17 enlf Exp $
+/* $Id: xerror.c,v 1.17 2004/09/04 10:50:46 enlf Exp $
  */
 
 /*
@@ -62,7 +62,7 @@ static GtkWidget *wlogs = NULL;
 
 void XMdcFatalErrorKill(GtkWidget *button, int *code)
 {
-  gtk_exit(*code);
+  gtk_exit(-*code);
 }
 
 void *XMdcDisplayDialog(int code, char *windowtitle, char *info)
