@@ -8,11 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xerror.h,v 1.1.1.1 2000/10/28 16:51:42 enlf Exp $
+/* $Id: xerror.h,v 1.8 2004/01/04 22:36:17 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2000 by Erik Nolf
+   Copyright (C) 1997-2004 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -41,6 +41,11 @@ void *XMdcDisplayWarn(char *fmt, ...);
 void *XMdcDisplayMesg(char *fmt, ...);
 void *XMdcDisplayErr(char *fmt, ...);
 void XMdcDisplayFatalErr(int code, char *fmt, ...);
+void XMdcLogHandler(const gchar *domain, GLogLevelFlags level,
+                    const gchar *message, gpointer user_data);
+void XMdcCreateLogConsole(void);
+void XMdcShowLogConsole(void);
+void XMdcClearLogConsole(void);
 
 #endif
 
