@@ -7,7 +7,8 @@
  *                                                                         *
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
- * Functions    : XMdcExtractImages()                 - Extract the images *
+ * Functions    : XMdcExtractNotBussy()               - Check for bussy    *
+ *                XMdcExtractImages()                 - Extract the images *
  *                XMdcHandleEcatList()                - Handle Ecat list   *
  *                XMdcHandleNormList()                - Handle Norm list   *
  *                XMdcGetImagesCallbackApply()        - Get Apply callback *
@@ -16,11 +17,11 @@
  *                XMdcExtractStyleSel()               - Extract Style Sel  *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xextract.c,v 1.1.1.1 2000/10/28 16:51:44 enlf Exp $
+/* $Id: xextract.c,v 1.20 2004/05/09 22:48:03 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2000 by Erik Nolf
+   Copyright (C) 1997-2004 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -40,6 +41,21 @@
                               H E A D E R S
 ****************************************************************************/
 
+#include "m-depend.h"
+
+#include <stdio.h>
+#ifdef HAVE_STDLIB_H
+#include <stdlib.h>
+#endif
+#ifdef HAVE_STRING_H
+#include <string.h>
+#endif
+#ifdef HAVE_STRINGS_H
+#ifndef _WIN32
+#include <strings.h>
+#endif
+#endif
+
 #include "xmedcon.h"
 
 /****************************************************************************
@@ -48,6 +64,8 @@
 
 static int BUSSY = MDC_NO;
 
+static GtkWidget  *wextract=NULL;
+
 /****************************************************************************
                             F U N C T I O N S
 ****************************************************************************/
@@ -59,19 +77,19 @@ gboolean XMdcExtractNotBussy(GtkWidget *widget, gpointer data)
 
 void XMdcExtractImages(void)
 {
-  XMdcBeginProgressBar("Extracting images:");
+  char *msg;
+  XMdcProgressBar(MDC_PROGRESS_BEGIN,0.,"Extracting images:");
 
   XMdcViewerHide();
   XMdcViewerEnableAutoShrink();
   XMdcViewerReset();
  
-  MdcExtractImages(my.fi); /* any failure has been handled */
+  msg = MdcExtractImages(my.fi);
+  if (msg != NULL) XMdcDisplayErr("Extract - %s",msg);
 
   XMdcDisplayImages();
-  XMdcViewerShow();
-  XMdcViewerDisableAutoShrink();
  
-  XMdcEndProgressBar();
+  XMdcProgressBar(MDC_PROGRESS_END,0.,NULL);
 
   XMDC_FILE_TYPE = XMDC_EXTRACT;
 
@@ -79,159 +97,23 @@ void XMdcExtractImages(void)
 
 int XMdcHandleEcatList(char *s, Uint32 **list, Uint32 max)
 {
-  Uint32 a1, a2, j, length, tmp;
-  int i, SeekBegin=MDC_YES;
-  char *p, *item;
+  char *msg;
+
+  msg = MdcHandleEcatList(s, list, max);
+
+  if (msg != NULL) { XMdcDisplayErr(msg); return(MDC_NO); }
 
-  MdcDebugPrint("DEBUG: entry = <%s>\n",s);
- 
-  length = strlen(s);
-  p = s; item = s;
-  for (i=0; i<length; i++) {
-     MdcDebugPrint("DEBUG: char = <%c>\n",p[i]);
-     if (p[i]=='-') break;
-     if (SeekBegin) {
-       if (p[i]!=' ') { item = &p[i]; SeekBegin=MDC_NO; }
-     }else if (p[i]==' ') {
-         SeekBegin=MDC_YES;
-         p[i]='\0';
-         if (strstr(item,"...") != 0) {
-           /* a RANGE values */
-           MdcDebugPrint("DEBUG: RANGE = <%s>\n",item);
-           sscanf(item,"%u...%u",&a1,&a2);
-           if (a1 > max || a2 > max) {
-             XMdcDisplayErr("Bad entry found in list");
-             return(MDC_NO);
-           }
-           if ( (a1==0) || (a2==0) ) {
-             for (j=1; j<=max; j++) (*list)[j]=MDC_YES;
-             (*list)[0]=max;
-             return(MDC_YES);
-           }
-           if (a1 > a2) {
-             tmp = a1;
-             a1  = a2;
-             a2  = tmp;
-           }
-           for (j=a1; j<=a2; j++) {
-              if ( (*list)[j] == MDC_NO) {
-                (*list)[j] = MDC_YES;
-                (*list)[0] += 1;
-              }
-           }
-         }else{
-           /* a SINGLE value */
-           MdcDebugPrint("DEBUG: SINGLE = <%s>\n",item);
-           sscanf(item,"%u",&a1);
-           if (a1 > max) {
-             XMdcDisplayErr("Bad entry found in list");
-             return(MDC_NO);
-           }
-           if (a1 == 0) {
-             for (j=1; j<=max; j++) (*list)[j]=MDC_YES;
-             (*list)[0]=max;
-             return(MDC_YES);
-           }
-           if ( (*list)[a1] == MDC_NO) {
-             (*list)[a1] = MDC_YES;
-             (*list)[0] += 1;
-           }
-         }
-      }
-  }
   return(MDC_YES);
 }
 
  
 int XMdcHandleNormList(char *s, Uint32 **inrs,Uint32 *it,Uint32 *bt,Uint32 max)
 {
-  Uint32 a1, a2, j, length;
-  int i, SeekBegin=MDC_YES;
-  char *p, *item;
+  char *msg;
 
-  MdcDebugPrint("DEBUG: entry = <%s>\n",s);
+  msg = MdcHandleNormList(s, inrs, it, bt, max);
 
-  length = strlen(s);
-  p = s; item = s;
-  for (i=0; i<length; i++) {
-     MdcDebugPrint("DEBUG: char = <%c>\n",p[i]);
-     if (p[i]=='-') break;
-     if (SeekBegin) {
-       if (p[i]!=' ') { item=&p[i]; SeekBegin=MDC_NO; }
-     }else if (p[i]==' ') {
-         SeekBegin=MDC_YES;
-         p[i]='\0';
-         if (strstr(item,"...") != 0) {
-           /* a RANGE values */
-           MdcDebugPrint("DEBUG: RANGE = <%s>\n",item);
-           sscanf(item,"%u...%u",&a1,&a2);
-
-           if (a1 > max || a2 > max) {
-             XMdcDisplayErr("Bad entry found in list");
-             return(MDC_NO);
-           }
-
-           if ( (a1==0) || (a2==0) ) {
-             (*inrs)[1] = 0;
-             *it = 2;
-             return(MDC_YES);
-           }
-
-           if (a1 > a2) {
-             for (j=a1; j>=a2; j--) {
-                (*inrs)[*it] = j;
-                *it += 1;
-                if ( (*it % MDC_BUF_ITMS) == 0 ) {
-                  if (((*inrs)=(Uint32 *)MdcRealloc((*inrs),
-                               (*bt)*MDC_BUF_ITMS*sizeof(Uint32)))==NULL) {
-                    XMdcDisplayErr("Couldn't realloc number buffer");
-                    return(MDC_NO);
-                  }
-                  *bt += 1;
-                }
-             }
-           }else{
-             for (j=a1; j<=a2; j++) {
-                (*inrs)[*it] = j;
-                *it += 1;
-                if ( (*it % MDC_BUF_ITMS) == 0 ) {
-                  if (((*inrs)=(Uint32 *)MdcRealloc((*inrs),
-                               (*bt)*MDC_BUF_ITMS*sizeof(Uint32)))==NULL) {
-                    XMdcDisplayErr("Couldn't realloc number buffer");
-                    return(MDC_NO);
-                  }
-                  *bt += 1;
-                }
-             }
-           }
-
-         }else{
-           /* a SINGLE value */
-           MdcDebugPrint("DEBUG: SINGLE = <%s>\n",item);
-           sscanf(item,"%u",&a1);
-           if (a1 > max) {
-             XMdcDisplayErr("Bad entry found in list",a1);
-             return(MDC_NO);
-           }
-           if (a1 == 0) {
-             (*inrs)[1] = 0;
-             *it = 2;
-             return(MDC_YES);
-           }
-           (*inrs)[*it] = a1;
-           (*it) += 1;
-           if ( (*it % MDC_BUF_ITMS) == 0) {
-             if (((*inrs)=(Uint32 *)MdcRealloc((*inrs),
-                          (*bt)*MDC_BUF_ITMS*sizeof(Uint32)))==NULL) {
-               XMdcDisplayErr("Couldn't realloc number buffer");
-               return(MDC_NO);
-             }
-             *bt += 1;
-           }
-
-         }
-     }
-  }
+  if (msg != NULL) { XMdcDisplayErr(msg); return(MDC_NO); }
 
   return(MDC_YES);
 } 
@@ -255,11 +137,8 @@ void XMdcGetImagesCallbackApply(GtkWidget *widget, gpointer data)
 
     entry = gtk_entry_get_text(GTK_ENTRY(sExtractSelection.InputPlanes));
     
-    strcpy(xmdcstr,entry);
-    strcat(xmdcstr," -1");
-
     it = 1; bt = 2;
-    if (XMdcHandleNormList(xmdcstr,&input->inrs,&it,&bt,my.fi->number) 
+    if (XMdcHandleNormList(entry,&input->inrs,&it,&bt,my.fi->number) 
          != MDC_YES) {
       MdcFree(input->inrs);
       return;
@@ -291,38 +170,30 @@ void XMdcGetImagesCallbackApply(GtkWidget *widget, gpointer data)
     memset(beds,0,(my.fi->dim[6]+1)*sizeof(Uint32));
 
     entry = gtk_entry_get_text(GTK_ENTRY(sExtractSelection.InputPlanes));
-    strcpy(xmdcstr,entry);
-    strcat(xmdcstr," -1");
-    if (XMdcHandleEcatList(xmdcstr,&planes,my.fi->dim[3]) != MDC_YES) {
+    if (XMdcHandleEcatList(entry,&planes,(unsigned)my.fi->dim[3]) != MDC_YES) {
       MdcFree(planes); MdcFree(frames); MdcFree(gates); MdcFree(beds);
       return;
     }
 
     entry = gtk_entry_get_text(GTK_ENTRY(sExtractSelection.InputFrames));
-    strcpy(xmdcstr,entry);
-    strcat(xmdcstr," -1");
-    if (XMdcHandleEcatList(xmdcstr,&frames,my.fi->dim[4]) != MDC_YES) {
+    if (XMdcHandleEcatList(entry,&frames,(unsigned)my.fi->dim[4]) != MDC_YES) {
       MdcFree(planes); MdcFree(frames); MdcFree(gates); MdcFree(beds);
       return;
     }
 
     entry = gtk_entry_get_text(GTK_ENTRY(sExtractSelection.InputGates));
-    strcpy(xmdcstr,entry);
-    strcat(xmdcstr," -1");
-    if (XMdcHandleEcatList(xmdcstr,&gates,my.fi->dim[5]) != MDC_YES) {
+    if (XMdcHandleEcatList(entry,&gates,(unsigned)my.fi->dim[5]) != MDC_YES) {
       MdcFree(planes); MdcFree(frames); MdcFree(gates); MdcFree(beds);
       return;
     }
 
     entry = gtk_entry_get_text(GTK_ENTRY(sExtractSelection.InputBeds));
-    strcpy(xmdcstr,entry);
-    strcat(xmdcstr," -1");
-    if (XMdcHandleEcatList(xmdcstr,&beds,my.fi->dim[6]) != MDC_YES) {
+    if (XMdcHandleEcatList(entry,&beds,(unsigned)my.fi->dim[6]) != MDC_YES) {
       MdcFree(planes); MdcFree(frames); MdcFree(gates); MdcFree(beds);
       return;
     }
 
-    MdcDebugPrint("DEBUG: p=%u f=%u g=%u b=%u\n",planes[0],frames[0],gates[0],beds[0]); 
+    MdcDebugPrint("p=%u f=%u g=%u b=%u",planes[0],frames[0],gates[0],beds[0]); 
 
     images*=planes[0]*frames[0]*gates[0]*beds[0];
 
@@ -415,11 +286,12 @@ void XMdcGetImages(void)
 
    if (input->style == MDC_INPUT_NORM_STYLE) {
      /* create input notes */
-     strcpy(mdcbufr,"a) Any number must be one-based (0 = All reversed)\n" \
-                    "b) The syntax of a range: X...Y (no spaces)\n" \
-                    "c) Items must be separated by spaces\n" \
-                    "d) This list is sequence sensitive!\n\n" \
-                    " Example: 1 3 12...6 84 31\n");
+     strcpy(mdcbufr,"a) Any number must be one-based     (0 = All reversed)\n" \
+                    "b) Syntax of a range : X...Y or X-Y\n" \
+                    "c) Syntax of interval: X:S:Y        (S = step)\n" \
+                    "d) Items must be separated by spaces\n" \
+                    "e) This list is sequence sensitive!\n\n" \
+                    " Example: 1 3 4:2:11 12...6\n");
 
      label = gtk_label_new(mdcbufr);
      gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_LEFT);
@@ -449,7 +321,7 @@ void XMdcGetImages(void)
      gtk_widget_show(label);
 
      planes=gtk_entry_new_with_max_length(50);
-     MdcDebugPrint("DEBUG: rc-style name = %s\n",gtk_widget_get_name(planes));
+     MdcDebugPrint("rc-style name = %s",gtk_widget_get_name(planes));
      gtk_entry_set_text(GTK_ENTRY(planes),"0");
      gtk_editable_select_region(GTK_EDITABLE(planes),0,-1);
      gtk_box_pack_start(GTK_BOX(box3),planes,TRUE,TRUE,0);
@@ -460,9 +332,10 @@ void XMdcGetImages(void)
    }else{
      /* create input notes */
      strcpy(mdcbufr,"a) Any number must be one-based (0 = All)\n" \
-                    "b) The syntax of a range: X...Y (no spaces)\n" \
-                    "c) Items must be separated by spaces\n\n" \
-                    " Example: 1 3 5...10 12\n");
+                    "b) Syntax of range   : X...Y or X-Y\n" \
+                    "c) Syntax of interval: X:S:Y    (S = step)\n" \
+                    "d) Items must be separated by spaces\n\n" \
+                    " Example: 1 3 5...10 12:2:20\n");
 
      label = gtk_label_new(mdcbufr);
      gtk_label_set_justify(GTK_LABEL(label),GTK_JUSTIFY_LEFT);
@@ -589,13 +462,12 @@ void XMdcExtractStyleSelCallbackApply(GtkWidget *widget, gpointer data)
 
   if (XMdcNoFileOpened()) return; 
 
-  MdcDebugPrint("DEBUG: Extraction style: ");
-
+  MdcDebugPrint("extract stype: ");
   if (GTK_TOGGLE_BUTTON(sExtractSelection.NormStyle)->active) {
-    MdcDebugPrint("Normal Style\n");  
+    MdcDebugPrint("\tnormal");  
     input->style = MDC_INPUT_NORM_STYLE;
   }else if (GTK_TOGGLE_BUTTON(sExtractSelection.EcatStyle)->active) {
-    MdcDebugPrint("Ecat Style\n");
+    MdcDebugPrint("\tecat");
     input->style = MDC_INPUT_ECAT_STYLE;
   }
 
@@ -607,7 +479,6 @@ void XMdcExtractStyleSelCallbackApply(GtkWidget *widget, gpointer data)
 
 void XMdcExtractStyleSel(GtkWidget *widget, gpointer data)
 {
-  GtkWidget *window=NULL;
   GtkWidget *box1;
   GtkWidget *box2;
   GtkWidget *box3;
@@ -620,83 +491,107 @@ void XMdcExtractStyleSel(GtkWidget *widget, gpointer data)
 
   if (XMdcNoFileOpened() || BUSSY) return;
 
-  window = gtk_window_new(GTK_WINDOW_TOPLEVEL); BUSSY = MDC_YES;
+  if (wextract == NULL)  {
 
-  gtk_signal_connect(GTK_OBJECT(window),"delete_event",
-                     GTK_SIGNAL_FUNC(XMdcExtractNotBussy),NULL);
-  gtk_signal_connect(GTK_OBJECT(window),"destroy",
-                     GTK_SIGNAL_FUNC(gtk_widget_destroy),NULL);
-  gtk_window_set_title(GTK_WINDOW(window),"Extract Selection");
+    wextract = gtk_window_new(GTK_WINDOW_TOPLEVEL); BUSSY = MDC_YES;
 
-  gtk_container_set_border_width (GTK_CONTAINER(window), 0);
+    gtk_signal_connect(GTK_OBJECT(wextract),"destroy",
+                       GTK_SIGNAL_FUNC(XMdcMedconQuit),NULL);
+    gtk_signal_connect(GTK_OBJECT(wextract),"delete_event",
+                       GTK_SIGNAL_FUNC(XMdcExtractNotBussy),NULL);
+    gtk_signal_connect(GTK_OBJECT(wextract),"delete_event",
+                       GTK_SIGNAL_FUNC(XMdcHandlerToHide),NULL);
 
-  box1 = gtk_vbox_new(FALSE,0);
-  gtk_container_add(GTK_CONTAINER(window),box1);
-  gtk_widget_show(box1);
+    gtk_window_set_title(GTK_WINDOW(wextract),"Extract Selection");
 
-  /* create upper box - Extract Style */
-  box2 = gtk_vbox_new(FALSE, 5);
-  gtk_box_pack_start(GTK_BOX(box1),box2,TRUE,TRUE,0);
-  gtk_container_set_border_width(GTK_CONTAINER(box2),5);
-  gtk_widget_show(box2);
+    gtk_container_set_border_width (GTK_CONTAINER(wextract), 0);
 
-  box3 = gtk_hbox_new(FALSE, 5);
-  gtk_box_pack_start(GTK_BOX(box2),box3,TRUE,TRUE,0);
-  gtk_widget_show(box3);
+    box1 = gtk_vbox_new(FALSE,0);
+    gtk_container_add(GTK_CONTAINER(wextract),box1);
+    gtk_widget_show(box1);
 
-  frame = gtk_frame_new("Extraction Style");
-  gtk_box_pack_start(GTK_BOX(box3),frame,TRUE,TRUE,0);
-  gtk_widget_show(frame);
+    /* create upper box - Extract Style */
+    box2 = gtk_vbox_new(FALSE, 5);
+    gtk_box_pack_start(GTK_BOX(box1),box2,TRUE,TRUE,0);
+    gtk_container_set_border_width(GTK_CONTAINER(box2),5);
+    gtk_widget_show(box2);
 
-  box4 = gtk_vbox_new(FALSE,0);
-  gtk_container_add(GTK_CONTAINER(frame),box4);
-  gtk_container_set_border_width(GTK_CONTAINER(box4), 5);
-  gtk_widget_show(box4);
+    box3 = gtk_hbox_new(FALSE, 5);
+    gtk_box_pack_start(GTK_BOX(box2),box3,TRUE,TRUE,0);
+    gtk_widget_show(box3);
 
-  button = gtk_radio_button_new_with_label(NULL,"Normal");
-  gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
-  if (input->style == MDC_INPUT_NORM_STYLE)
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(button), TRUE);
-  gtk_widget_show(button);
-  sExtractSelection.NormStyle=button;
+    frame = gtk_frame_new("Extraction Style");
+    gtk_box_pack_start(GTK_BOX(box3),frame,TRUE,TRUE,0);
+    gtk_widget_show(frame);
 
-  group = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
-  button= gtk_radio_button_new_with_label(group,"Ecat");
-  gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
-  if (input->style == MDC_INPUT_ECAT_STYLE)
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(button), TRUE);
-  gtk_widget_show(button);
-  sExtractSelection.EcatStyle=button;
+    box4 = gtk_vbox_new(FALSE,0);
+    gtk_container_add(GTK_CONTAINER(frame),box4);
+    gtk_container_set_border_width(GTK_CONTAINER(box4), 5);
+    gtk_widget_show(box4);
 
-  /* create horizontal separator */
-  separator = gtk_hseparator_new();
-  gtk_box_pack_start(GTK_BOX(box1),separator,FALSE,FALSE,0);
-  gtk_widget_show(separator);
+    button = gtk_radio_button_new_with_label(NULL,"Normal");
+    gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
+    if (input->style == MDC_INPUT_NORM_STYLE)
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(button), TRUE);
+    gtk_widget_show(button);
+    sExtractSelection.NormStyle=button;
 
-  /* create bottom button box */
-  box2 = gtk_hbox_new(FALSE,0);
-  gtk_box_pack_start(GTK_BOX(box1),box2,TRUE,TRUE,2);
-  gtk_widget_show(box2);
+    group = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+    button= gtk_radio_button_new_with_label(group,"Ecat");
+    gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
+    if (input->style == MDC_INPUT_ECAT_STYLE)
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(button), TRUE);
+    gtk_widget_show(button);
+    sExtractSelection.EcatStyle=button;
+  
+    /* create horizontal separator */
+    separator = gtk_hseparator_new();
+    gtk_box_pack_start(GTK_BOX(box1),separator,FALSE,FALSE,0);
+    gtk_widget_show(separator);
 
-  button = gtk_button_new_with_label("Apply");
-  gtk_box_pack_start(GTK_BOX(box2),button,TRUE,TRUE,2);
-  gtk_signal_connect_object(GTK_OBJECT(button),"clicked",
-                     GTK_SIGNAL_FUNC(gtk_widget_hide), GTK_OBJECT(window));
-  gtk_signal_connect(GTK_OBJECT(button),"clicked",
+    /* create bottom button box */
+    box2 = gtk_hbox_new(FALSE,0);
+    gtk_box_pack_start(GTK_BOX(box1),box2,TRUE,TRUE,2);
+    gtk_widget_show(box2);
+
+    button = gtk_button_new_with_label("Apply");
+    gtk_box_pack_start(GTK_BOX(box2),button,TRUE,TRUE,2);
+    gtk_signal_connect_object(GTK_OBJECT(button),"clicked",
+                     GTK_SIGNAL_FUNC(gtk_widget_hide), GTK_OBJECT(wextract));
+    gtk_signal_connect(GTK_OBJECT(button),"clicked",
                      GTK_SIGNAL_FUNC(XMdcExtractStyleSelCallbackApply), NULL);
-  gtk_signal_connect_object(GTK_OBJECT(button), "clicked",
-                     GTK_SIGNAL_FUNC(gtk_widget_destroy), GTK_OBJECT(window));
-  gtk_widget_show(button);
+    gtk_widget_show(button);
 
-  button = gtk_button_new_with_label("Cancel");
-  gtk_box_pack_start(GTK_BOX(box2),button,TRUE,TRUE,2);
-  gtk_signal_connect(GTK_OBJECT(button),"clicked",
-                     GTK_SIGNAL_FUNC(XMdcExtractNotBussy), NULL);
-  gtk_signal_connect_object(GTK_OBJECT(button),"clicked",
-                     GTK_SIGNAL_FUNC(gtk_widget_destroy), GTK_OBJECT(window));
-  gtk_widget_show(button);
+    button = gtk_button_new_with_label("Cancel");
+    gtk_box_pack_start(GTK_BOX(box2),button,TRUE,TRUE,2);
+    gtk_signal_connect(GTK_OBJECT(button),"clicked",
+                       GTK_SIGNAL_FUNC(XMdcExtractNotBussy), NULL);
+    gtk_signal_connect_object(GTK_OBJECT(button),"clicked",
+            GTK_SIGNAL_FUNC(gtk_widget_hide),GTK_OBJECT(wextract));
+    gtk_widget_show(button);
 
-  XMdcShowWidget(window);
+  }else{
+    GtkWidget *b1, *b2;
+
+    gtk_widget_hide(wextract);
+
+    b1 = sExtractSelection.NormStyle;
+    b2 = sExtractSelection.EcatStyle;
+
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b1),FALSE);
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b2),FALSE);
+    switch (sExtractSelection.input->style) {
+      case MDC_INPUT_NORM_STYLE:
+          gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b1),TRUE); break;
+      case MDC_INPUT_ECAT_STYLE:
+          gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b2),TRUE); break;
+    }
+
+
+  }
+
+
+  XMdcShowWidget(wextract);
 
 }
 
