@@ -15,11 +15,11 @@
  *                XMdcAbout()             - Hello                          *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xfancy.c,v 1.1.1.1 2000/10/28 16:51:44 enlf Exp $
+/* $Id: xfancy.c,v 1.12 2004/01/05 00:27:08 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2000 by Erik Nolf
+   Copyright (C) 1997-2004 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -39,6 +39,18 @@
                               H E A D E R S
 ****************************************************************************/
 
+#include "m-depend.h"
+
+#include <stdio.h>
+#ifdef HAVE_STRING_H
+#include <string.h>
+#endif
+#ifdef HAVE_STRINGS_H
+#ifndef _WIN32
+#include <strings.h>
+#endif
+#endif
+
 #include "xmedcon.h"
 
 /****************************************************************************
@@ -79,9 +91,11 @@ void XMdcMakeMyColors(void)
 void XMdcMakeMyFonts(void)
 {
 #ifdef _WIN32
- sfixed=gdk_font_load("-*-courier new-medium-r-normal--*-90-*-*-*-*-iso8859-1");
+sfixed=gdk_font_load("-*-courier new-medium-r-normal--*-100-*-*-*-*-iso8859-1");
 #else
- sfixed=gdk_font_load("-misc-fixed-medium-r-normal--*-100-*-*-*-*-*-*");
+sfixed=gdk_font_load("-adobe-courier-medium-r-normal-*-*-100-*-*-*-*-*-*");
+ if (sfixed == NULL)
+sfixed=gdk_font_load("-misc-fixed-medium-r-normal--*-100-*-*-*-*-*-*");
 #endif
  if (sfixed == NULL) {
    XMdcDisplayErr("Couldn't get fixed font");
@@ -128,8 +142,9 @@ void XMdcAbout(GtkWidget *widget, gpointer data)
   gtk_container_add(GTK_CONTAINER(window),box1);
   gtk_widget_show(box1);
 
-  sprintf(mdcbufr," XMedCon %s \n\n",MdcGetLibShortVersion());
-  strcat(mdcbufr," Ghent University \n\n" \
+  sprintf(mdcbufr," %s %s \n\n",MDC_PRGR,MdcGetLibShortVersion());
+  strcat(mdcbufr," Ghent University \n" \
+                 " Hospital \n\n" \
                  " enlf@users.sourceforge.net\n" \
                  " http://xmedcon.sourceforge.net \n\n" \
                  " With special regards to You \n\n" \
