@@ -8,11 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xfiles.h,v 1.1.1.1 2000/10/28 16:51:45 enlf Exp $
+/* $Id: xfiles.h,v 1.6 2004/01/04 22:36:17 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2000 by Erik Nolf
+   Copyright (C) 1997-2004 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -37,7 +37,7 @@
 
 void XMdcDisplayFile(char *fname);
 void XMdcRereadFile(GtkWidget *widget, gpointer data);
-void XMdcFileClose(GtkWidget *widget, gpointer data);
+void XMdcCloseFile(GtkWidget *widget, gpointer data);
 int  XMdcNoFileOpened(void);
 #endif
 
