@@ -26,7 +26,7 @@
  *                XMdcRawPredefSelOpen()            - Raw Predef Load      * 
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xfilesel.c,v 1.26 2004/05/09 22:48:03 enlf Exp $
+/* $Id: xfilesel.c,v 1.27 2004/09/23 22:24:13 enlf Exp $
  */
 
 /*
@@ -554,11 +554,10 @@ void XMdcLutSelOpen(GtkWidget *widget, gpointer data)
     *       a default filename */
    if (XMEDCONLUT != NULL) {
      strncpy(xmdcstr,XMEDCONLUT,MDC_1KB_OFFSET); xmdcstr[MDC_1KB_OFFSET]='\0';
-#ifdef MDC_DOS
-     if (xmdcstr[strlen(xmdcstr)-1] != '\\' ) strcat(xmdcstr,"\\"); 
-#else
-     if (xmdcstr[strlen(xmdcstr)-1] != '/' ) strcat(xmdcstr,"/");
-#endif
+
+     if (xmdcstr[strlen(xmdcstr)-1] != MDC_PATH_DELIM_CHR)
+       strcat(xmdcstr,MDC_PATH_DELIM_STR);
+
      gtk_file_selection_set_filename(GTK_FILE_SELECTION(olutw),xmdcstr);
    }else{ 
      /* installation dir */
@@ -614,11 +613,10 @@ void XMdcRawPredefSelSave(GtkWidget *widget, gpointer data)
 
   if (XMEDCONRPI != NULL) {
     strncpy(xmdcstr,XMEDCONRPI,MDC_1KB_OFFSET); xmdcstr[MDC_1KB_OFFSET]='\0';
-#ifdef MDC_DOS
-    if (xmdcstr[strlen(xmdcstr)-1] != '\\' ) strcat(xmdcstr,"\\");
-#else
-    if (xmdcstr[strlen(xmdcstr)-1] != '/' ) strcat(xmdcstr,"/");
-#endif
+
+    if (xmdcstr[strlen(xmdcstr)-1] != MDC_PATH_DELIM_CHR)
+      strcat(xmdcstr,MDC_PATH_DELIM_STR);
+
     gtk_file_selection_set_filename(GTK_FILE_SELECTION(spredefw),xmdcstr);
 
     gtk_file_selection_complete(GTK_FILE_SELECTION(spredefw),"predef.rpi");
@@ -673,11 +671,10 @@ void XMdcRawPredefSelOpen(GtkWidget *widget, gpointer data)
 
    if (XMEDCONRPI != NULL) {
      strncpy(xmdcstr,XMEDCONRPI,MDC_1KB_OFFSET); xmdcstr[MDC_1KB_OFFSET]='\0';
-#ifdef MDC_DOS
-     if (xmdcstr[strlen(xmdcstr)-1] != '\\' ) strcat(xmdcstr,"\\");
-#else
-     if (xmdcstr[strlen(xmdcstr)-1] != '/' ) strcat(xmdcstr,"/");
-#endif
+
+     if (xmdcstr[strlen(xmdcstr)-1] != MDC_PATH_DELIM_CHR)
+       strcat(xmdcstr,MDC_PATH_DELIM_STR);
+
      gtk_file_selection_set_filename(GTK_FILE_SELECTION(opredefw),xmdcstr);
 
      gtk_file_selection_complete(GTK_FILE_SELECTION(opredefw),"*.rpi");
