@@ -8,11 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xicons.h,v 1.1.1.1 2000/10/28 16:51:42 enlf Exp $
+/* $Id: xicons.h,v 1.6 2004/01/04 22:36:17 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2000 by Erik Nolf
+   Copyright (C) 1997-2004 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -35,9 +35,9 @@
                               D E F I N E S 
 ****************************************************************************/
 
-extern char xmdc_brightness_icon[];
-extern char xmdc_contrast_icon[];
-extern char xmdc_gamma_icon[];
+extern const unsigned char xmdc_brightness_icon[];
+extern const unsigned char xmdc_contrast_icon[];
+extern const unsigned char xmdc_gamma_icon[];
 
 #endif
 
