@@ -16,7 +16,7 @@
  *                XMdcImagesView()             - Show the images (viewer)  *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: ximages.c,v 1.17 2004/05/09 22:48:04 enlf Exp $
+/* $Id: ximages.c,v 1.20 2004/10/21 23:48:39 enlf Exp $
  */
 
 /*
@@ -232,15 +232,15 @@ void XMdcBuildCurrentImages(void)
 
      my.realnumber[ri] = i;
 
-     my.im[ri] = XMdcBuildGdkPixbufFI(my.fi,i,sGbc.mod.vgbc,MDC_YES);
+     my.im[ri] = XMdcBuildGdkPixbufFI(my.fi,i,sGbc.mod.vgbc);
 
      if (my.image[ri] == NULL) {
 
        my.image[ri] = gtk_drawing_area_new();
 
        gtk_drawing_area_size(GTK_DRAWING_AREA(my.image[ri])
-           ,(gint)(XMdcResize(my.fi->mwidth)  + XMDC_IMAGE_BORDER)
-           ,(gint)(XMdcResize(my.fi->mheight) + XMDC_IMAGE_BORDER));
+           ,(gint)(XMdcScaleW(my.fi->mwidth)  + XMDC_IMAGE_BORDER)
+           ,(gint)(XMdcScaleH(my.fi->mheight) + XMDC_IMAGE_BORDER));
 
        gtk_widget_set_events (my.image[ri], GDK_EXPOSURE_MASK
 		                          | GDK_BUTTON_PRESS_MASK
@@ -303,6 +303,7 @@ void XMdcBuildCurrentImages(void)
 void XMdcDisplayImages(void)
 {
   XMdcProgressBar(MDC_PROGRESS_BEGIN,0.,"Preparing Viewer:");
+  XMdcSetImageScales();
   XMdcGetBoardDimensions();
   XMdcHandleBoardDimensions();
   XMdcBuildViewerWindow();
