@@ -11,7 +11,7 @@
  *                XMdcShowFileInfo()        - Display general file info    *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xinfo.c,v 1.47 2004/02/18 23:48:39 enlf Exp $
+/* $Id: xinfo.c,v 1.52 2004/10/17 21:52:13 enlf Exp $
  */
 
 /*
@@ -194,11 +194,9 @@ void XMdcImagesInfo(GtkWidget *widget, Uint32 nr)
                  ,f,MdcGetStrHHMMSS(f));
   gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
 
-  sprintf(xmdcstr,"\nModality & Position\n");
+  sprintf(xmdcstr,"\nPosition & Orientation\n");
   gtk_text_insert(GTK_TEXT(text),NULL,&Blue,NULL,xmdcstr,-1);
 
-  sprintf(xmdcstr,"image modality            : %s\n",id->image_mod);
-  gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
   sprintf(xmdcstr,"image position device     : %+e\\%+e\\%+e\n",
                                                     id->image_pos_dev[0],
                                                     id->image_pos_dev[1],
@@ -379,6 +377,9 @@ void XMdcShowFileInfo(GtkWidget *widget, gpointer data)
   v = (int)my.fi->iformat;
   sprintf(xmdcstr,"iformat     : %d (= %s)\n",v,FrmtString[v]);
   gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
+  sprintf(xmdcstr,"modality    : %d (= %s)\n",my.fi->modality
+                                          ,MdcGetStrModality(my.fi->modality));
+  gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
   v = (int)my.fi->rawconv;
   sprintf(xmdcstr,"rawconv     : %d (= %s)\n",v,MdcGetStrRawConv(v));
   gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
@@ -481,17 +482,23 @@ void XMdcShowFileInfo(GtkWidget *widget, gpointer data)
   gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
   sprintf(xmdcstr,"study_id         : %s\n",my.fi->study_id);
   gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
-  sprintf(xmdcstr,"study_date_day   : %d\n",my.fi->study_date_day);
+  sprintf(xmdcstr,"study_date_year  : %02d\n",my.fi->study_date_year);
   gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
   sprintf(xmdcstr,"study_date_month : %d\n",my.fi->study_date_month);
   gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
-  sprintf(xmdcstr,"study_date_year  : %d\n",my.fi->study_date_year);
+  sprintf(xmdcstr,"study_date_day   : %d\n",my.fi->study_date_day);
   gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
-  sprintf(xmdcstr,"study_time_hour  : %d\n",my.fi->study_time_hour);
+  sprintf(xmdcstr,"study_time_hour  : %02d\n",my.fi->study_time_hour);
   gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
-  sprintf(xmdcstr,"study_time_minute: %d\n",my.fi->study_time_minute);
+  sprintf(xmdcstr,"study_time_minute: %02d\n",my.fi->study_time_minute);
   gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
-  sprintf(xmdcstr,"study_time_second: %d\n",my.fi->study_time_second);
+  sprintf(xmdcstr,"study_time_second: %02d\n",my.fi->study_time_second);
+  gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
+  sprintf(xmdcstr,"dose_time_hour   : %02d\n",my.fi->dose_time_hour);
+  gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
+  sprintf(xmdcstr,"dose_time_minute : %02d\n",my.fi->dose_time_minute);
+  gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
+  sprintf(xmdcstr,"dose_time_second : %02d\n",my.fi->dose_time_second);
   gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
   sprintf(xmdcstr,"nr_series        : %hd\n",my.fi->nr_series);
   gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
@@ -530,7 +537,9 @@ void XMdcShowFileInfo(GtkWidget *widget, gpointer data)
   gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
   sprintf(xmdcstr,"isotope_code     : %s\n",my.fi->isotope_code);
   gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
-  sprintf(xmdcstr,"isotope_halflife : %+e [sec]\n",my.fi->isotope_halflife);
+  sprintf(xmdcstr,"isotope_halflife : %+e [sec] or %g [hrs]\n"
+                                          ,my.fi->isotope_halflife
+                                          ,my.fi->isotope_halflife/3600.);
   gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
   sprintf(xmdcstr,"injected_dose    : %+e [MBq]\n",my.fi->injected_dose);
   gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
