@@ -8,11 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xinfo.h,v 1.1.1.1 2000/10/28 16:51:50 enlf Exp $
+/* $Id: xinfo.h,v 1.6 2004/01/04 22:36:17 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2000 by Erik Nolf
+   Copyright (C) 1997-2004 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -36,7 +36,7 @@
 ****************************************************************************/
 
 void XMdcImagesInfo(GtkWidget *widget, Uint32 nr);
-void XMdcFileInfo(GtkWidget *widget, gpointer data);
+void XMdcShowFileInfo(GtkWidget *widget, gpointer data);
 
 #endif
 
