@@ -18,7 +18,7 @@
  *                XMdcLabelSel()                - Label selection          *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xlabels.c,v 1.16 2004/01/04 22:36:17 enlf Exp $
+/* $Id: xlabels.c,v 1.17 2004/10/21 22:06:38 enlf Exp $
  */
 
 /*
@@ -164,7 +164,7 @@ void XMdcPrintImageLabelIndex(GtkWidget *widget, Uint32 nr)
 	label=XMdcGetImageLabelIndex(nr);
 
 	gdk_draw_string(widget->window, sfixed, sLabelSelection.gc
-                        , 2, (gint)(XMdcResize(my.fi->mheight)-2), label);
+                        , 2, (gint)(XMdcScaleH(my.fi->mheight)-2), label);
 
 	gdk_colormap_free_colors(map,sLabelSelection.color,1);
 	gdk_gc_destroy(sLabelSelection.gc);
