@@ -29,7 +29,7 @@
  *                XMdcInitCineButtons()            - Init cine buttons     *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xoptions.c,v 1.61 2004/11/07 00:15:43 enlf Exp $
+/* $Id: xoptions.c,v 1.62 2005/02/01 23:23:47 enlf Exp $
  */
 
 /*
@@ -119,7 +119,7 @@ void XMdcOptionsMedconCallbackApply(GtkWidget *widget, gpointer data)
     MDC_WRITE_ENDIAN = MDC_BIG_ENDIAN;
   }
 
-  /* Image Flipping */
+  /* Flipping - Sorting*/
   if (GTK_TOGGLE_BUTTON(sOptionsMedCon.FlipHoriz)->active) {
     MDC_FLIP_HORIZONTAL = MDC_YES;
   }else{
@@ -131,7 +131,6 @@ void XMdcOptionsMedconCallbackApply(GtkWidget *widget, gpointer data)
     MDC_FLIP_VERTICAL = MDC_NO;
   }
 
-  /* Slices Sorting */
   if (GTK_TOGGLE_BUTTON(sOptionsMedCon.SortReverse)->active) {
     MDC_SORT_REVERSE = MDC_YES;
   }else{
@@ -211,6 +210,19 @@ void XMdcOptionsMedconCallbackApply(GtkWidget *widget, gpointer data)
     MDC_DITHER_COLOR=MDC_NO;
   }
 
+  /* Padding */
+  if (GTK_TOGGLE_BUTTON(sOptionsMedCon.PadAround)->active) {
+    MDC_PADDING_MODE = MDC_PAD_AROUND;
+  }
+
+  if (GTK_TOGGLE_BUTTON(sOptionsMedCon.PadTopLeft)->active) {
+    MDC_PADDING_MODE = MDC_PAD_TOP_LEFT;
+  }
+
+  if (GTK_TOGGLE_BUTTON(sOptionsMedCon.PadBottomRight)->active) {
+    MDC_PADDING_MODE = MDC_PAD_BOTTOM_RIGHT;
+  }
+
   /* File Names */
   if (GTK_TOGGLE_BUTTON(sOptionsMedCon.NameAlias)->active) {
     MDC_ALIAS_NAME=MDC_YES;
@@ -703,7 +715,7 @@ void XMdcOptionsMedconAddTabSlices(GtkWidget *notebook)
   gtk_widget_show(table);
 
   /* Image Flipping*/
-  frame = gtk_frame_new("Flip");
+  frame = gtk_frame_new("Flip - Sorting");
   gtk_container_set_border_width(GTK_CONTAINER(frame),5);
   gtk_table_attach_defaults(GTK_TABLE(table),frame,0,1,0,1);
   gtk_widget_show(frame);
@@ -727,17 +739,6 @@ void XMdcOptionsMedconAddTabSlices(GtkWidget *notebook)
   gtk_widget_show(button);
   sOptionsMedCon.FlipVert = button;
 
-  /* Slices Sorting */
-  frame = gtk_frame_new("Sorting");
-  gtk_container_set_border_width(GTK_CONTAINER(frame),5);
-  gtk_table_attach_defaults(GTK_TABLE(table),frame,1,2,0,1);
-  gtk_widget_show(frame);
-
-  box3 = gtk_vbox_new(FALSE,5);
-  gtk_container_add(GTK_CONTAINER(frame),box3);
-  gtk_container_set_border_width(GTK_CONTAINER(box3),5);
-  gtk_widget_show(box3);
-
   button =gtk_check_button_new_with_label("[r]  reverse slices");
   gtk_box_pack_start(GTK_BOX(box3),button,TRUE,TRUE,0);
   if (MDC_SORT_REVERSE == MDC_YES)
@@ -809,7 +810,7 @@ void XMdcOptionsMedconAddTabSlices(GtkWidget *notebook)
   /* Color */
   frame = gtk_frame_new("Color");
   gtk_container_set_border_width(GTK_CONTAINER(frame),5);
-  gtk_table_attach_defaults(GTK_TABLE(table),frame,1,2,1,2);
+  gtk_table_attach_defaults(GTK_TABLE(table),frame,1,2,0,1);
   gtk_widget_show(frame);
 
   box3 = gtk_vbox_new(FALSE,0);
@@ -839,6 +840,43 @@ void XMdcOptionsMedconAddTabSlices(GtkWidget *notebook)
   gtk_widget_show(button);
   sOptionsMedCon.ColorDither = button;
 
+  /* Padding */
+  frame = gtk_frame_new("Padding");
+  gtk_container_set_border_width(GTK_CONTAINER(frame),5);
+  gtk_table_attach_defaults(GTK_TABLE(table),frame,1,2,1,2);
+  gtk_widget_show(frame);
+
+  box3 = gtk_vbox_new(FALSE,0);
+  gtk_container_add(GTK_CONTAINER(frame),box3);
+  gtk_container_set_border_width(GTK_CONTAINER(box3),5);
+  gtk_widget_show(box3);
+
+  button =
+  gtk_radio_button_new_with_label(NULL,"[rw]  symmetrical around image");
+  gtk_box_pack_start(GTK_BOX(box3),button,TRUE,TRUE,0);
+  if (MDC_PADDING_MODE == MDC_PAD_AROUND)
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+  gtk_widget_show(button);
+  sOptionsMedCon.PadAround = button;
+
+  group = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+  button = 
+  gtk_radio_button_new_with_label(group,"[rw]  before first row and column");
+  gtk_box_pack_start(GTK_BOX(box3),button,TRUE,TRUE,0);
+  if (MDC_PADDING_MODE == MDC_PAD_TOP_LEFT)
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+  gtk_widget_show(button);
+  sOptionsMedCon.PadTopLeft = button;
+ 
+  group = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+  button =
+  gtk_radio_button_new_with_label(group,"[rw]  after last row and column");
+  gtk_box_pack_start(GTK_BOX(box3),button,TRUE,TRUE,0);
+  if (MDC_PADDING_MODE == MDC_PAD_BOTTOM_RIGHT)
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+  gtk_widget_show(button);
+  sOptionsMedCon.PadBottomRight = button;
+
 }
 
 void XMdcOptionsMedconAddTabFormats(GtkWidget *notebook)
@@ -1383,6 +1421,27 @@ void XMdcOptionsMedconSel(GtkWidget *widget, gpointer data)
      else
        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b1), FALSE);
 
+     /* Padding */
+     b1 = sOptionsMedCon.PadAround;
+     b2 = sOptionsMedCon.PadTopLeft;
+     b3 = sOptionsMedCon.PadBottomRight;
+
+     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b1), FALSE);
+     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b2), FALSE);
+     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b3), FALSE);
+
+     switch (MDC_PADDING_MODE) {
+       case MDC_PAD_AROUND:
+           gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b1), TRUE);
+           break;
+       case MDC_PAD_TOP_LEFT:
+           gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b2), TRUE);
+           break;
+       case MDC_PAD_BOTTOM_RIGHT:
+           gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b3), TRUE);
+           break;
+     }
+
      /* Output File Names */
      b1 = sOptionsMedCon.NameAlias;
      if (MDC_ALIAS_NAME == MDC_YES)
@@ -1495,7 +1554,7 @@ void XMdcOptionsMedconSel(GtkWidget *widget, gpointer data)
        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b2), TRUE);
      }
 
-     /* Image Flipping */
+     /* Flipping - Sorting */
      b1 = sOptionsMedCon.FlipHoriz;
      if (MDC_FLIP_HORIZONTAL == MDC_YES) 
        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b1), TRUE);
@@ -1508,7 +1567,6 @@ void XMdcOptionsMedconSel(GtkWidget *widget, gpointer data)
      else
        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b1), FALSE);
 
-     /* Slices Sorting */
      b1 = sOptionsMedCon.SortReverse;
      if (MDC_SORT_REVERSE== MDC_YES) 
        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b1), TRUE);
