@@ -9,19 +9,22 @@
  *                                                                         *
  * Note         : This code gets linked in (X)MedCon library with X-support*
  *                                                                         *
- * Functions    : XMdcUpdateDrawing()         - Update queued drawings     *
+ * Functions    : XMdcProgressBar()           - Run progress bar           *
+ *                XMdcUpdateDrawing()         - Update queued drawings     *
  *                XMdcUpdateProgressBar()     - Update progressbar         *
+ *                XMdcSetProgressBar()        - Set progressbar            *
+ *                XMdcIncrProgressBar()       - Increment progressbar      *
  *                XMdcCreateProgressBar()     - Create   progressbar       *
  *                XMdcBeginProgressBar()      - Begin of progressbar       *
  *                XMdcEndProgressBar()        - End   of progressbar       *
  *                XMdcHandleBarLabel()        - Handle its label           *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xprogbar.c,v 1.1.1.1 2000/10/28 16:51:55 enlf Exp $
+/* $Id: xprogbar.c,v 1.9 2004/05/09 22:48:04 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2000 by Erik Nolf
+   Copyright (C) 1997-2004 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -41,6 +44,18 @@
                               H E A D E R S
 ****************************************************************************/
 
+#include "m-depend.h"
+
+#include <stdio.h>
+#ifdef HAVE_STRING_H
+#include <string.h>
+#endif
+#ifdef HAVE_STRINGS_H
+#ifndef _WIN32
+#include <strings.h>
+#endif
+#endif
+
 #include "xmedcon.h"
 
 /****************************************************************************
@@ -51,28 +66,57 @@ static GtkWidget *pbarwindow=NULL;
 static GtkWidget *pbar=NULL;
 static GtkWidget *pbarlabel=NULL;
 static char barstring[26];
+static gfloat pvalue = 0.;
 
 Uint8  XMDC_DOBAR = MDC_NO;
-gfloat pvalue=0.;
 
 /****************************************************************************
                             F U N C T I O N S
 ****************************************************************************/
 
+void XMdcProgressBar(int type, float value, char *label)
+{
+  switch (type) {
+    case MDC_PROGRESS_BEGIN: XMdcBeginProgressBar(label);
+        break;
+    case MDC_PROGRESS_SET  : XMdcSetProgressBar(value);
+        break;
+    case MDC_PROGRESS_INCR : XMdcIncrProgressBar(value);
+        break;
+    case MDC_PROGRESS_END  : XMdcEndProgressBar();
+        break;
+  }
+
+}
+
 void XMdcUpdateDrawing(void)
 {
   while (gtk_events_pending())
        gtk_main_iteration();
 }
 
-gint XMdcUpdateProgressBar(gpointer data)
+void XMdcUpdateProgressBar(void)
 {
   if (XMDC_DOBAR) {
     if (pvalue > 1.0 ) pvalue = 1.0;
     gtk_progress_bar_update(GTK_PROGRESS_BAR(pbar), pvalue);
   }
   XMdcUpdateDrawing();
-  return(TRUE);
+}
+
+void XMdcSetProgressBar(float set)
+{
+  if (XMDC_DOBAR) pvalue = (gfloat)set;
+
+  XMdcUpdateProgressBar();
+
+}
+
+void XMdcIncrProgressBar(float incr)
+{
+  if (XMDC_DOBAR) pvalue += (gfloat)incr;
+
+  XMdcUpdateProgressBar();
 }
 
 void XMdcCreateProgressBar(char *labelstring)
@@ -109,7 +153,7 @@ void XMdcCreateProgressBar(char *labelstring)
 
      gtk_widget_show(pbarwindow);
 
-     XMdcUpdateProgressBar(NULL);
+     XMdcUpdateProgressBar();
 
 }
 
@@ -118,9 +162,9 @@ void XMdcBeginProgressBar(char *labelstring)
   if (XMDC_DOBAR) {
     pvalue = 0.0;
     gtk_label_set_text(GTK_LABEL(pbarlabel),XMdcHandleBarLabel(NULL));
-    XMdcUpdateProgressBar(NULL);
+    XMdcUpdateProgressBar();
     gtk_label_set_text(GTK_LABEL(pbarlabel),XMdcHandleBarLabel(labelstring));
-    XMdcUpdateProgressBar(NULL);
+    XMdcUpdateProgressBar();
   }else{
     XMdcCreateProgressBar(labelstring); XMdcMainWidgetsInsensitive();
   }
