@@ -8,20 +8,23 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * Functions    : XMdcReadFile()                  - Read selected file     *
- *                XMdcInteractiveReadFinish()     - Finish interactive read*
- *                XMdcInteractiveReadBegin()      - Begin  interactive read*
+ *                XMdcRawReadFinish()             - Finish raw read        *
+ *                XMdcRawReadInteractive()        - Interactive raw read   *
+ *                XMdcRawReadPredef()             - Read predefined raw    *
+ *                XMdcRawReadCancel()             - Raw read break up      *
  *                XMdcGetImageInfoPixelType()     - Get specified pixeltype*
  *                XMdcGetImageInfoCallbackApply() - Img Info Apply callback*
+ *                XMdcGetImageInfoCallbackCancel()- Img Info Cancel        *
  *                XMdcGetImageInfo()              - Ask Img Info           *
  *                XMdcGetHeaderInfoCallbackApply()- Hdr Info Cont callback *
  *                XMdcGetHeaderInfo()             - Ask Hdr Info           *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xreader.c,v 1.1.1.1 2000/10/28 16:51:58 enlf Exp $
+/* $Id: xreader.c,v 1.20 2004/05/09 22:48:04 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2000 by Erik Nolf
+   Copyright (C) 1997-2004 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -41,6 +44,21 @@
                               H E A D E R S
 ****************************************************************************/
 
+#include "m-depend.h"
+
+#include <stdio.h>
+#ifdef HAVE_STDLIB_H
+#include <stdlib.h>
+#endif
+#ifdef HAVE_STRING_H
+#include <string.h>
+#endif
+#ifdef HAVE_STRINGS_H
+#ifndef _WIN32
+#include <strings.h>
+#endif
+#endif
+
 #include "xmedcon.h"
 
 
@@ -59,15 +77,21 @@ static MdcRawPrevInputStruct *prev = &mdcrawprevinput;
 int XMdcReadFile(char *fname)
 {
 
-  if (MdcOpenFile(my.fi,fname) != MDC_OK) return(MDC_BAD_OPEN);
+  if (MdcOpenFile(my.fi,fname) != MDC_OK) {
+    XMdcDisplayErr("Failure opening file");
+    return(MDC_BAD_OPEN);
+  }
 
-  if (MdcReadFile(my.fi,0) != MDC_OK) return(MDC_BAD_READ);
+  if (MdcReadFile(my.fi,0,NULL) != MDC_OK) {
+    XMdcDisplayErr("Failure reading file");
+    return(MDC_BAD_READ);
+  }
 
   return(MDC_OK);
 
 }
 
-void XMdcInteractiveReadFinish(void)
+void XMdcRawReadFinish(guint otype)
 {
   char *msg;
 
@@ -75,7 +99,7 @@ void XMdcInteractiveReadFinish(void)
   if ( (my.fi->ifp = fopen(my.fi->ipath,"rb")) == NULL) {
     MdcSplitPath(my.fi->ipath,my.fi->idir,my.fi->ifname);
     sprintf(mdcbufr,"Couldn't open <%s>",my.fi->ifname);
-    XMdcGetImageInfoCallbackCancel();
+    XMdcRawReadCancel(otype);
     XMdcDisplayErr("Reading: %s",mdcbufr);
     return;
   }else{
@@ -86,9 +110,9 @@ void XMdcInteractiveReadFinish(void)
   msg = MdcReadRAW(my.fi);
   if (msg != NULL) {
     if (strstr(msg,"Truncated image") == NULL) {
-      XMdcGetImageInfoCallbackCancel();
+      XMdcRawReadCancel(otype);
       XMdcDisplayErr("Reading: %s",msg);
-      XMdcEndProgressBar();
+      XMdcProgressBar(MDC_PROGRESS_END,0.,NULL);
       return;
     }else{
       XMdcDisplayWarn(msg);
@@ -109,25 +133,24 @@ void XMdcInteractiveReadFinish(void)
   MdcGetColorMap(sColormapSelection.CurMap,my.fi->palette);
   msg = MdcImagesPixelFiddle(my.fi);
   if (msg != NULL) {
-    XMdcGetImageInfoCallbackCancel();
+    XMdcRawReadCancel(otype);
     XMdcDisplayErr("Reading: %s",msg);
-    XMdcEndProgressBar();
+    XMdcProgressBar(MDC_PROGRESS_END,0.,NULL);
     return;
   } 
   
   XMDC_FILE_OPEN = MDC_YES; XMDC_FILE_TYPE = XMDC_RAW;
   XMdcViewerEnableAutoShrink();
   XMdcDisplayImages();
-  XMdcViewerShow();
-  XMdcViewerDisableAutoShrink();
 
-  XMdcEndProgressBar();
+  XMdcProgressBar(MDC_PROGRESS_END,0.,NULL);
 
-  gtk_widget_destroy(sRawReadSelection.HdrInfoWindow);
+  if (otype == XMDC_RAW)
+    gtk_widget_destroy(sRawReadSelection.HdrInfoWindow);
 
 } 
 
-void XMdcInteractiveReadBegin(GtkWidget *fs)
+void XMdcRawReadInteractive(GtkWidget *fs)
 {
   char *fname;
 
@@ -146,35 +169,109 @@ void XMdcInteractiveReadBegin(GtkWidget *fs)
   XMdcGetHeaderInfo();
 }
 
+void XMdcRawReadPredef(GtkWidget *fs)
+{
+  IMG_DATA *id;
+  Uint32 i;
+  char *fname;
+
+  XMdcMainWidgetsInsensitive();
+
+  gtk_widget_hide(fs);
+
+  XMdcViewerHide();
+
+  XMdcFileReset();
+
+  fname = gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs));
+
+  MdcInitFI(my.fi, fname);
+
+  /* fill in input struct with predef values */
+  input->gen_offset = prev->GENHDR;
+  input->img_offset = prev->IMGHDR;
+  input->DIFF       = prev->DIFF;
+  input->REPEAT     = prev->HDRREP;
+
+  /* now fill structs with predef values */
+  if (!MdcGetStructID(my.fi,prev->NRIMGS)) {
+    XMdcDisplayErr("Bad malloc IMG_DATA structs");
+    return;
+  }
+
+  /* actually unused here, only identical images suppported */
+  input->abs_offset=(Uint32 *)malloc(my.fi->number*sizeof(Uint32));
+  if (input->abs_offset == NULL) {
+    MdcCleanUpFI(my.fi);
+    XMdcDisplayErr("Couldn't malloc abs_offset[]");
+    return;
+  }else{
+    memset(input->abs_offset,0,my.fi->number*sizeof(Uint32));
+  }
+
+  for (i=0; i<my.fi->number; i++) {
+     id = &my.fi->image[i];
+     id->width = prev->XDIM;
+     id->height= prev->YDIM;
+     id->type  = prev->PTYPE;
+     id->bits  = MdcType2Bits(id->type);
+  }
+
+  if (prev->PSWAP == MDC_YES) {
+    MDC_FILE_ENDIAN = !MDC_HOST_ENDIAN;
+  }else{
+    MDC_FILE_ENDIAN = MDC_HOST_ENDIAN;
+  }
+
+  my.fi->endian = MDC_FILE_ENDIAN; 
+  my.fi->dim[0] = 3;
+  my.fi->dim[3] = my.fi->number;
+  my.fi->diff_type = MDC_NO;
+  my.fi->diff_size = MDC_NO;
+
+  XMdcRawReadFinish(XMDC_PREDEF);
+
+}
+
+void XMdcRawReadCancel(guint otype)
+{
+  MdcFree(input->abs_offset);
+  MdcCleanUpFI(my.fi);
+  if (otype == XMDC_RAW)
+    gtk_widget_destroy(sRawReadSelection.HdrInfoWindow);
+}
+
 Int16 XMdcGetImageInfoPixelType(void)
 {
-  MdcDebugPrint("DEBUG: type = ");
+  MdcDebugPrint("pixel type: ");
   if (GTK_TOGGLE_BUTTON(raw->typeBIT1)->active) {
-    MdcDebugPrint("BIT1\n"); return(BIT1);
+    MdcDebugPrint("\tBIT1"); return(BIT1);
   }else if (GTK_TOGGLE_BUTTON(raw->typeASCII)->active) {
-    MdcDebugPrint("ASCII\n"); return(ASCII);
+    MdcDebugPrint("\tASCII"); return(ASCII);
   }else if (GTK_TOGGLE_BUTTON(raw->typeBIT8_S)->active) {
-    MdcDebugPrint("BIT8_S\n"); return(BIT8_S);
+    MdcDebugPrint("\tBIT8_S"); return(BIT8_S);
   }else if (GTK_TOGGLE_BUTTON(raw->typeBIT8_U)->active) {
-    MdcDebugPrint("BIT8_U\n"); return(BIT8_U);
+    MdcDebugPrint("\tBIT8_U"); return(BIT8_U);
   }else if (GTK_TOGGLE_BUTTON(raw->typeBIT16_S)->active) {
-    MdcDebugPrint("BIT16_S\n"); return(BIT16_S);
+    MdcDebugPrint("\tBIT16_S"); return(BIT16_S);
   }else if (GTK_TOGGLE_BUTTON(raw->typeBIT16_U)->active) {
-    MdcDebugPrint("BIT16_U\n"); return(BIT16_U);
+    MdcDebugPrint("\tBIT16_U"); return(BIT16_U);
   }else if (GTK_TOGGLE_BUTTON(raw->typeBIT32_S)->active) {
-    MdcDebugPrint("BIT32_S\n"); return(BIT32_S);
+    MdcDebugPrint("\tBIT32_S"); return(BIT32_S);
   }else if (GTK_TOGGLE_BUTTON(raw->typeBIT32_U)->active) {
-    MdcDebugPrint("BIT32_U\n"); return(BIT32_U);
+    MdcDebugPrint("\tBT32_U"); return(BIT32_U);
 #ifdef HAVE_8BYTE_INT
   }else if (GTK_TOGGLE_BUTTON(raw->typeBIT64_S)->active) {
-    MdcDebugPrint("BIT64_S\n"); return(BIT64_S);
+    MdcDebugPrint("\tBIT64_S"); return(BIT64_S);
   }else if (GTK_TOGGLE_BUTTON(raw->typeBIT64_U)->active) {
-    MdcDebugPrint("BIT64_U\n"); return(BIT64_U);
+    MdcDebugPrint("\tBIT64_U"); return(BIT64_U);
 #endif 
   }else if (GTK_TOGGLE_BUTTON(raw->typeFLT32)->active) {
-    MdcDebugPrint("FLT32\n"); return(FLT32);
+    MdcDebugPrint("\tFLT32"); return(FLT32);
   }else if (GTK_TOGGLE_BUTTON(raw->typeFLT64)->active) {
-    MdcDebugPrint("FLT64\n"); return(FLT64);
+    MdcDebugPrint("\tFLT64"); return(FLT64);
+  }else if (GTK_TOGGLE_BUTTON(raw->typeCOLRGB)->active) {
+    MdcDebugPrint("\tRGB"); return(COLRGB);
   }else{
     XMdcDisplayFatalErr(MDC_BAD_CODE,"Unknown pixeltype encountered");
   }
@@ -192,26 +289,26 @@ void XMdcGetImageInfoCallbackApply(void)
 
   imgnr = raw->ImgCounter - 1;
 
-  MdcDebugPrint("DEBUG: image nr    = %u\n",imgnr);
+  MdcDebugPrint("image nr    = %u",imgnr);
   entry  = gtk_entry_get_text(GTK_ENTRY(raw->AbsOffset));
   offset = (Uint32) atol(entry); prev->ABSHDR = offset;
-  MdcDebugPrint("DEBUG: abs offset  = %u\n",offset);
+  MdcDebugPrint("abs offset  = %u",offset);
   entry = gtk_entry_get_text(GTK_ENTRY(raw->ImgWidth));
   width = (Uint32) atol(entry); prev->XDIM = width;
-  MdcDebugPrint("DEBUG: image width = %u\n",width);
+  MdcDebugPrint("image width = %u",width);
   entry = gtk_entry_get_text(GTK_ENTRY(raw->ImgHeight));
   height= (Uint32) atol(entry); prev->YDIM = height;
-  MdcDebugPrint("DEBUG: image height= %u\n",height);
+  MdcDebugPrint("image height= %u",height);
   type  = XMdcGetImageInfoPixelType(); prev->PTYPE = type;
 
   if (width == 0) {
     XMdcDisplayErr("No width specified");
-    XMdcGetImageInfoCallbackCancel();
+    XMdcRawReadCancel(XMDC_RAW);
     return;
   }
   if (height == 0) {
     XMdcDisplayErr("No height specified");
-    XMdcGetImageInfoCallbackCancel();
+    XMdcRawReadCancel(XMDC_RAW);
     return;
   }
 
@@ -244,16 +341,14 @@ void XMdcGetImageInfoCallbackApply(void)
     my.fi->endian = MDC_FILE_ENDIAN;
     my.fi->dim[0] = 3;
     my.fi->dim[3] = my.fi->number;
-    XMdcInteractiveReadFinish();
+    XMdcRawReadFinish(XMDC_RAW);
   }
 
 }
 
 void XMdcGetImageInfoCallbackCancel(void)
 {
-  MdcFree(input->abs_offset);
-  gtk_widget_destroy(sRawReadSelection.HdrInfoWindow);
-  MdcCleanUpFI(my.fi);
+  XMdcRawReadCancel(XMDC_RAW);
 }
 
 void XMdcGetImageInfo(void)
@@ -374,7 +469,7 @@ void XMdcGetImageInfo(void)
   gtk_container_set_border_width(GTK_CONTAINER(box2),5);
   gtk_widget_show(box2);
 
-  table = gtk_table_new(6,2,FALSE);
+  table = gtk_table_new(7,2,FALSE);
   gtk_container_add(GTK_CONTAINER(box2),table);
   gtk_widget_show(table);
 
@@ -475,6 +570,15 @@ void XMdcGetImageInfo(void)
   }
   gtk_widget_show(button);
   raw->typeFLT64=button;
+  group = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+  button = gtk_radio_button_new_with_label(group,"RGB");
+  gtk_table_attach_defaults(GTK_TABLE(table),button,0,1,6,7);
+  if (prev->PTYPE == COLRGB) {
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button),TRUE);
+  }
+  gtk_widget_show(button);
+  raw->typeCOLRGB=button;
+
 
   separator = gtk_hseparator_new();
   gtk_box_pack_start (GTK_BOX (box1), separator, FALSE, FALSE, 0);
@@ -516,62 +620,65 @@ void XMdcGetImageInfo(void)
 /* Apply = Continue */
 void XMdcGetHeaderInfoCallbackApply(void)
 {
+  Uint32 number;
   char *entry = NULL;
 
   /* total number of images */
   entry = gtk_entry_get_text(GTK_ENTRY(raw->NrImages));
-  my.fi->number = (Uint32) atol(entry); prev->NRIMGS = my.fi->number;
-  MdcDebugPrint("DEBUG: total images = %u\n",my.fi->number);
-  if (my.fi->number == 0) {
+  number = (Uint32) atol(entry); prev->NRIMGS = number;
+  MdcDebugPrint("total images = %u",number);
+  if (number == 0) {
+    XMdcRawReadCancel(XMDC_RAW);
     XMdcDisplayErr("No images specified");
     return;
   }
-  if (!MdcGetStructID(my.fi)) {
+  if (!MdcGetStructID(my.fi,number)) {
+    XMdcRawReadCancel(XMDC_RAW);
     XMdcDisplayErr("Bad alloc IMG_DATA structs");
     return;
   }
   /* general header offset */
   entry = gtk_entry_get_text(GTK_ENTRY(raw->GenOffset));
   input->gen_offset = (Uint32) atol(entry); prev->GENHDR=input->gen_offset;
-  MdcDebugPrint("DEBUG: general header offset = %u\n",input->gen_offset);
+  MdcDebugPrint("general header offset = %u",input->gen_offset);
 
   /* image   header offset */
   entry = gtk_entry_get_text(GTK_ENTRY(raw->ImgOffset));
   input->img_offset = (Uint32) atol(entry); prev->IMGHDR=input->img_offset;
-  MdcDebugPrint("DEBUG: image  header offset = %u\n",input->gen_offset);
+  MdcDebugPrint("image  header offset = %u",input->gen_offset);
 
   /* image   header repeated */
   if (GTK_TOGGLE_BUTTON(raw->IhdrRep)->active) {
     input->REPEAT = MDC_YES; prev->HDRREP = MDC_YES;
-    MdcDebugPrint("DEBUG: image  header repeated = Yes\n");
+    MdcDebugPrint("image  header repeated = yes");
   }else{
     input->REPEAT = MDC_NO;  prev->HDRREP = MDC_NO;
-    MdcDebugPrint("DEBUG: image  header repeated = No\n");
+    MdcDebugPrint("image  header repeated = no");
   } 
 
   /* swap pixel bytes */
   if (GTK_TOGGLE_BUTTON(raw->PixSwap)->active) {
     MDC_FILE_ENDIAN = !MDC_HOST_ENDIAN; prev->PSWAP = MDC_YES;
-    MdcDebugPrint("DEBUG: swap pixels = Yes\n");
+    MdcDebugPrint("swap pixels = yes");
   }else{
     MDC_FILE_ENDIAN = MDC_HOST_ENDIAN;  prev->PSWAP = MDC_NO;
-    MdcDebugPrint("DEBUG: swap pixels = No\n");
+    MdcDebugPrint("swap pixels = no");
   }
 
   /* identical images */
   if (GTK_TOGGLE_BUTTON(raw->ImgSame)->active) {
     input->DIFF = MDC_NO; prev->DIFF = MDC_NO;
-    MdcDebugPrint("DEBUG: identical images = Yes\n");
+    MdcDebugPrint("identical images = yes");
     raw->ImgCounter = my.fi->number;
   }else{
     input->DIFF = MDC_YES; prev->DIFF = MDC_YES;
-    MdcDebugPrint("DEBUG: identical images = No\n");
+    MdcDebugPrint("identical images = no");
     raw->ImgCounter = 1;
   }
 
   input->abs_offset=(Uint32 *)malloc(my.fi->number*sizeof(Uint32));
   if (input->abs_offset == NULL) {
-    XMdcGetImageInfoCallbackCancel();
+    XMdcRawReadCancel(XMDC_RAW);
     XMdcDisplayErr("Couldn't malloc abs_offset[]");
     return;
   }else{
@@ -705,8 +812,8 @@ void XMdcGetHeaderInfo(void)
 
   button = gtk_button_new_with_label("Continue");
   gtk_box_pack_start(GTK_BOX(box2),button,TRUE,TRUE,2);
-  gtk_signal_connect_object(GTK_OBJECT(button), "clicked",
-                    GTK_SIGNAL_FUNC(XMdcGetHeaderInfoCallbackApply),NULL);
+  gtk_signal_connect(GTK_OBJECT(button), "clicked",
+                     GTK_SIGNAL_FUNC(XMdcGetHeaderInfoCallbackApply),NULL);
   gtk_signal_connect_object(GTK_OBJECT(button), "clicked",
                     GTK_SIGNAL_FUNC(gtk_widget_hide),
                     GTK_OBJECT(window));
@@ -721,5 +828,5 @@ void XMdcGetHeaderInfo(void)
 
   XMdcShowWidget(window);
 
-} 
+}
 
