@@ -8,11 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xreader.h,v 1.1.1.1 2000/10/28 16:51:58 enlf Exp $
+/* $Id: xreader.h,v 1.8 2004/01/04 22:36:17 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2000 by Erik Nolf
+   Copyright (C) 1997-2004 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -36,8 +36,10 @@
 ****************************************************************************/
 
 int XMdcReadFile(char *fname);
-void XMdcInteractiveReadFinish(void);
-void XMdcInteractiveReadBegin(GtkWidget *fs);
+void XMdcRawReadFinish(guint otype);
+void XMdcRawReadInteractive(GtkWidget *fs);
+void XMdcRawReadPredef(GtkWidget *fs);
+void XMdcRawReadCancel(guint otype);
 Int16 XMdcGetImageInfoPixelType(void);
 void XMdcGetImageInfoCallbackApply(void);
 void XMdcGetImageInfoCallbackCancel(void);
