@@ -12,11 +12,11 @@
  *                XMdcRenderingSel()              - Rendering selection    *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xrender.c,v 1.1.1.1 2000/10/28 16:51:59 enlf Exp $
+/* $Id: xrender.c,v 1.8 2004/01/04 22:36:17 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2000 by Erik Nolf
+   Copyright (C) 1997-2004 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -36,6 +36,8 @@
                               H E A D E R S
 ****************************************************************************/
 
+#include <stdio.h>
+
 #include "xmedcon.h"
 
 /****************************************************************************
@@ -66,32 +68,32 @@ void XMdcRenderingSelCallbackApply(GtkWidget *widget, gpointer data)
   GdkRgbDither  dither = sRenderSelection.Dither;
   GdkInterpType interp = sRenderSelection.Interp;
 
-  MdcDebugPrint("DEBUG: Dither type: ");
+  MdcDebugPrint("dither type: ");
   if (GTK_TOGGLE_BUTTON(sRenderSelection.DitherNone)->active)         {
-    dither = GDK_RGB_DITHER_NONE;   MdcDebugPrint("None\n");
+    dither = GDK_RGB_DITHER_NONE;   MdcDebugPrint("\tnone");
   }else if (GTK_TOGGLE_BUTTON(sRenderSelection.DitherNormal)->active) {
-    dither = GDK_RGB_DITHER_NORMAL; MdcDebugPrint("Normal\n"); 
+    dither = GDK_RGB_DITHER_NORMAL; MdcDebugPrint("\tnormal"); 
   }else if (GTK_TOGGLE_BUTTON(sRenderSelection.DitherMax)->active)    {
-    dither = GDK_RGB_DITHER_MAX;    MdcDebugPrint("Max\n");
+    dither = GDK_RGB_DITHER_MAX;    MdcDebugPrint("\tmax");
   }
 
-  MdcDebugPrint("DEBUG: Interpolation Type: ");
+  MdcDebugPrint("interpolation type: ");
 
   if (GTK_TOGGLE_BUTTON(sRenderSelection.InterpNearest)->active)        {
-    interp = GDK_INTERP_NEAREST;  MdcDebugPrint("Nearest\n");
+    interp = GDK_INTERP_NEAREST;  MdcDebugPrint("\tnearest");
   }else if (GTK_TOGGLE_BUTTON(sRenderSelection.InterpTiles)->active)    {
-    interp = GDK_INTERP_TILES;    MdcDebugPrint("Tiles\n");
+    interp = GDK_INTERP_TILES;    MdcDebugPrint("\ttiles");
   }else if (GTK_TOGGLE_BUTTON(sRenderSelection.InterpBilinear)->active) {
-    interp = GDK_INTERP_BILINEAR; MdcDebugPrint("Bilinear\n");
+    interp = GDK_INTERP_BILINEAR; MdcDebugPrint("\tbilinear");
   }else if (GTK_TOGGLE_BUTTON(sRenderSelection.InterpHyper)->active)    {
-    interp = GDK_INTERP_HYPER;    MdcDebugPrint("Hyper\n");
+    interp = GDK_INTERP_HYPER;    MdcDebugPrint("\thyper");
   }
 
   if (sRenderSelection.Dither != dither || 
       sRenderSelection.Interp != interp) {
     sRenderSelection.Dither = dither; 
     sRenderSelection.Interp = interp;
-    if (XMDC_FILE_OPEN) XMdcApplyNewRendering();
+    if (XMDC_FILE_OPEN == MDC_YES) XMdcApplyNewRendering();
   } 
 
 }
