@@ -13,7 +13,7 @@
  *                XMdcColorMapReset()  - Reset to a new colormap           *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xreset.c,v 1.9 2004/01/04 22:36:17 enlf Exp $
+/* $Id: xreset.c,v 1.11 2004/10/21 23:02:58 enlf Exp $
  */
 
 /*
@@ -54,6 +54,8 @@ void XMdcStructsReset(void)
   my.viewbox = NULL;
   my.cmap = NULL;
   my.curpage = 0; my.prevpage = 0;
+  my.scale_width = 1.; my.scale_height = 1.;
+  my.RESIZE = MDC_YES;
 }
 
 void XMdcViewerReset(void)
