@@ -13,7 +13,7 @@
  *                XMdcResizeNeeded()           - Resize when image>screen? *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xresize.c,v 1.12 2004/05/09 22:48:04 enlf Exp $
+/* $Id: xresize.c,v 1.16 2004/10/27 22:16:16 enlf Exp $
  */
 
 /*
@@ -55,6 +55,8 @@ Uint32 XMdcResize(Uint32 dim)
 {
   Uint32 newdim = dim;    
 
+  if (my.RESIZE == MDC_NO) return(newdim);
+
   /* note #1: when divide, integer round up => no pixel loss */
   /* note #2: defined division constants are negative        */
 
@@ -62,7 +64,10 @@ Uint32 XMdcResize(Uint32 dim)
    case XMDC_RESIZE_ORIGINAL: 
        break;
    case XMDC_RESIZE_FOURTH  :
-       newdim -= (XMDC_RESIZE_FOURTH + 1); newdim /= -XMDC_RESIZE_FOURTH; 
+       newdim -= (XMDC_RESIZE_FOURTH + 1); newdim /= -XMDC_RESIZE_FOURTH;
+       break;
+   case XMDC_RESIZE_THIRD   :
+       newdim -= (XMDC_RESIZE_THIRD  + 1); newdim /= -XMDC_RESIZE_THIRD;
        break;
    case XMDC_RESIZE_HALF    : 
        newdim -= (XMDC_RESIZE_HALF   + 1); newdim /= -XMDC_RESIZE_HALF;   
@@ -70,6 +75,8 @@ Uint32 XMdcResize(Uint32 dim)
    case XMDC_RESIZE_DOUBLE  : 
        newdim *=  XMDC_RESIZE_DOUBLE;
        break;
+   case XMDC_RESIZE_TRIPLE  :
+       newdim *=  XMDC_RESIZE_TRIPLE; 
   }
 
   return(newdim);
@@ -81,13 +88,17 @@ void XMdcResizeSelCallbackApply(GtkWidget *widget, gpointer data)
 
   MdcDebugPrint("initial resize: ");
   if (GTK_TOGGLE_BUTTON(sResizeSelection.Fourth)->active)         {
-    MdcDebugPrint("\t1:4"); type = XMDC_RESIZE_FOURTH;       
-  }else if (GTK_TOGGLE_BUTTON(sResizeSelection.Half)->active)           {
+    MdcDebugPrint("\t1:4"); type = XMDC_RESIZE_FOURTH;
+  }else if (GTK_TOGGLE_BUTTON(sResizeSelection.Third)->active)    {
+    MdcDebugPrint("\t1:3"); type = XMDC_RESIZE_THIRD;
+  }else if (GTK_TOGGLE_BUTTON(sResizeSelection.Half)->active)     {
     MdcDebugPrint("\t1:2"); type = XMDC_RESIZE_HALF;
   }else if (GTK_TOGGLE_BUTTON(sResizeSelection.Original)->active) {
     MdcDebugPrint("\t1:1"); type = XMDC_RESIZE_ORIGINAL;
   }else if (GTK_TOGGLE_BUTTON(sResizeSelection.Double)->active)   {
     MdcDebugPrint("\t2:1"); type = XMDC_RESIZE_DOUBLE;
+  }else if (GTK_TOGGLE_BUTTON(sResizeSelection.Triple)->active)   {
+    MdcDebugPrint("\t3:1"); type = XMDC_RESIZE_TRIPLE;
   }
 
   if (type != sResizeSelection.CurType) {
@@ -157,6 +168,14 @@ void XMdcResizeSel(void)
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(button), TRUE);
     gtk_widget_show(button);
     sResizeSelection.Fourth = button;
+  
+    group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
+    button = gtk_radio_button_new_with_label(group, "[1:3] third");
+    gtk_box_pack_start(GTK_BOX(box4), button, TRUE, TRUE, 0);
+    if (sResizeSelection.CurType == XMDC_RESIZE_THIRD)
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(button), TRUE);
+    gtk_widget_show(button);
+    sResizeSelection.Third = button;
 
     group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
     button = gtk_radio_button_new_with_label(group, "[1:2] half");
@@ -182,6 +201,14 @@ void XMdcResizeSel(void)
     gtk_widget_show(button);
     sResizeSelection.Double = button;
 
+    group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
+    button = gtk_radio_button_new_with_label(group, "[3:1] triple");
+    gtk_box_pack_start (GTK_BOX(box4), button, TRUE, TRUE, 0);
+    if (sResizeSelection.CurType == XMDC_RESIZE_TRIPLE)
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(button), TRUE);
+    gtk_widget_show(button);
+    sResizeSelection.Triple = button;
+
     /* create horizontal separator */
     separator = gtk_hseparator_new ();
     gtk_box_pack_start (GTK_BOX (box1), separator, FALSE, FALSE, 0);
@@ -210,27 +237,35 @@ void XMdcResizeSel(void)
  
   }else{
     /* set buttons to appropriate state */
-    GtkWidget *b1, *b2, *b3, *b4;
+    GtkWidget *b1, *b2, *b3, *b4, *b5, *b6;
    
     gtk_widget_hide(wresize);
  
     b1 = sResizeSelection.Fourth;
-    b2 = sResizeSelection.Half;
-    b3 = sResizeSelection.Original;
-    b4 = sResizeSelection.Double;
+    b2 = sResizeSelection.Third;
+    b3 = sResizeSelection.Half;
+    b4 = sResizeSelection.Original;
+    b5 = sResizeSelection.Double;
+    b6 = sResizeSelection.Triple;
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b1),FALSE);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b2),FALSE);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b3),FALSE);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b4),FALSE);
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b5),FALSE);
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b6),FALSE);
     switch (sResizeSelection.CurType) {
       case XMDC_RESIZE_FOURTH  :
           gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b1),TRUE); break;
-      case XMDC_RESIZE_HALF    :
+      case XMDC_RESIZE_THIRD   :
           gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b2),TRUE); break;
-      case XMDC_RESIZE_ORIGINAL:
+      case XMDC_RESIZE_HALF    :
           gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b3),TRUE); break;
-      case XMDC_RESIZE_DOUBLE  :
+      case XMDC_RESIZE_ORIGINAL:
           gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b4),TRUE); break;
+      case XMDC_RESIZE_DOUBLE  :
+          gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b5),TRUE); break;
+      case XMDC_RESIZE_TRIPLE  :
+          gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(b6),TRUE); break;
     }
 
   } 
@@ -240,8 +275,8 @@ void XMdcResizeSel(void)
 
 void XMdcResizeNeeded(void)
 {
-  if (XMdcResize(my.fi->mwidth)  >= (gdk_screen_width()  - XMDC_FREE_BORDER) || 
-      XMdcResize(my.fi->mheight) >= (gdk_screen_height() - XMDC_FREE_BORDER)) {
+  if (XMdcScaleW(my.fi->mwidth)  >= (gdk_screen_width()  - XMDC_FREE_BORDER) || 
+      XMdcScaleH(my.fi->mheight) >= (gdk_screen_height() - XMDC_FREE_BORDER)) {
 
     XMdcAskYesNo( GTK_SIGNAL_FUNC(XMdcResizeSel),
                   GTK_SIGNAL_FUNC(XMdcViewerShow),
@@ -261,4 +296,5 @@ void XMdcResizeNeeded(void)
 
 
 
+
    
