@@ -23,13 +23,16 @@
  *                XMdcHandlerToHide()         - Hide widget (no delete)    *
  *                XMdcFreeRGB()               - Free RGB image             *
  *                XMdcToggleVisibility()      - Toggle widget visibility   *
+ *                XMdcSetImageScales()        - Set width & height scale   *
+ *                XMdcScaleW()                - Scale image width          *
+ *                XMdcScaleH()                - Scale image height         *
  *                                                                         *
  * Note         : Algoritme for gamma/brightness/contrast correction in    *
  *                function XMdcSetGbcCorrection() copied from library      *
  *                Imlib by Rasterman                                       *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xutils.c,v 1.19 2004/01/04 22:36:17 enlf Exp $
+/* $Id: xutils.c,v 1.22 2004/10/21 23:48:39 enlf Exp $
  */
 
 /*
@@ -274,7 +277,7 @@ Uint8 *XMdcBuildRgbImage(Uint8 *img8, Int16 type, Uint32 pixels, Uint8 *vgbc)
   return(imgRGB);
 }
 
-GdkPixbuf *XMdcBuildGdkPixbuf(Uint8 *img8, Uint32 w, Uint32 h, Int16 type, Uint8 *vgbc, int RESIZE)
+GdkPixbuf *XMdcBuildGdkPixbuf(Uint8 *img8, Uint32 w, Uint32 h, Int16 type, Uint8 *vgbc)
 {
   GdkPixbuf *imtmp, *im;
   Uint8 *imgRGB;
@@ -290,8 +293,9 @@ GdkPixbuf *XMdcBuildGdkPixbuf(Uint8 *img8, Uint32 w, Uint32 h, Int16 type, Uint8
                                          ,(int)(3*w),XMdcFreeRGB,NULL);
   if (imtmp == NULL) { MdcFree(imgRGB); return(NULL); }
 
-  if (RESIZE && sResizeSelection.CurType != XMDC_RESIZE_ORIGINAL) {
-    rw = (gint)XMdcResize(w); rh = (gint)XMdcResize(h);
+  rw = (gint)XMdcScaleW(w); rh = (gint)XMdcScaleH(h);
+
+  if ((rw != w) || (rh != h)) {
     im = gdk_pixbuf_scale_simple(imtmp,rw,rh,sRenderSelection.Interp);
     gdk_pixbuf_unref(imtmp);
   }else{
@@ -301,7 +305,7 @@ GdkPixbuf *XMdcBuildGdkPixbuf(Uint8 *img8, Uint32 w, Uint32 h, Int16 type, Uint8
   return(im);
 }
 
-GdkPixbuf *XMdcBuildGdkPixbufFI(FILEINFO *fi,Uint32 i,Uint8 *vgbc,int RESIZE)
+GdkPixbuf *XMdcBuildGdkPixbufFI(FILEINFO *fi,Uint32 i,Uint8 *vgbc)
 {
    GdkPixbuf *im;
    Uint8 *img8;
@@ -316,7 +320,7 @@ GdkPixbuf *XMdcBuildGdkPixbufFI(FILEINFO *fi,Uint32 i,Uint8 *vgbc,int RESIZE)
    if (img8 == NULL)
      XMdcDisplayFatalErr(MDC_BAD_ALLOC,"Couldn't create byte image");
 
-   im = XMdcBuildGdkPixbuf(img8, w, h, t, vgbc, RESIZE); 
+   im = XMdcBuildGdkPixbuf(img8, w, h, t, vgbc);
 
    MdcFree(img8);
 
@@ -352,3 +356,47 @@ void XMdcToggleVisibility(GtkWidget *widget)
     gtk_widget_show(widget);
   }
 }
+
+void XMdcSetImageScales(void)
+{
+  my.scale_width = 1.; my.scale_height = 1.;
+
+  if (my.fi->pixdim[1] > my.fi->pixdim[2]) {
+
+    /* width > height -> height is unit */
+    my.scale_width  = my.fi->pixdim[1] / my.fi->pixdim[2];
+
+  }else if (my.fi->pixdim[2] > my.fi->pixdim[1]) {
+
+    /* height > width -> width  is unit */
+    my.scale_height = my.fi->pixdim[2] / my.fi->pixdim[1];
+
+  }
+
+}
+
+Uint32 XMdcScaleW(Uint32 width)
+{
+  Uint32 new_width = width;
+
+  if (my.scale_width != 1.) {
+
+    new_width = (Uint32)((float)width * my.scale_width);
+
+  }
+  
+  return(XMdcResize(new_width));
+}
+
+Uint32 XMdcScaleH(Uint32 height)
+{
+  Uint32 new_height = height;
+
+  if (my.scale_height != 1.) {
+
+    new_height = (Uint32)((float)height * my.scale_height);
+
+  }
+  
+  return(XMdcResize(new_height));
+}
