@@ -8,7 +8,7 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xutils.h,v 1.7 2004/01/04 22:36:17 enlf Exp $
+/* $Id: xutils.h,v 1.10 2004/10/21 23:48:39 enlf Exp $
  */
 
 /*
@@ -45,11 +45,15 @@ void XMdcShowWidget(GtkWidget *w);
 void XMdcWidgetDestroy(GtkWidget *widget, gpointer data);
 void XMdcSetGbcCorrection(ColorModifier *mod);
 Uint8 *XMdcBuildRgbImage(Uint8 *img8, Int16 type, Uint32 pixels, Uint8 *vgbc);
-GdkPixbuf *XMdcBuildGdkPixbuf(Uint8 *img8, Uint32 w, Uint32 h, Int16 type, Uint8 *vgbc, int  RESIZE);
-GdkPixbuf *XMdcBuildGdkPixbufFI(FILEINFO *fi,Uint32 i,Uint8 *vgbc,int RESIZE);
+GdkPixbuf *XMdcBuildGdkPixbuf(Uint8 *img8, Uint32 w, Uint32 h, Int16 type, Uint8 *vgbc);
+GdkPixbuf *XMdcBuildGdkPixbufFI(FILEINFO *fi,Uint32 i,Uint8 *vgbc);
 gboolean XMdcPreventDelete(GtkWidget *widget, GdkEvent *event, gpointer data);
 gboolean XMdcHandlerToHide(GtkWidget *widget, GdkEvent *event, gpointer data);
 void XMdcFreeRGB(guchar *pixdata, gpointer data);
 void XMdcToggleVisibility(GtkWidget *widget);
+void XMdcSetImageScales(void);
+Uint32 XMdcScaleW(Uint32 width);
+Uint32 XMdcScaleH(Uint32 height);
+
 #endif
 
