@@ -16,7 +16,7 @@
  *                XMdcViewerDisableAutoShrink()- Disable auto shrinking    *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xviewer.c,v 1.21 2004/01/04 22:36:17 enlf Exp $
+/* $Id: xviewer.c,v 1.22 2004/10/21 22:06:38 enlf Exp $
  */
 
 /*
@@ -67,8 +67,8 @@ int XMdcGetBoardDimensions(void)
    if (real_images == 0)
      XMdcDisplayFatalErr(MDC_BAD_CODE,"Number of images is zero !?");
 
-   mwidth  = XMdcResize(my.fi->mwidth);
-   mheight = XMdcResize(my.fi->mheight);
+   mwidth  = XMdcScaleW(my.fi->mwidth);
+   mheight = XMdcScaleH(my.fi->mheight);
 
    /* TRIAL#1: original number of images is a neat square ? */
    total_images = real_images;
@@ -161,9 +161,9 @@ int XMdcGetBoardDimensions(void)
 
    /* final fallback based on screen dimensions */
    arbitrary_row = (gdk_screen_height() - XMDC_FREE_BORDER)
-                    / XMdcResize(my.fi->mheight);
+                    / XMdcScaleH(my.fi->mheight);
    arbitrary_col = (gdk_screen_width()  - XMDC_FREE_BORDER)
-                    / XMdcResize(my.fi->mwidth);
+                    / XMdcScaleW(my.fi->mwidth);
 
    if (arbitrary_row == 0 || arbitrary_col == 0) {
      arbitrary_row = 1; arbitrary_col = 1;
@@ -217,10 +217,10 @@ void XMdcHandleBoardDimensions(void)
   /* derive colormap dimensions */
   vertical = my.images_vertical;
 
-  if (vertical*(XMdcResize(h)+(XMDC_IMAGE_BORDER<<1)) < XMDC_COLORMAP_HEIGHT) {
+  if (vertical*(XMdcScaleH(h)+(XMDC_IMAGE_BORDER<<1)) < XMDC_COLORMAP_HEIGHT) {
     my.cmap_h = XMDC_COLORMAP_HEIGHT;
   }else{
-    my.cmap_h = vertical * (XMdcResize(h) + XMDC_IMAGE_BORDER);
+    my.cmap_h = vertical * (XMdcScaleH(h) + XMDC_IMAGE_BORDER);
   }
   my.cmap_w = XMDC_COLORMAP_WIDTH;
 
