@@ -11,7 +11,7 @@
  *                XMdcEditFileInfo()            - Edit FILEINFO struct     *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xvifi.c,v 1.22 2004/05/09 22:48:04 enlf Exp $
+/* $Id: xvifi.c,v 1.24 2004/10/16 20:36:35 enlf Exp $
  */
 
 /*
@@ -148,6 +148,10 @@ void XMdcEditFileInfoCallbackApply(GtkWidget *widget, gpointer data)
     sEditFI.CurModality = M_NM;
   }else if (GTK_TOGGLE_BUTTON(sEditFI.ModalityPT)->active) {
     sEditFI.CurModality = M_PT;
+  }else if (GTK_TOGGLE_BUTTON(sEditFI.ModalityCT)->active) {
+    sEditFI.CurModality = M_CT;
+  }else if (GTK_TOGGLE_BUTTON(sEditFI.ModalityMR)->active) {
+    sEditFI.CurModality = M_MR;
   }
 
   for (i=0; i < MDC_MAX_ACQUISITIONS; i++) {
@@ -164,6 +168,9 @@ void XMdcEditFileInfoCallbackApply(GtkWidget *widget, gpointer data)
   }
 
   /* fill in FI struct */
+
+  my.fi->modality = sEditFI.CurModality;
+
   if (my.fi->pixdim[0] < 4) my.fi->pixdim[0] = 4; /* at least */
   my.fi->pixdim[1] = pixel_size;
   my.fi->pixdim[2] = pixel_size;
@@ -179,7 +186,6 @@ void XMdcEditFileInfoCallbackApply(GtkWidget *widget, gpointer data)
      id->slice_width = slice_width;
      id->slice_spacing = slice_spacing;
 
-     strcpy(id->image_mod,MdcGetStrModality(sEditFI.CurModality));
      MdcFillImgPos(my.fi,i,i%my.fi->dim[3],0.0);
      MdcFillImgOrient(my.fi,i);
   }
@@ -573,18 +579,13 @@ void XMdcEditFileInfo(void)
    gtk_widget_show(tablabel);
    gtk_notebook_append_page(GTK_NOTEBOOK(notebook), box2, tablabel);
 
-   box3 = gtk_vbox_new(FALSE,5);
+   box3 = gtk_hbox_new(FALSE,5);
    gtk_container_add(GTK_CONTAINER(box2),box3);
    gtk_container_set_border_width(GTK_CONTAINER(box3),5);
    gtk_widget_show(box3);
 
-   top = gtk_hbox_new(FALSE,5);
-   gtk_container_add(GTK_CONTAINER(box3),top);
-   gtk_container_set_border_width(GTK_CONTAINER(top),5);
-   gtk_widget_show(top);
-
    frame = gtk_frame_new("Reconstructed");
-   gtk_container_add(GTK_CONTAINER(top),frame);
+   gtk_container_add(GTK_CONTAINER(box3),frame);
    gtk_container_set_border_width(GTK_CONTAINER(frame),5);
    gtk_widget_show(frame);
 
@@ -609,7 +610,7 @@ void XMdcEditFileInfo(void)
    gtk_widget_show(button); /* MARK: no need to preserve, only two supported */
 
    frame = gtk_frame_new("Planar");
-   gtk_container_add(GTK_CONTAINER(top),frame);
+   gtk_container_add(GTK_CONTAINER(box3),frame);
    gtk_container_set_border_width(GTK_CONTAINER(frame),5);
    gtk_widget_show(frame);
 
@@ -633,34 +634,10 @@ void XMdcEditFileInfo(void)
      gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
    gtk_widget_show(button); /* MARK: no need to preserve, only two supported */
 
-   frame = gtk_frame_new("Modality");
-   gtk_container_add(GTK_CONTAINER(top),frame);
-   gtk_container_set_border_width(GTK_CONTAINER(frame),5);
-   gtk_widget_show(frame);
-
-   box4 = gtk_hbox_new(FALSE,5);
-   gtk_container_add(GTK_CONTAINER(frame),box4);
-   gtk_container_set_border_width(GTK_CONTAINER(box4),0);
-   gtk_widget_show(box4);
-
-   vifi->CurModality = MdcGetIntModality(my.fi->image[0].image_mod);
-
-   button = gtk_radio_button_new_with_label(NULL,"NM");
-   gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
-   if (vifi->CurModality == M_NM) {
-     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
-   }
-   gtk_widget_show(button);
-   vifi->ModalityNM = button;
-
-   group  = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
-   button = gtk_radio_button_new_with_label(group,"PT");
-   gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
-   if (vifi->CurModality == M_PT) {
-     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
-   }
-   gtk_widget_show(button); /* MARK: no need to preserve, only two supported */
-   vifi->ModalityPT = button;
+   box3 = gtk_hbox_new(FALSE,5);
+   gtk_container_add(GTK_CONTAINER(box2),box3);
+   gtk_container_set_border_width(GTK_CONTAINER(box3),5);
+   gtk_widget_show(box3);
 
    frame = gtk_frame_new("Acquisition Type");
    gtk_container_add(GTK_CONTAINER(box3),frame);
@@ -690,6 +667,60 @@ void XMdcEditFileInfo(void)
       vifi->AcquisitionType[i] = button;
    }
 
+   frame = gtk_frame_new("Modality");
+   gtk_container_add(GTK_CONTAINER(box3),frame);
+   gtk_container_set_border_width(GTK_CONTAINER(frame),5);
+   gtk_widget_show(frame);
+
+   box4 = gtk_vbox_new(FALSE,5);
+   gtk_container_add(GTK_CONTAINER(frame),box4);
+   gtk_container_set_border_width(GTK_CONTAINER(box4),0);
+   gtk_widget_show(box4);
+
+   vifi->CurModality = my.fi->modality;
+
+   button = gtk_radio_button_new_with_label(NULL,"NM");
+   gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
+   /*if (vifi->CurModality == M_NM) {
+     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+   }*/
+   gtk_widget_show(button);
+   vifi->ModalityNM = button;
+
+   group  = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+   button = gtk_radio_button_new_with_label(group,"PT");
+   gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
+   /*if (vifi->CurModality == M_PT) {
+     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+   }*/
+   gtk_widget_show(button);
+   vifi->ModalityPT = button;
+
+   group  = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+   button = gtk_radio_button_new_with_label(group,"CT");
+   gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
+   /*if (vifi->CurModality == M_CT) {
+     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+   }*/
+   gtk_widget_show(button);
+   vifi->ModalityCT = button;
+
+   group  = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+   button = gtk_radio_button_new_with_label(group,"MR");
+   gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
+   /*if (vifi->CurModality == M_MR) {
+     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+   }*/
+   gtk_widget_show(button);
+   vifi->ModalityMR = button;
+
+   group  = gtk_radio_button_group(GTK_RADIO_BUTTON(button));
+   button = gtk_radio_button_new_with_label(group,"keep current");
+   gtk_box_pack_start(GTK_BOX(box4),button,TRUE,TRUE,0);
+   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+   gtk_widget_show(button);
+   vifi->ModalityCurrent = button;
+
    /* create horizontal separator */
    separator = gtk_hseparator_new();
    gtk_box_pack_start(GTK_BOX(box1),separator,FALSE,FALSE,0);
