@@ -13,7 +13,7 @@
  *                XMdcImagesZoom()                - Display zoomed image   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xzoom.c,v 1.10 2004/01/04 22:36:17 enlf Exp $
+/* $Id: xzoom.c,v 1.17 2004/10/31 10:39:02 enlf Exp $
  */
 
 /*
@@ -52,8 +52,7 @@
 
 typedef struct ZoomStruct_t {
 
-  float factor;
-  Int8 type;
+  int type;
   Uint32 nr;
   GdkPixbuf *im, *cur;
   GtkWidget *darea;
@@ -64,43 +63,31 @@ typedef struct ZoomStruct_t {
                             F U N C T I O N S
 ****************************************************************************/
 
-#ifdef _WIN32
-static void Win32MinDim128(ZoomStruct *zoom, int *arg_w, int *arg_h)
-{
-  int w=*arg_w, h=*arg_h;
-  float factor = zoom->factor;
 
-  while (w < 128 || h < 128) {
-    factor *= (float)XMDC_ZOOM_FACTOR;
-    w = (int)((float)w * (float)XMDC_ZOOM_FACTOR);
-    h = (int)((float)h * (float)XMDC_ZOOM_FACTOR);
+/* local routine */
+static int XMdcGetZoomFactor(ZoomStruct *zoom, int z)
+{
+  zoom->type += z; /* incr/decr */
+
+  /* prevent zero (= not allowed) and -1 (= 1 original) */
+  if (zoom->type == 0 || zoom->type == -1) {
+    switch (z) {
+      case XMDC_ZOOM_IN : zoom->type =  1; break;
+      case XMDC_ZOOM_OUT: zoom->type = -2; break;
+      default           : zoom->type =  1;
+    }
   }
-  zoom->factor = factor;
-  *arg_w = w;
-  *arg_h = h;
-}
-#endif
 
-/* local routine */
-static float XMdcGetZoomFactor(Int8 type)
-{
-  float zoom;
-
-  if (type < 0) zoom = 1./(float)(-type);
-  else zoom = (float)type;
-
-  return(zoom); 
+  return(zoom->type);
 }
 
 /* local routine */
-static char *XMdcGetStrZoomFactor(float factor)
+static char *XMdcGetStrZoomFactor(int type)
 {
-  if (factor <= 0.) factor=1;
-
-  if (factor < 1.) {
-    sprintf(xmdcstr,"[1:%d]",(int)(1./factor));
+  if (type < 0) {
+    sprintf(xmdcstr,"[1:%d]",-type);
   }else{
-    sprintf(xmdcstr,"[%d:1]",(int)factor);
+    sprintf(xmdcstr,"[%d:1]",type);
   }
 
   return(xmdcstr);
@@ -110,9 +97,8 @@ static char *XMdcGetStrZoomFactor(float factor)
 static void XMdcSetZoomWindowTitle(GtkWidget *window, ZoomStruct *zoom)
 {
   Uint32 nr = zoom->nr + 1;
-  float factor = zoom->factor;
 
-  sprintf(mdcbufr,"%u %s",nr,XMdcGetStrZoomFactor(factor));
+  sprintf(mdcbufr,"%u %s",nr,XMdcGetStrZoomFactor(zoom->type));
   gtk_window_set_title(GTK_WINDOW(window),mdcbufr);
 }
 
@@ -152,86 +138,96 @@ static gboolean XMdcImagesZoomCallbackExpose(GtkWidget *widget,
 
 }
 
-
-
-
 void XMdcImagesZoomIn(GtkWidget *window)
 {
   GdkPixbuf *new;
   ZoomStruct *zoom;
-  int w, h;
+  int w, h, z;
+
+#ifdef _WIN32
+  gtk_widget_hide(window);
+#endif
 
   zoom = (ZoomStruct *)gtk_object_get_data(GTK_OBJECT(window),"zoomstruct");
 
-  zoom->factor *= (float) XMDC_ZOOM_FACTOR;
+  z = XMdcGetZoomFactor(zoom,XMDC_ZOOM_IN);
 
-  w = (int)((float)gdk_pixbuf_get_width(zoom->im)  * zoom->factor); 
-  h = (int)((float)gdk_pixbuf_get_height(zoom->im) * zoom->factor);
+  w = gdk_pixbuf_get_width(zoom->im);
+  h = gdk_pixbuf_get_height(zoom->im);
+ 
+  if (z < 0) {
+    w /= -z;
+    h /= -z;
+  }else{
+    w *= z;
+    h *= z;
+  }
+
+  gtk_window_set_policy(GTK_WINDOW(window),TRUE,TRUE,TRUE);
+
+  new = gdk_pixbuf_scale_simple(zoom->im,w,h,sRenderSelection.Interp); 
+  gdk_pixbuf_unref(zoom->cur); zoom->cur = new;
+
+  gtk_drawing_area_size(GTK_DRAWING_AREA(zoom->darea),w,h);
+
+  gdk_pixbuf_render_to_drawable(zoom->cur, zoom->darea->window,
+                                zoom->darea->style->fg_gc[GTK_STATE_NORMAL],
+                                0,0,0,0,w,h,sRenderSelection.Dither,0,0);
+
+  XMdcSetZoomWindowTitle(window,zoom);
+
+  gtk_window_set_policy(GTK_WINDOW(window),FALSE,FALSE,FALSE);
 
 #ifdef _WIN32
-  Win32MinDim128(zoom, &w, &h);
+  gtk_widget_show(window);
 #endif
 
-  if ((w < (gdk_screen_width() - XMDC_FREE_BORDER)) &&
-      (h < (gdk_screen_height()- XMDC_FREE_BORDER))) {
-
-    gtk_window_set_policy(GTK_WINDOW(window),TRUE,TRUE,TRUE);
-
-    new = gdk_pixbuf_scale_simple(zoom->im,w,h,sRenderSelection.Interp); 
-    gdk_pixbuf_unref(zoom->cur); zoom->cur = new;
-
-    gtk_drawing_area_size(GTK_DRAWING_AREA(zoom->darea),w,h);
-
-    gdk_pixbuf_render_to_drawable(zoom->cur, zoom->darea->window,
-                                  zoom->darea->style->fg_gc[GTK_STATE_NORMAL],
-                                  0,0,0,0,w,h,sRenderSelection.Dither,0,0);
-
-    XMdcSetZoomWindowTitle(window,zoom);
-
-    gtk_window_set_policy(GTK_WINDOW(window),FALSE,FALSE,FALSE);
-
-  }else{
-
-    zoom->factor /= (float)XMDC_ZOOM_FACTOR;
- 
-  }
 }
 
 void XMdcImagesZoomOut(GtkWidget *window)
 {
   GdkPixbuf *new;
   ZoomStruct *zoom;
-  int w, h;
+  int w, h, z;
+
+#ifdef _WIN32
+  gtk_widget_hide(window);
+#endif
 
   zoom = (ZoomStruct *)gtk_object_get_data(GTK_OBJECT(window),"zoomstruct");
 
-  if (zoom->factor > XMdcGetZoomFactor(zoom->type)) {
+  z = XMdcGetZoomFactor(zoom,XMDC_ZOOM_OUT);
 
-    zoom->factor /= (float)XMDC_ZOOM_FACTOR;
+  w = gdk_pixbuf_get_width(zoom->im);
+  h = gdk_pixbuf_get_height(zoom->im);
 
-    w = (int)((float)gdk_pixbuf_get_width(zoom->im)  * zoom->factor);
-    h = (int)((float)gdk_pixbuf_get_height(zoom->im) * zoom->factor);
+  if (z < 0) {
+    w /= -z;
+    h /= -z;
+  }else{
+    w *= z;
+    h *= z;
+  }
+
+  gtk_window_set_policy(GTK_WINDOW(window),TRUE,TRUE,TRUE);
+
+  new = gdk_pixbuf_scale_simple(zoom->im,w,h,sRenderSelection.Interp);
+  gdk_pixbuf_unref(zoom->cur); zoom->cur = new;
+
+  gtk_drawing_area_size(GTK_DRAWING_AREA(zoom->darea),w,h);
+
+  gdk_pixbuf_render_to_drawable(zoom->cur, zoom->darea->window,
+                                zoom->darea->style->fg_gc[GTK_STATE_NORMAL],
+                                0,0,0,0,w,h,sRenderSelection.Dither,0,0);
+
+  XMdcSetZoomWindowTitle(window,zoom);
+
+  gtk_window_set_policy(GTK_WINDOW(window),FALSE,FALSE,FALSE);
 
 #ifdef _WIN32
-    Win32MinDim128(zoom, &w, &h);
+  gtk_widget_show(window);
 #endif
 
-    gtk_window_set_policy(GTK_WINDOW(window),TRUE,TRUE,TRUE);
-
-    new = gdk_pixbuf_scale_simple(zoom->im,w,h,sRenderSelection.Interp);
-    gdk_pixbuf_unref(zoom->cur); zoom->cur = new;
-
-    gtk_drawing_area_size(GTK_DRAWING_AREA(zoom->darea),w,h);
-
-    gdk_pixbuf_render_to_drawable(zoom->cur, zoom->darea->window,
-                                  zoom->darea->style->fg_gc[GTK_STATE_NORMAL],
-                                  0,0,0,0,w,h,sRenderSelection.Dither,0,0);
- 
-    XMdcSetZoomWindowTitle(window,zoom);
-
-    gtk_window_set_policy(GTK_WINDOW(window),FALSE,FALSE,FALSE);
-
-  }
 }
 
 gboolean XMdcImagesZoomCallbackClicked(GtkWidget *widget, GdkEventButton *button, GtkWidget *window)
@@ -253,7 +249,7 @@ void XMdcImagesZoom(GtkWidget *widget, Uint32 nr)
   GtkWidget *tblbox;
   GtkWidget *darea;
   ZoomStruct *zoom=NULL;
-  int w, h, fctr;
+  int w, h, z, w_zoom, h_zoom;
 
 
   /* allocate structure */
@@ -264,67 +260,63 @@ void XMdcImagesZoom(GtkWidget *widget, Uint32 nr)
   }else{
     zoom->nr = my.realnumber[nr];
     zoom->type = sResizeSelection.CurType;
-    zoom->factor = XMdcGetZoomFactor(zoom->type);
     zoom->im = NULL; zoom->cur = NULL;
   }
 
-  if (zoom->factor < 1.) {
-    fctr = (int)1./zoom->factor;
-    w = ((int)my.fi->image[zoom->nr].width  + (fctr-1)) / fctr;
-    h = ((int)my.fi->image[zoom->nr].height + (fctr-1)) / fctr;
+  w = (int)XMdcScaleW(my.fi->image[zoom->nr].width);  w_zoom = w;
+  h = (int)XMdcScaleH(my.fi->image[zoom->nr].height); h_zoom = h;
+
+  z = XMdcGetZoomFactor(zoom,XMDC_ZOOM_NONE);
+  
+  if (z < 0) {
+    w_zoom /= -z;
+    h_zoom /= -z;
   }else{
-    fctr = (int)zoom->factor;
-    w = (int)my.fi->image[zoom->nr].width  * fctr;
-    h = (int)my.fi->image[zoom->nr].height * fctr;
+    w_zoom *= z;
+    h_zoom *= z;
   }
 
-#ifdef _WIN32
-  Win32MinDim128(zoom, &w, &h);
-#endif
+  /* initial pixmap must be original image; so no resize here */
+  my.RESIZE = MDC_NO;
+  zoom->im  = XMdcBuildGdkPixbufFI(my.fi,zoom->nr,sGbc.mod.vgbc);
+  my.RESIZE = MDC_YES;
+  zoom->cur = gdk_pixbuf_scale_simple(zoom->im,w,h,sRenderSelection.Interp);
 
-  if ( w < (gdk_screen_width() - XMDC_FREE_BORDER) &&
-       h < (gdk_screen_height()- XMDC_FREE_BORDER) ) {
-
-    /* get first pixbuf from original size (resizing = degrading image) */
-    zoom->im  = XMdcBuildGdkPixbufFI(my.fi,zoom->nr,sGbc.mod.vgbc,MDC_NO);
-    zoom->cur = gdk_pixbuf_scale_simple(zoom->im,w,h,sRenderSelection.Interp);
-
-    window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-    gtk_window_set_policy(GTK_WINDOW(window),TRUE,TRUE,TRUE);
-    gtk_container_set_border_width(GTK_CONTAINER(window),1);
-    gtk_signal_connect(GTK_OBJECT(window),"destroy",
-                       GTK_SIGNAL_FUNC(XMdcRemoveZoomStruct),zoom);
-    gtk_signal_connect(GTK_OBJECT(window),"destroy",
-                       GTK_SIGNAL_FUNC(gtk_widget_destroy),NULL);
+  window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+  gtk_window_set_policy(GTK_WINDOW(window),TRUE,TRUE,TRUE);
+  gtk_container_set_border_width(GTK_CONTAINER(window),1);
+  gtk_signal_connect(GTK_OBJECT(window),"destroy",
+                     GTK_SIGNAL_FUNC(XMdcRemoveZoomStruct),zoom);
+  gtk_signal_connect(GTK_OBJECT(window),"destroy",
+                     GTK_SIGNAL_FUNC(gtk_widget_destroy),NULL);
 
 
-    tblbox = gtk_table_new(1,1,TRUE);
-    gtk_container_add(GTK_CONTAINER(window),tblbox);
-    gtk_widget_show(tblbox);
+  tblbox = gtk_table_new(1,1,TRUE);
+  gtk_container_add(GTK_CONTAINER(window),tblbox);
+  gtk_widget_show(tblbox);
 
-    darea = gtk_drawing_area_new(); zoom->darea = darea;
-    gtk_table_attach(GTK_TABLE(tblbox),darea,0,1,0,1,GTK_FILL,GTK_FILL,0,0);
-    gtk_widget_show(darea);
-    gtk_widget_set_events(darea, GDK_EXPOSURE_MASK | GDK_BUTTON_PRESS_MASK);
-    gtk_drawing_area_size(GTK_DRAWING_AREA(darea),w,h);
-    
-    gtk_signal_connect(GTK_OBJECT(darea),"button_press_event",
-                       GTK_SIGNAL_FUNC(XMdcImagesZoomCallbackClicked),
-                       GTK_WIDGET(window));
-    gtk_signal_connect(GTK_OBJECT(darea),"expose_event",
-                       GTK_SIGNAL_FUNC(XMdcImagesZoomCallbackExpose),
-                       GTK_WIDGET(window));
+  darea = gtk_drawing_area_new(); zoom->darea = darea;
+  gtk_table_attach(GTK_TABLE(tblbox),darea,0,1,0,1,GTK_FILL,GTK_FILL,0,0);
+  gtk_widget_show(darea);
+  gtk_widget_set_events(darea, GDK_EXPOSURE_MASK | GDK_BUTTON_PRESS_MASK);
+  gtk_drawing_area_size(GTK_DRAWING_AREA(darea),w,h);
+  
+  gtk_signal_connect(GTK_OBJECT(darea),"button_press_event",
+                     GTK_SIGNAL_FUNC(XMdcImagesZoomCallbackClicked),
+                     GTK_WIDGET(window));
+  gtk_signal_connect(GTK_OBJECT(darea),"expose_event",
+                     GTK_SIGNAL_FUNC(XMdcImagesZoomCallbackExpose),
+                     GTK_WIDGET(window));
 
-    XMdcShowWidget(window);
+  XMdcShowWidget(window);
 
-    gdk_window_set_cursor (window->window, fleurcursor);
+  gdk_window_set_cursor (window->window, fleurcursor);
 
-    gtk_object_set_data(GTK_OBJECT(window),"zoomstruct",zoom);
+  gtk_object_set_data(GTK_OBJECT(window),"zoomstruct",zoom);
 
-    XMdcSetZoomWindowTitle(window,zoom);
+  XMdcSetZoomWindowTitle(window,zoom);
 
-    gtk_window_set_policy(GTK_WINDOW(window),FALSE,FALSE,FALSE);
+  gtk_window_set_policy(GTK_WINDOW(window),FALSE,FALSE,FALSE);
 
-  }
 }
 
